(***********************************************************************



                    Mathematica-Compatible Notebook



This notebook can be used on any computer system with Mathematica 3.0,

MathReader 3.0, or any compatible application. The data for the notebook 

starts with the line of stars above.



To get the notebook into a Mathematica-compatible application, do one of 

the following:



* Save the data starting with the line of stars above into a file

  with a name ending in .nb, then open the file inside the application;



* Copy the data starting with the line of stars above to the

  clipboard, then use the Paste menu command inside the application.



Data for notebooks contains only printable 7-bit ASCII and can be

sent directly in email or through ftp in text mode.  Newlines can be

CR, LF or CRLF (Unix, Macintosh or MS-DOS style).



NOTE: If you modify the data for this notebook not in a Mathematica-

compatible application, you must delete the line below containing the 

word CacheID, otherwise Mathematica-compatible applications may try to 

use invalid cache data.



For more information on notebooks and Mathematica-compatible 

applications, contact Wolfram Research:

  web: http://www.wolfram.com

  email: info@wolfram.com

  phone: +1-217-398-0700 (U.S.)



Notebook reader applications are available free of charge from 

Wolfram Research.

***********************************************************************)



(*CacheID: 232*)





(*NotebookFileLineBreakTest

NotebookFileLineBreakTest*)

(*NotebookOptionsPosition[    256263,      10801]*)

(*NotebookOutlinePosition[    257341,      10835]*)

(*  CellTagsIndexPosition[    257297,      10831]*)

(*WindowFrame->Normal*)







Notebook[{



Cell[CellGroupData[{

Cell["One-dimensional example of the DWT with the Haar Wavelet", "Title"],



Cell["Setup", "Subtitle"],



Cell["Define Quadrature Mirror Filters for the Haar Wavelet", "Subsubtitle"],



Cell[TextData[{

  Cell[BoxData[

      \(TraditionalForm\`h\_0\  = \ \(h\_1\  = \ 1/\@2\)\)]],

  " and ",

  Cell[BoxData[

      \(TraditionalForm\`g\_0 = \(\(-g\_1\) = \ 1/\@2\)\)]]

}], "Text"],



Cell[BoxData[

    \(h[x_Integer]\  := \ 0; \ h[0]\  = \ 1/Sqrt[2]; \ h[1]\  = \ 1/Sqrt[2]; 

    \ng[x_Integer]\  := \ 0; \ g[0]\  = \ 1/Sqrt[2]; \ 

    g[1]\  = \ \(-1\)/Sqrt[2]; \)], "Input"],



Cell[CellGroupData[{



Cell["Define the \"Operator Form\" of the DWT", "Subsubtitle"],



Cell[BoxData[

    \(H[a_List, n_Integer]\  := \ 

      Table[h[k\  - \ 2  n], {k, 0, Length[a] - 1}].a // N; \n

    G[a_List, n_Integer]\  := \ 

      Table[g[k - 2  n], {k, 0, Length[a] - 1}].a // N; \)], "Input"]

}, Open  ]],



Cell[CellGroupData[{



Cell["Define the \"Operator Form\" of the IDWT", "Subsubtitle"],



Cell[BoxData[

    \(Hstar[a_List, k_Integer]\  := \ 

      Table[h[k\  - \ 2  n], {n, 0, Length[a] - 1}].a // N; \n

    Gstar[a_List, k_Integer]\  := \ 

      Table[g[k\  - \ 2\ n], {n, 0, Length[a]\  - \ 1}].a // N; \)], "Input"],



Cell[BoxData[{

    \(H[a_List]\  := \ Table[Simplify[H[a, n]], {n, 0, Length[a]/2 - 1}]\), 

    \(G[a_List]\  := \ Table[Simplify[G[a, n]], {n, 0, Length[a]/2 - 1}]\)}], 

  "Input"],



Cell[BoxData[

    \(Hstar[a_List]\  := \ 

      Table[Simplify[Hstar[a, n]], {n, 0, Length[a]*2 - 1}]; \n

    Gstar[a_List]\  := \ 

      Table[Simplify[Gstar[a, n]], {n, 0, Length[a]*2 - 1}]; \)], "Input"]

}, Open  ]],



Cell[CellGroupData[{



Cell["\<\

Define some auxiliary functions that will compose other functions\

\>", "Subsubtitle"],



Cell["\<\

This is a somewhat inefficient way of doing things, but it works for the \

demonstration.\

\>", "Text"],



Cell[BoxData[

    \(\(compose[f_, g_]\  := \ f[g[#]]&; \)\)], "Input"],



Cell[BoxData[

    \(\(compose[f_, 0]\  = \ #&; \)\)], "Input"],



Cell[BoxData[

    \(\(compose[f_, n_Integer]\  := \ 

      \(compose[f, n]\  = \ compose[f, compose[f, n - 1]]\); \)\)], "Input"]

}, Open  ]],



Cell[CellGroupData[{



Cell["Define the functions that will be called", "Subsubtitle"],



Cell[BoxData[

    \(DWT[a_List]\  := \ 

      Flatten[Append[

          Table[\(compose[G, compose[H, i]]\)[a], {i, 0, 

              Log[2, Length[a]] - 1}], \(compose[H, Log[2, Length[a]]]\)[a]]]

        \)], "Input"],



Cell[BoxData[

    \(IDWT[a_List]\  := \ 

      Module[{l\  = \ Log[2, Length[a]]}, \n\t\t

        Sum[\(compose[Hstar, j]\)[

              Gstar[a[\([

                    Range[2^l - 2^\((l - j)\) + 1, 

                      2^l\  - \ 2^\((l - j - 1)\)]]\)]]], {j, 0, l - 1}] + 

          \(compose[Hstar, l]\)[{a[\([Length[a]]\)]}]]\)], "Input"]

}, Open  ]],



Cell[CellGroupData[{



Cell["Define some auxiliary functions for denoising", "Subsubtitle"],



Cell[BoxData[

    \(\(thresh[a_List, x_]\  := \ \(If[# >= x, #, 0]&\)/@a; \)\)], "Input"],



Cell[BoxData[

    \(\(thresh2[a_List, x_]\  := \ \(If[Abs[#]\  >= \ x, #, 0]&\)/@a; \)\)], 

  "Input"],



Cell[BoxData[

    \(\(threshmax[a_List, x_]\  := \ thresh[a, Max[a]*x]; \)\)], "Input"],



Cell[BoxData[

    \(threshmax2[a_List, x_]\  := \ thresh2[a, Max[Abs/@a]*x]\)], "Input"],



Cell[BoxData[

    \(Plot2Lists[list1_List, list2_List, opts___]\  := \ 

      Show[ListPlot[list1, PlotJoined -> True, 

          PlotStyle -> {RGBColor[1, 0, 0]}, DisplayFunction -> Identity], 

        ListPlot[list2, PlotStyle -> {RGBColor[0, 0, 1]}, PlotJoined -> True, 

          DisplayFunction -> Identity], DisplayFunction -> $DisplayFunction, 

        opts]\)], "Input"]

}, Open  ]],



Cell[CellGroupData[{



Cell["Demonstration", "Subtitle"],



Cell["The underlying curve is just a sine curve", "Subsubtitle",

  CellFrame->{{0, 0}, {0, 2}}],



Cell[BoxData[

    \(\(udata\  = \ Table[Sin[x*2\ Pi/512], {x, 0, 511}]; \)\)], "Input"],



Cell[CellGroupData[{



Cell[BoxData[

    \(ListPlot[udata, PlotJoined -> True]\)], "Input"],



Cell[GraphicsData["PostScript", "\<\



%!



%%Creator: Mathematica



%%AspectRatio: .61803 



MathPictureStart



/Mabs {



Mgmatrix idtransform



Mtmatrix dtransform



} bind def



/Mabsadd { Mabs



3 -1 roll add



3 1 roll add



exch } bind def



%% Graphics



%%IncludeResource: font Courier



%%IncludeFont: Courier



/Courier findfont 10  scalefont  setfont



% Scaling calculations



0.0238095 0.00186012 0.309017 0.294302 [



[.20982 .29652 -9 -9 ]



[.20982 .29652 9 0 ]



[.39583 .29652 -9 -9 ]



[.39583 .29652 9 0 ]



[.58185 .29652 -9 -9 ]



[.58185 .29652 9 0 ]



[.76786 .29652 -9 -9 ]



[.76786 .29652 9 0 ]



[.95387 .29652 -9 -9 ]



[.95387 .29652 9 0 ]



[.01131 .01472 -12 -4.5 ]



[.01131 .01472 0 4.5 ]



[.01131 .16187 -24 -4.5 ]



[.01131 .16187 0 4.5 ]



[.01131 .45617 -18 -4.5 ]



[.01131 .45617 0 4.5 ]



[.01131 .60332 -6 -4.5 ]



[.01131 .60332 0 4.5 ]



[ 0 0 0 0 ]



[ 1 .61803 0 0 ]



] MathScale



% Start of Graphics



1 setlinecap



1 setlinejoin



newpath



0 g



.25 Mabswid



.20982 .30902 m



.20982 .31527 L



s



[(100)] .20982 .29652 0 1 Mshowa



.39583 .30902 m



.39583 .31527 L



s



[(200)] .39583 .29652 0 1 Mshowa



.58185 .30902 m



.58185 .31527 L



s



[(300)] .58185 .29652 0 1 Mshowa



.76786 .30902 m



.76786 .31527 L



s



[(400)] .76786 .29652 0 1 Mshowa



.95387 .30902 m



.95387 .31527 L



s



[(500)] .95387 .29652 0 1 Mshowa



.125 Mabswid



.06101 .30902 m



.06101 .31277 L



s



.09821 .30902 m



.09821 .31277 L



s



.13542 .30902 m



.13542 .31277 L



s



.17262 .30902 m



.17262 .31277 L



s



.24702 .30902 m



.24702 .31277 L



s



.28423 .30902 m



.28423 .31277 L



s



.32143 .30902 m



.32143 .31277 L



s



.35863 .30902 m



.35863 .31277 L



s



.43304 .30902 m



.43304 .31277 L



s



.47024 .30902 m



.47024 .31277 L



s



.50744 .30902 m



.50744 .31277 L



s



.54464 .30902 m



.54464 .31277 L



s



.61905 .30902 m



.61905 .31277 L



s



.65625 .30902 m



.65625 .31277 L



s



.69345 .30902 m



.69345 .31277 L



s



.73065 .30902 m



.73065 .31277 L



s



.80506 .30902 m



.80506 .31277 L



s



.84226 .30902 m



.84226 .31277 L



s



.87946 .30902 m



.87946 .31277 L



s



.91667 .30902 m



.91667 .31277 L



s



.99107 .30902 m



.99107 .31277 L



s



.25 Mabswid



0 .30902 m



1 .30902 L



s



.02381 .01472 m



.03006 .01472 L



s



[(-1)] .01131 .01472 1 0 Mshowa



.02381 .16187 m



.03006 .16187 L



s



[(-0.5)] .01131 .16187 1 0 Mshowa



.02381 .45617 m



.03006 .45617 L



s



[(0.5)] .01131 .45617 1 0 Mshowa



.02381 .60332 m



.03006 .60332 L



s



[(1)] .01131 .60332 1 0 Mshowa



.125 Mabswid



.02381 .04415 m



.02756 .04415 L



s



.02381 .07358 m



.02756 .07358 L



s



.02381 .10301 m



.02756 .10301 L



s



.02381 .13244 m



.02756 .13244 L



s



.02381 .1913 m



.02756 .1913 L



s



.02381 .22073 m



.02756 .22073 L



s



.02381 .25016 m



.02756 .25016 L



s



.02381 .27959 m



.02756 .27959 L



s



.02381 .33845 m



.02756 .33845 L



s



.02381 .36788 m



.02756 .36788 L



s



.02381 .39731 m



.02756 .39731 L



s



.02381 .42674 m



.02756 .42674 L



s



.02381 .4856 m



.02756 .4856 L



s



.02381 .51503 m



.02756 .51503 L



s



.02381 .54446 m



.02756 .54446 L



s



.02381 .57389 m



.02756 .57389 L



s



.25 Mabswid



.02381 0 m



.02381 .61803 L



s



0 0 m



1 0 L



1 .61803 L



0 .61803 L



closepath



clip



newpath



.5 Mabswid



.02567 .30902 m



.02753 .31263 L



.02939 .31624 L



.03125 .31985 L



.03311 .32346 L



.03497 .32706 L



.03683 .33067 L



.03869 .33427 L



.04055 .33786 L



.04241 .34146 L



.04427 .34504 L



.04613 .34862 L



.04799 .3522 L



.04985 .35577 L



.05171 .35933 L



.05357 .36289 L



.05543 .36643 L



.05729 .36997 L



.05915 .3735 L



.06101 .37702 L



.06287 .38053 L



.06473 .38402 L



.06659 .38751 L



.06845 .39099 L



.07031 .39445 L



.07217 .3979 L



.07403 .40133 L



.07589 .40476 L



.07775 .40816 L



.07961 .41156 L



.08147 .41493 L



.08333 .4183 L



.08519 .42164 L



.08705 .42497 L



.08891 .42828 L



.09077 .43157 L



.09263 .43485 L



.09449 .4381 L



.09635 .44134 L



.09821 .44455 L



.10007 .44775 L



.10193 .45092 L



.10379 .45408 L



.10565 .45721 L



.10751 .46032 L



.10937 .4634 L



.11124 .46647 L



.1131 .46951 L



.11496 .47252 L



.11682 .47551 L



Mistroke



.11868 .47848 L



.12054 .48142 L



.1224 .48433 L



.12426 .48722 L



.12612 .49008 L



.12798 .49291 L



.12984 .49572 L



.1317 .4985 L



.13356 .50125 L



.13542 .50397 L



.13728 .50666 L



.13914 .50932 L



.141 .51195 L



.14286 .51455 L



.14472 .51712 L



.14658 .51966 L



.14844 .52216 L



.1503 .52464 L



.15216 .52708 L



.15402 .52949 L



.15588 .53186 L



.15774 .53421 L



.1596 .53652 L



.16146 .53879 L



.16332 .54103 L



.16518 .54323 L



.16704 .5454 L



.1689 .54754 L



.17076 .54963 L



.17262 .5517 L



.17448 .55372 L



.17634 .55571 L



.1782 .55766 L



.18006 .55957 L



.18192 .56145 L



.18378 .56329 L



.18564 .56509 L



.1875 .56685 L



.18936 .56857 L



.19122 .57025 L



.19308 .57189 L



.19494 .5735 L



.1968 .57506 L



.19866 .57659 L



.20052 .57807 L



.20238 .57951 L



.20424 .58092 L



.2061 .58228 L



.20796 .5836 L



.20982 .58488 L



Mistroke



.21168 .58612 L



.21354 .58731 L



.2154 .58846 L



.21726 .58958 L



.21912 .59065 L



.22098 .59167 L



.22284 .59266 L



.2247 .5936 L



.22656 .5945 L



.22842 .59536 L



.23028 .59617 L



.23214 .59694 L



.234 .59766 L



.23586 .59835 L



.23772 .59899 L



.23958 .59958 L



.24144 .60013 L



.2433 .60064 L



.24516 .60111 L



.24702 .60153 L



.24888 .6019 L



.25074 .60223 L



.2526 .60252 L



.25446 .60277 L



.25632 .60296 L



.25818 .60312 L



.26004 .60323 L



.2619 .6033 L



.26376 .60332 L



.26563 .6033 L



.26749 .60323 L



.26935 .60312 L



.27121 .60296 L



.27307 .60277 L



.27493 .60252 L



.27679 .60223 L



.27865 .6019 L



.28051 .60153 L



.28237 .60111 L



.28423 .60064 L



.28609 .60013 L



.28795 .59958 L



.28981 .59899 L



.29167 .59835 L



.29353 .59766 L



.29539 .59694 L



.29725 .59617 L



.29911 .59536 L



.30097 .5945 L



.30283 .5936 L



Mistroke



.30469 .59266 L



.30655 .59167 L



.30841 .59065 L



.31027 .58958 L



.31213 .58846 L



.31399 .58731 L



.31585 .58612 L



.31771 .58488 L



.31957 .5836 L



.32143 .58228 L



.32329 .58092 L



.32515 .57951 L



.32701 .57807 L



.32887 .57659 L



.33073 .57506 L



.33259 .5735 L



.33445 .57189 L



.33631 .57025 L



.33817 .56857 L



.34003 .56685 L



.34189 .56509 L



.34375 .56329 L



.34561 .56145 L



.34747 .55957 L



.34933 .55766 L



.35119 .55571 L



.35305 .55372 L



.35491 .5517 L



.35677 .54963 L



.35863 .54754 L



.36049 .5454 L



.36235 .54323 L



.36421 .54103 L



.36607 .53879 L



.36793 .53652 L



.36979 .53421 L



.37165 .53186 L



.37351 .52949 L



.37537 .52708 L



.37723 .52464 L



.37909 .52216 L



.38095 .51966 L



.38281 .51712 L



.38467 .51455 L



.38653 .51195 L



.38839 .50932 L



.39025 .50666 L



.39211 .50397 L



.39397 .50125 L



.39583 .4985 L



Mistroke



.39769 .49572 L



.39955 .49291 L



.40141 .49008 L



.40327 .48722 L



.40513 .48433 L



.40699 .48142 L



.40885 .47848 L



.41071 .47551 L



.41257 .47252 L



.41443 .46951 L



.41629 .46647 L



.41815 .4634 L



.42001 .46032 L



.42188 .45721 L



.42374 .45408 L



.4256 .45092 L



.42746 .44775 L



.42932 .44455 L



.43118 .44134 L



.43304 .4381 L



.4349 .43485 L



.43676 .43157 L



.43862 .42828 L



.44048 .42497 L



.44234 .42164 L



.4442 .4183 L



.44606 .41493 L



.44792 .41156 L



.44978 .40816 L



.45164 .40476 L



.4535 .40133 L



.45536 .3979 L



.45722 .39445 L



.45908 .39099 L



.46094 .38751 L



.4628 .38402 L



.46466 .38053 L



.46652 .37702 L



.46838 .3735 L



.47024 .36997 L



.4721 .36643 L



.47396 .36289 L



.47582 .35933 L



.47768 .35577 L



.47954 .3522 L



.4814 .34862 L



.48326 .34504 L



.48512 .34146 L



.48698 .33786 L



.48884 .33427 L



Mistroke



.4907 .33067 L



.49256 .32706 L



.49442 .32346 L



.49628 .31985 L



.49814 .31624 L



.5 .31263 L



.50186 .30902 L



.50372 .30541 L



.50558 .30179 L



.50744 .29818 L



.5093 .29458 L



.51116 .29097 L



.51302 .28737 L



.51488 .28377 L



.51674 .28017 L



.5186 .27658 L



.52046 .27299 L



.52232 .26941 L



.52418 .26583 L



.52604 .26226 L



.5279 .2587 L



.52976 .25515 L



.53162 .2516 L



.53348 .24806 L



.53534 .24454 L



.5372 .24102 L



.53906 .23751 L



.54092 .23401 L



.54278 .23052 L



.54464 .22705 L



.5465 .22359 L



.54836 .22014 L



.55022 .2167 L



.55208 .21328 L



.55394 .20987 L



.5558 .20648 L



.55766 .2031 L



.55952 .19974 L



.56138 .19639 L



.56324 .19306 L



.5651 .18975 L



.56696 .18646 L



.56882 .18319 L



.57068 .17993 L



.57254 .1767 L



.5744 .17348 L



.57626 .17028 L



.57813 .16711 L



.57999 .16396 L



.58185 .16082 L



Mistroke



.58371 .15772 L



.58557 .15463 L



.58743 .15157 L



.58929 .14853 L



.59115 .14551 L



.59301 .14252 L



.59487 .13956 L



.59673 .13662 L



.59859 .1337 L



.60045 .13081 L



.60231 .12795 L



.60417 .12512 L



.60603 .12231 L



.60789 .11954 L



.60975 .11679 L



.61161 .11407 L



.61347 .11138 L



.61533 .10871 L



.61719 .10608 L



.61905 .10348 L



.62091 .10091 L



.62277 .09838 L



.62463 .09587 L



.62649 .0934 L



.62835 .09095 L



.63021 .08854 L



.63207 .08617 L



.63393 .08383 L



.63579 .08152 L



.63765 .07924 L



.63951 .07701 L



.64137 .0748 L



.64323 .07263 L



.64509 .0705 L



.64695 .0684 L



.64881 .06634 L



.65067 .06431 L



.65253 .06233 L



.65439 .06037 L



.65625 .05846 L



.65811 .05659 L



.65997 .05475 L



.66183 .05295 L



.66369 .05119 L



.66555 .04947 L



.66741 .04778 L



.66927 .04614 L



.67113 .04454 L



.67299 .04297 L



.67485 .04145 L



Mistroke



.67671 .03996 L



.67857 .03852 L



.68043 .03712 L



.68229 .03576 L



.68415 .03444 L



.68601 .03316 L



.68787 .03192 L



.68973 .03072 L



.69159 .02957 L



.69345 .02846 L



.69531 .02739 L



.69717 .02636 L



.69903 .02538 L



.70089 .02443 L



.70275 .02353 L



.70461 .02268 L



.70647 .02187 L



.70833 .0211 L



.71019 .02037 L



.71205 .01969 L



.71391 .01905 L



.71577 .01845 L



.71763 .0179 L



.71949 .01739 L



.72135 .01693 L



.72321 .01651 L



.72507 .01613 L



.72693 .0158 L



.72879 .01551 L



.73065 .01527 L



.73251 .01507 L



.73438 .01491 L



.73624 .0148 L



.7381 .01474 L



.73996 .01472 L



.74182 .01474 L



.74368 .0148 L



.74554 .01491 L



.7474 .01507 L



.74926 .01527 L



.75112 .01551 L



.75298 .0158 L



.75484 .01613 L



.7567 .01651 L



.75856 .01693 L



.76042 .01739 L



.76228 .0179 L



.76414 .01845 L



.766 .01905 L



.76786 .01969 L



Mistroke



.76972 .02037 L



.77158 .0211 L



.77344 .02187 L



.7753 .02268 L



.77716 .02353 L



.77902 .02443 L



.78088 .02538 L



.78274 .02636 L



.7846 .02739 L



.78646 .02846 L



.78832 .02957 L



.79018 .03072 L



.79204 .03192 L



.7939 .03316 L



.79576 .03444 L



.79762 .03576 L



.79948 .03712 L



.80134 .03852 L



.8032 .03996 L



.80506 .04145 L



.80692 .04297 L



.80878 .04454 L



.81064 .04614 L



.8125 .04778 L



.81436 .04947 L



.81622 .05119 L



.81808 .05295 L



.81994 .05475 L



.8218 .05659 L



.82366 .05846 L



.82552 .06037 L



.82738 .06233 L



.82924 .06431 L



.8311 .06634 L



.83296 .0684 L



.83482 .0705 L



.83668 .07263 L



.83854 .0748 L



.8404 .07701 L



.84226 .07924 L



.84412 .08152 L



.84598 .08383 L



.84784 .08617 L



.8497 .08854 L



.85156 .09095 L



.85342 .0934 L



.85528 .09587 L



.85714 .09838 L



.859 .10091 L



.86086 .10348 L



Mistroke



.86272 .10608 L



.86458 .10871 L



.86644 .11138 L



.8683 .11407 L



.87016 .11679 L



.87202 .11954 L



.87388 .12231 L



.87574 .12512 L



.8776 .12795 L



.87946 .13081 L



.88132 .1337 L



.88318 .13662 L



.88504 .13956 L



.8869 .14252 L



.88876 .14551 L



.89063 .14853 L



.89249 .15157 L



.89435 .15463 L



.89621 .15772 L



.89807 .16082 L



.89993 .16396 L



.90179 .16711 L



.90365 .17028 L



.90551 .17348 L



.90737 .1767 L



.90923 .17993 L



.91109 .18319 L



.91295 .18646 L



.91481 .18975 L



.91667 .19306 L



.91853 .19639 L



.92039 .19974 L



.92225 .2031 L



.92411 .20648 L



.92597 .20987 L



.92783 .21328 L



.92969 .2167 L



.93155 .22014 L



.93341 .22359 L



.93527 .22705 L



.93713 .23052 L



.93899 .23401 L



.94085 .23751 L



.94271 .24102 L



.94457 .24454 L



.94643 .24806 L



.94829 .2516 L



.95015 .25515 L



.95201 .2587 L



.95387 .26226 L



Mistroke



.95573 .26583 L



.95759 .26941 L



.95945 .27299 L



.96131 .27658 L



.96317 .28017 L



.96503 .28377 L



.96689 .28737 L



.96875 .29097 L



.97061 .29458 L



.97247 .29818 L



.97433 .30179 L



.97619 .30541 L



Mfstroke



% End of Graphics



MathPictureEnd





\

\>"], "Graphics",

  ImageSize->{398, 245.875},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006>0000mA000`40O003h00OogooSgoo003oOon?

Ool00?moohmoo`00ogooSgoo003oOon?Ool001aoo`03001oogoo0?moog1oo`0077oo00<007ooOol0

ogooL7oo000LOol00`00Oomoo`3oOom`Ool001aoo`03001oogoo0?moog1oo`004goo1@0017oo00<0

07ooOol0ogooL7oo000EOol00`00Oomoo`04Ool00`00Oomoo`3oOom`Ool000moo`<000=oo`03001o

ogoo00Aoo`@00?moo`Ioo`/005ioo`005Goo00<007ooOol017oo00<007ooOol0ogoo0goo1@002Woo

1@00FGoo000EOol00`00Oomoo`04Ool00`00Oomoo`3oOol4000BOol3001GOol001Aoo`8000Ioo`03

001oogoo0?eoo`<001Qoo`8005Eoo`0077oo00<007ooOol0ngoo0`0077oo0`00DWoo000LOol00`00

Oomoo`3jOol2000POol2001AOol001aoo`03001oogoo0?Qoo`8002Aoo`03001oogoo04ioo`0077oo

00<007ooOol0mWoo0`009Woo0P00CWoo000LOol00`00Oomoo`3eOol2000ZOol2001<Ool001aoo`03

001oogoo0?Aoo`03001oogoo02aoo`03001oogoo04Uoo`0077oo00<007ooOol0lgoo0P00;Woo0P00

BWoo000LOol3003aOol2000bOol00`00Oomoo`17Ool001aoo`03001oogoo0?5oo`03001oogoo039o

o`03001oogoo04Ioo`0077oo00<007ooOol0kgoo0P00=Woo00<007ooOol0AGoo000LOol00`00Oomo

o`3^Ool2000hOol20015Ool001aoo`03001oogoo0>eoo`03001oogoo03Yoo`03001oogoo049oo`00

77oo00<007ooOol0kGoo00<007ooOol0>Woo00<007ooOol0@Woo000LOol00`00Oomoo`3[Ool2000n

Ool20012Ool001aoo`03001oogoo0>Yoo`03001oogoo03moo`03001oogoo041oo`0077oo00<007oo

Ool0jWoo00<007ooOol0@7oo00<007ooOol0?goo000LOol00`00Oomoo`3XOol20014Ool00`00Oomo

o`0nOol001aoo`03001oogoo0>Qoo`03001oogoo04Aoo`03001oogoo03eoo`0077oo0`00igoo00<0

07ooOol0AWoo00<007ooOol0?7oo000LOol00`00Oomoo`3VOol00`00Oomoo`18Ool00`00Oomoo`0k

Ool001aoo`03001oogoo0>Eoo`8004Yoo`8003aoo`0077oo00<007ooOol0i7oo00<007ooOol0C7oo

00<007ooOol0>Goo000LOol00`00Oomoo`3SOol00`00Oomoo`1=Ool00`00Oomoo`0iOol001aoo`03

001oogoo0>=oo`03001oogoo04ioo`03001oogoo03Qoo`0077oo00<007ooOol0hWoo00<007ooOol0

D7oo00<007ooOol0=goo000LOol00`00Oomoo`3QOol00`00Oomoo`1AOol00`00Oomoo`0gOol001ao

o`03001oogoo0>5oo`03001oogoo059oo`03001oogoo03Ioo`0077oo00<007ooOol0h7oo00<007oo

Ool0E7oo00<007ooOol0=Goo000LOol00`00Oomoo`3OOol00`00Oomoo`1FOol00`00Oomoo`0dOol0

01aoo`<00=ioo`03001oogoo05Moo`03001oogoo03Aoo`0077oo00<007ooOol0gWoo00<007ooOol0

F7oo00<007ooOol0<goo000LOol00`00Oomoo`3LOol2001LOol00`00Oomoo`0bOol001aoo`03001o

ogoo0=aoo`03001oogoo05]oo`03001oogoo039oo`0077oo00<007ooOol0g7oo00<007ooOol0G7oo

00<007ooOol0<Goo000LOol00`00Oomoo`3KOol00`00Oomoo`1NOol00`00Oomoo`0`Ool001aoo`03

001oogoo0=Yoo`03001oogoo061oo`03001oogoo02moo`0077oo00<007ooOol0fWoo00<007ooOol0

H7oo00<007ooOol0;goo000LOol00`00Oomoo`3IOol00`00Oomoo`1ROol00`00Oomoo`0^Ool001ao

o`03001oogoo0=Qoo`03001oogoo06Aoo`03001oogoo02eoo`0077oo00<007ooOol0egoo00<007oo

Ool0IGoo00<007ooOol0;Goo000LOol3003GOol00`00Oomoo`1VOol00`00Oomoo`0/Ool001aoo`03

001oogoo0=Ioo`03001oogoo06Qoo`03001oogoo02]oo`0077oo00<007ooOol0eGoo00<007ooOol0

JGoo00<007ooOol0:goo000LOol00`00Oomoo`3EOol00`00Oomoo`1ZOol00`00Oomoo`0ZOol001ao

o`03001oogoo0=Aoo`03001oogoo06aoo`03001oogoo02Uoo`0077oo00<007ooOol0dgoo00<007oo

Ool0KWoo00<007ooOol0:7oo000LOol00`00Oomoo`3COol00`00Oomoo`1^Ool00`00Oomoo`0XOol0

01aoo`03001oogoo0==oo`03001oogoo06ioo`03001oogoo02Qoo`0077oo00<007ooOol0dWoo00<0

07ooOol0L7oo00<007ooOol09goo000LOol00`00Oomoo`3AOol00`00Oomoo`1bOol00`00Oomoo`0V

Ool000]oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo0=1oo`03001o

ogoo07=oo`03001oogoo02Ioo`002Woo00<007oo00001goo00<007oo00001Goo00<007ooOol0d7oo

00<007ooOol0M7oo00<007ooOol09Goo0005Ool30002Ool00`00Ool00009Ool00`00Oomoo`03Ool4

003>Ool00`00Oomoo`1fOol00`00Oomoo`0TOol000Yoo`03001oo`0000Moo`8000Ioo`03001oogoo

0<ioo`03001oogoo07Moo`03001oogoo02Aoo`002Woo00<007oo00001goo00<007ooOol01Goo00<0

07ooOol0cWoo00<007ooOol0Mgoo00<007ooOol097oo000;Ool00`00Oomoo`06Ool30005Ool00`00

Oomoo`3>Ool00`00Oomoo`1hOol00`00Oomoo`0SOol001aoo`03001oogoo0<eoo`03001oogoo07Yo

o`03001oogoo029oo`0077oo00<007ooOol0c7oo00<007ooOol0O7oo00<007ooOol08Goo000LOol0

0`00Oomoo`3<Ool00`00Oomoo`1lOol00`00Oomoo`0QOol001aoo`03001oogoo0<]oo`03001oogoo

07eoo`03001oogoo025oo`0077oo00<007ooOol0bgoo00<007ooOol0OWoo00<007ooOol087oo000L

Ool00`00Oomoo`3:Ool00`00Oomoo`20Ool00`00Oomoo`0OOol001aoo`03001oogoo0<Uoo`03001o

ogoo085oo`03001oogoo01moo`0077oo0`00bGoo00<007ooOol0PWoo00<007ooOol07Woo000LOol0

0`00Oomoo`38Ool00`00Oomoo`23Ool00`00Oomoo`0NOol001aoo`03001oogoo0<Qoo`03001oogoo

08Aoo`03001oogoo01eoo`0077oo00<007ooOol0agoo00<007ooOol0QGoo00<007ooOol07Goo000L

Ool00`00Oomoo`37Ool00`00Oomoo`26Ool00`00Oomoo`0LOol001aoo`03001oogoo0<Ioo`03001o

ogoo08Qoo`03001oogoo01]oo`0077oo00<007ooOol0aGoo00<007ooOol0RGoo00<007ooOol06goo

000LOol00`00Oomoo`35Ool00`00Oomoo`2:Ool00`00Oomoo`0JOol001aoo`03001oogoo0<Eoo`03

001oogoo08Yoo`03001oogoo01Yoo`0077oo00<007ooOol0a7oo00<007ooOol0S7oo00<007ooOol0

6Goo000LOol00`00Oomoo`33Ool00`00Oomoo`2=Ool00`00Oomoo`0IOol001aoo`<00<=oo`03001o

ogoo08ioo`03001oogoo01Qoo`0077oo00<007ooOol0`Woo00<007ooOol0Sgoo00<007ooOol067oo

000LOol00`00Oomoo`32Ool00`00Oomoo`2@Ool00`00Oomoo`0GOol001aoo`03001oogoo0<5oo`03

001oogoo099oo`03001oogoo01Ioo`0077oo00<007ooOol0`7oo00<007ooOol0Tgoo00<007ooOol0

5Woo000LOol00`00Oomoo`30Ool00`00Oomoo`2COol00`00Oomoo`0FOol001aoo`03001oogoo0<1o

o`03001oogoo09Aoo`03001oogoo01Eoo`0077oo00<007ooOol0_goo00<007ooOol0UWoo00<007oo

Ool057oo000LOol00`00Oomoo`2nOol00`00Oomoo`2GOol00`00Oomoo`0DOol001aoo`03001oogoo

0;ioo`03001oogoo09Qoo`03001oogoo01=oo`0077oo00<007ooOol0_Goo00<007ooOol0VGoo00<0

07ooOol04goo000LOol3002mOol00`00Oomoo`2JOol00`00Oomoo`0BOol001aoo`03001oogoo0;ao

o`03001oogoo09]oo`03001oogoo019oo`0077oo00<007ooOol0_7oo00<007ooOol0W7oo00<007oo

Ool04Goo000LOol00`00Oomoo`2kOol00`00Oomoo`2MOol00`00Oomoo`0AOol001aoo`03001oogoo

0;]oo`03001oogoo09ioo`03001oogoo011oo`0077oo00<007ooOol0^Woo00<007ooOol0Wgoo00<0

07ooOol047oo000LOol00`00Oomoo`2jOol00`00Oomoo`2POol00`00Oomoo`0?Ool001aoo`03001o

ogoo0;Uoo`03001oogoo0:9oo`03001oogoo00ioo`0077oo00<007ooOol0^Goo00<007ooOol0XWoo

00<007ooOol03Woo000LOol00`00Oomoo`0lOol50002Ool00`00Oomoo`02Ool00`00Oomoo`0hOol3

0003Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`0>Ool20004Ool00`00Oomoo`02Ool0

0`00Oomoo`0iOol30002Ool00`00Oomoo`02Ool00`00Oomoo`0jOol00`00Oomoo`02Ool00`00Ool0

0002Ool00`00Oomoo`0;Ool001aoo`03001oogoo03ioo`07001oogooOol007oo00000Woo00<007oo

0000>Goo00<007ooOol00Woo00<007oo00000Woo00<007oo0000:7oo00<007ooOol047oo00H007oo

Ool007oo0002Ool00`00Ool0000kOol01P00Oomoo`00Ool0009oo`03001oo`0003Yoo`03001oo`00

009oo`04001oo`00Ool200000goo001oo`0;Ool001aoo`<003ioo`07001oogooOol007oo00000Woo

00<007oo0000>Woo00L007ooOomoo`00Ool00002Ool00`00Ool0000WOol00`00Oomoo`0@Ool01`00

Oomoogoo001oo`00009oo`03001oo`0003Uoo`@00004Ool007oo0002Ool00`00Ool0000lOol01P00

Oomoo`00Ool0009oo`03001oo`0000aoo`0077oo00<007ooOol0?Woo00L007ooOomoo`00Ool00002

Ool00`00Ool0000jOol01`00Oomoogoo001oo`00009oo`03001oo`0002Ioo`03001oogoo019oo`06

001oogoo001oo`000Woo00<007oo0000>Goo00<007oo00000Woo00<007oo00000Woo00<007oo0000

>Woo0P000goo00<007oo00000Woo00<007oo000037oo000LOol00`00Oomoo`0nOol01`00Oomoogoo

001oo`00009oo`03001oo`0003Uoo`03001oo`00009oo`03001oo`00009oo`03001oo`0002Ioo`03

001oogoo011oo`03001oo`00009oo`03001oo`00009oo`03001oo`0003Yoo`80009oo`03001oo`00

009oo`03001oo`0003Yoo`03001oogoo009oo`03001oo`00009oo`03001oo`0000aoo`0077oo00<0

07ooOol0?Goo0P0017oo00<007ooOol00Woo00<007ooOol0>Goo00<007ooOol00Woo00<007ooOol0

0Woo00<007ooOol09Goo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0

>Woo00D007ooOomoo`0000Aoo`03001oogoo03Uoo`<000=oo`03001oogoo009oo`03001oogoo00]o

o`0077oo00<007ooOol0]Goo00<007ooOol0ZWoo00<007ooOol02Woo000LOol00`00Oomoo`2dOol0

0`00Oomoo`2[Ool00`00Oomoo`0:Ool001aoo`03001oogoo0;Aoo`03001oogoo0:]oo`03001oogoo

00Yoo`0077oo00<007ooOol0]7oo00<007ooOol0[7oo00<007ooOol02Goo000LOol00`00Oomoo`2c

Ool00`00Oomoo`2^Ool00`00Oomoo`08Ool001aoo`03001oogoo0;9oo`03001oogoo0:moo`03001o

ogoo00Qoo`0077oo00<007ooOol0/Woo00<007ooOol0/7oo00<007ooOol01goo000COooo001l0000

01aoo`03001oo`0000]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo

00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo

00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Qoo`04001oogoo000=Ool00`00Oomo

o`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomo

o`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomo

o`0;Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool001aoo`03001oo`0004=oo`03001oogoo04Aoo`03

001oogoo02=oo`03001oogoo01eoo`03001oogoo04=oo`03001oogoo04=oo`03001oogoo011oo`00

77oo00<007oo0000/7oo00<007ooOol0_7oo000LOol01000Oomoo`00[Woo00<007ooOol0_Goo000L

Ool01000Oomoo`00[Woo00<007ooOol0_Goo000LOol01@00Oomoogoo0000[Goo00<007ooOol0_Goo

000LOol01@00Oomoogoo0000[7oo00<007ooOol0_Woo000LOol00`00Oomoo`02Ool00`00Oomoo`2X

Ool00`00Oomoo`2oOol001aoo`03001oogoo009oo`03001oogoo0:Qoo`03001oogoo0;moo`0077oo

00<007ooOol00goo00<007ooOol0Ygoo00<007ooOol0_goo000LOol30004Ool00`00Oomoo`2UOol0

0`00Oomoo`30Ool001aoo`03001oogoo00Aoo`03001oogoo0:Aoo`03001oogoo0<5oo`0077oo00<0

07ooOol017oo00<007ooOol0Y7oo00<007ooOol0`Goo000LOol00`00Oomoo`05Ool00`00Oomoo`2S

Ool00`00Oomoo`31Ool001aoo`03001oogoo00Ioo`03001oogoo0:5oo`03001oogoo0<9oo`0077oo

00<007ooOol01Woo00<007ooOol0X7oo00<007ooOol0`goo000LOol00`00Oomoo`06Ool00`00Oomo

o`2OOol00`00Oomoo`34Ool001aoo`03001oogoo00Moo`03001oogoo09ioo`03001oogoo0<Aoo`00

77oo00<007ooOol027oo00<007ooOol0WGoo00<007ooOol0a7oo000LOol00`00Oomoo`08Ool00`00

Oomoo`2LOol00`00Oomoo`35Ool001aoo`03001oogoo00Qoo`03001oogoo09]oo`03001oogoo0<Io

o`0077oo0`002Goo00<007ooOol0VWoo00<007ooOol0aWoo000LOol00`00Oomoo`0:Ool00`00Oomo

o`2IOol00`00Oomoo`36Ool001aoo`03001oogoo00]oo`03001oogoo09Moo`03001oogoo0<Moo`00

77oo00<007ooOol02goo00<007ooOol0UWoo00<007ooOol0b7oo000LOol00`00Oomoo`0;Ool00`00

Oomoo`2FOol00`00Oomoo`38Ool001aoo`03001oogoo00aoo`03001oogoo09Eoo`03001oogoo0<Qo

o`0077oo00<007ooOol03Goo00<007ooOol0Tgoo00<007ooOol0bGoo000LOol00`00Oomoo`0=Ool0

0`00Oomoo`2BOol00`00Oomoo`3:Ool001aoo`03001oogoo00eoo`03001oogoo099oo`03001oogoo

0<Yoo`0077oo00<007ooOol03Woo00<007ooOol0T7oo00<007ooOol0bgoo000LOol00`00Oomoo`0?

Ool00`00Oomoo`2?Ool00`00Oomoo`3;Ool001aoo`<000moo`03001oogoo08ioo`03001oogoo0<ao

o`0077oo00<007ooOol03goo00<007ooOol0SWoo00<007ooOol0c7oo000LOol00`00Oomoo`0@Ool0

0`00Oomoo`2<Ool00`00Oomoo`3=Ool001aoo`03001oogoo015oo`03001oogoo08]oo`03001oogoo

0<eoo`0077oo00<007ooOol04Woo00<007ooOol0RGoo00<007ooOol0cWoo000LOol00`00Oomoo`0B

Ool00`00Oomoo`28Ool00`00Oomoo`3?Ool001aoo`03001oogoo019oo`03001oogoo08Qoo`03001o

ogoo0<moo`0077oo00<007ooOol04goo00<007ooOol0Qgoo00<007ooOol0cgoo000LOol00`00Oomo

o`0DOol00`00Oomoo`25Ool00`00Oomoo`3@Ool001aoo`03001oogoo01Aoo`03001oogoo08Aoo`03

001oogoo0=5oo`0077oo00<007ooOol057oo00<007ooOol0Q7oo00<007ooOol0dGoo000LOol3000E

Ool00`00Oomoo`22Ool00`00Oomoo`3BOol001aoo`03001oogoo01Ioo`03001oogoo085oo`03001o

ogoo0=9oo`0077oo00<007ooOol05Woo00<007ooOol0P7oo00<007ooOol0dgoo000LOol00`00Oomo

o`0FOol00`00Oomoo`1oOol00`00Oomoo`3DOol001aoo`03001oogoo01Moo`03001oogoo07ioo`03

001oogoo0=Aoo`0077oo00<007ooOol067oo00<007ooOol0OGoo00<007ooOol0e7oo000LOol00`00

Oomoo`0IOol00`00Oomoo`1kOol00`00Oomoo`3EOol001aoo`03001oogoo01Uoo`03001oogoo07Yo

o`03001oogoo0=Ioo`0077oo00<007ooOol06Woo00<007ooOol0NGoo00<007ooOol0eWoo000LOol0

0`00Oomoo`0JOol00`00Oomoo`1hOol00`00Oomoo`3GOol000]oo`03001oogoo009oo`03001oogoo

009oo`03001oogoo00Aoo`03001oogoo01]oo`03001oogoo07Moo`03001oogoo0=Moo`002Woo00<0

07oo00001goo00<007oo00001Goo00<007ooOol06goo00<007ooOol0MWoo00<007ooOol0f7oo000:

Ool00`00Ool00009Ool00`00Oomoo`03Ool4000KOol00`00Oomoo`1dOol00`00Oomoo`3IOol000Yo

o`03001oo`0000Moo`8000Ioo`03001oogoo01eoo`03001oogoo07=oo`03001oogoo0=Uoo`002Woo

00<007oo00001goo00<007ooOol01Goo00<007ooOol07Goo00<007ooOol0LWoo00<007ooOol0fWoo

000;Ool00`00Oomoo`06Ool30005Ool00`00Oomoo`0NOol00`00Oomoo`1`Ool00`00Oomoo`3KOol0

01aoo`03001oogoo01ioo`03001oogoo071oo`03001oogoo0=]oo`0077oo00<007ooOol07goo00<0

07ooOol0Kgoo00<007ooOol0fgoo000LOol00`00Oomoo`0POol00`00Oomoo`1]Ool00`00Oomoo`3L

Ool001aoo`03001oogoo021oo`03001oogoo06aoo`03001oogoo0=eoo`0077oo00<007ooOol08Goo

00<007ooOol0JWoo00<007ooOol0gWoo000LOol00`00Oomoo`0ROol00`00Oomoo`1YOol00`00Oomo

o`3NOol001aoo`03001oogoo029oo`03001oogoo06Qoo`03001oogoo0=moo`0077oo0`008goo00<0

07ooOol0IWoo00<007ooOol0h7oo000LOol00`00Oomoo`0TOol00`00Oomoo`1UOol00`00Oomoo`3P

Ool001aoo`03001oogoo02Eoo`03001oogoo06=oo`03001oogoo0>5oo`0077oo00<007ooOol09Goo

00<007ooOol0HWoo00<007ooOol0hWoo000LOol00`00Oomoo`0UOol00`00Oomoo`1ROol00`00Oomo

o`3ROol001aoo`03001oogoo02Ioo`03001oogoo065oo`03001oogoo0>9oo`0077oo00<007ooOol0

9goo00<007ooOol0Ggoo00<007ooOol0hgoo000LOol00`00Oomoo`0WOol00`00Oomoo`1NOol00`00

Oomoo`3TOol001aoo`03001oogoo02Qoo`03001oogoo05aoo`03001oogoo0>Eoo`0077oo00<007oo

Ool0:Goo00<007ooOol0Fgoo00<007ooOol0iGoo000LOol00`00Oomoo`0YOol00`00Oomoo`1JOol0

0`00Oomoo`3VOol001aoo`<002Yoo`03001oogoo05Qoo`03001oogoo0>Moo`0077oo00<007ooOol0

:goo00<007ooOol0Egoo00<007ooOol0igoo000LOol00`00Oomoo`0/Ool00`00Oomoo`1DOol2003Z

Ool001aoo`03001oogoo02eoo`03001oogoo05=oo`03001oogoo0>Uoo`0077oo00<007ooOol0;Woo

00<007ooOol0DGoo00<007ooOol0jWoo000LOol00`00Oomoo`0^Ool00`00Oomoo`1@Ool00`00Oomo

o`3[Ool001aoo`03001oogoo02moo`03001oogoo04ioo`03001oogoo0>aoo`0077oo00<007ooOol0

<7oo00<007ooOol0CGoo00<007ooOol0k7oo000LOol00`00Oomoo`0`Ool00`00Oomoo`1<Ool00`00

Oomoo`3]Ool001aoo`03001oogoo035oo`03001oogoo04Yoo`03001oogoo0>ioo`0077oo00<007oo

Ool0<Woo0P00BGoo0P00l7oo000LOol3000cOol00`00Oomoo`16Ool00`00Oomoo`3`Ool001aoo`03

001oogoo03Aoo`03001oogoo04Eoo`03001oogoo0?1oo`0077oo00<007ooOol0=Goo00<007ooOol0

@goo00<007ooOol0lGoo000LOol00`00Oomoo`0eOol20012Ool2003dOol001aoo`03001oogoo03Mo

o`03001oogoo03moo`03001oogoo0?=oo`0077oo00<007ooOol0=goo00<007ooOol0?Woo00<007oo

Ool0m7oo000LOol00`00Oomoo`0hOol2000mOol00`00Oomoo`3eOol001aoo`03001oogoo03Yoo`03

001oogoo03Uoo`03001oogoo0?Ioo`0077oo00<007ooOol0>Woo0P00>Goo00<007ooOol0mgoo000L

Ool00`00Oomoo`0lOol00`00Oomoo`0eOol00`00Oomoo`3hOol001aoo`03001oogoo03aoo`8003Ao

o`800?]oo`0077oo0`00?Woo00<007ooOol0<7oo0P00o7oo000LOol00`00Oomoo`0oOol00`00Oomo

o`0^Ool00`00Oomoo`3lOol001aoo`03001oogoo041oo`8002eoo`800?ioo`0077oo00<007ooOol0

@Goo0P00:goo00<007ooOol0oWoo000LOol00`00Oomoo`13Ool00`00Oomoo`0VOol2003oOol2Ool0

01aoo`03001oogoo04Aoo`8002Aoo`800?moo`Aoo`0077oo00<007ooOol0AWoo0P008Goo00<007oo

Ool0ogoo17oo000LOol00`00Oomoo`18Ool2000LOol3003oOol7Ool001aoo`03001oogoo04Yoo`80

01Qoo`<00?moo`Uoo`004goo1@0017oo00<007ooOol0C7oo0`004goo0`00ogoo2goo000EOol00`00

Oomoo`04Ool00`00Oomoo`1?Ool3000<Ool4003oOol>Ool001Eoo`03001oogoo00Aoo`@0055oo``0

0?mooa9oo`005Goo00<007ooOol017oo00<007ooOol0ogooL7oo000EOol00`00Oomoo`04Ool00`00

Oomoo`3oOom`Ool001Aoo`8000Ioo`03001oogoo0?moog1oo`0077oo00<007ooOol0ogooL7oo000L

Ool00`00Oomoo`3oOom`Ool001aoo`03001oogoo0?moog1oo`00ogooSgoo003oOon?Ool00?moohmo

o`00ogooSgoo003oOon?Ool00001\

\>"],

  ImageRangeCache->{{{0, 397}, {244.875, 0}} -> {-40.9224, -1.10276, 1.425, 

  0.00900663}}]

}, Open  ]],



Cell[CellGroupData[{



Cell["Data from that curve", "Subsubtitle"],



Cell[BoxData[

    \(\(data\  = \ 

      Table[Sin[x*2\ Pi/512], {x, 0, 511}]\  + \ 

        \((Table[Random[], {x, 0, 511}]* .5\  - \  .25)\); \)\)], "Input"],



Cell[CellGroupData[{



Cell[BoxData[

    \(ListPlot[data, PlotJoined -> True]\)], "Input"],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.00186012 0.309548 0.23779 [

[.20982 .29705 -9 -9 ]

[.20982 .29705 9 0 ]

[.39583 .29705 -9 -9 ]

[.39583 .29705 9 0 ]

[.58185 .29705 -9 -9 ]

[.58185 .29705 9 0 ]

[.76786 .29705 -9 -9 ]

[.76786 .29705 9 0 ]

[.95387 .29705 -9 -9 ]

[.95387 .29705 9 0 ]

[.01131 .07176 -12 -4.5 ]

[.01131 .07176 0 4.5 ]

[.01131 .19065 -24 -4.5 ]

[.01131 .19065 0 4.5 ]

[.01131 .42844 -18 -4.5 ]

[.01131 .42844 0 4.5 ]

[.01131 .54734 -6 -4.5 ]

[.01131 .54734 0 4.5 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.20982 .30955 m

.20982 .3158 L

s

[(100)] .20982 .29705 0 1 Mshowa

.39583 .30955 m

.39583 .3158 L

s

[(200)] .39583 .29705 0 1 Mshowa

.58185 .30955 m

.58185 .3158 L

s

[(300)] .58185 .29705 0 1 Mshowa

.76786 .30955 m

.76786 .3158 L

s

[(400)] .76786 .29705 0 1 Mshowa

.95387 .30955 m

.95387 .3158 L

s

[(500)] .95387 .29705 0 1 Mshowa

.125 Mabswid

.06101 .30955 m

.06101 .3133 L

s

.09821 .30955 m

.09821 .3133 L

s

.13542 .30955 m

.13542 .3133 L

s

.17262 .30955 m

.17262 .3133 L

s

.24702 .30955 m

.24702 .3133 L

s

.28423 .30955 m

.28423 .3133 L

s

.32143 .30955 m

.32143 .3133 L

s

.35863 .30955 m

.35863 .3133 L

s

.43304 .30955 m

.43304 .3133 L

s

.47024 .30955 m

.47024 .3133 L

s

.50744 .30955 m

.50744 .3133 L

s

.54464 .30955 m

.54464 .3133 L

s

.61905 .30955 m

.61905 .3133 L

s

.65625 .30955 m

.65625 .3133 L

s

.69345 .30955 m

.69345 .3133 L

s

.73065 .30955 m

.73065 .3133 L

s

.80506 .30955 m

.80506 .3133 L

s

.84226 .30955 m

.84226 .3133 L

s

.87946 .30955 m

.87946 .3133 L

s

.91667 .30955 m

.91667 .3133 L

s

.99107 .30955 m

.99107 .3133 L

s

.25 Mabswid

0 .30955 m

1 .30955 L

s

.02381 .07176 m

.03006 .07176 L

s

[(-1)] .01131 .07176 1 0 Mshowa

.02381 .19065 m

.03006 .19065 L

s

[(-0.5)] .01131 .19065 1 0 Mshowa

.02381 .42844 m

.03006 .42844 L

s

[(0.5)] .01131 .42844 1 0 Mshowa

.02381 .54734 m

.03006 .54734 L

s

[(1)] .01131 .54734 1 0 Mshowa

.125 Mabswid

.02381 .09554 m

.02756 .09554 L

s

.02381 .11932 m

.02756 .11932 L

s

.02381 .14309 m

.02756 .14309 L

s

.02381 .16687 m

.02756 .16687 L

s

.02381 .21443 m

.02756 .21443 L

s

.02381 .23821 m

.02756 .23821 L

s

.02381 .26199 m

.02756 .26199 L

s

.02381 .28577 m

.02756 .28577 L

s

.02381 .33333 m

.02756 .33333 L

s

.02381 .35711 m

.02756 .35711 L

s

.02381 .38088 m

.02756 .38088 L

s

.02381 .40466 m

.02756 .40466 L

s

.02381 .45222 m

.02756 .45222 L

s

.02381 .476 m

.02756 .476 L

s

.02381 .49978 m

.02756 .49978 L

s

.02381 .52356 m

.02756 .52356 L

s

.02381 .04798 m

.02756 .04798 L

s

.02381 .0242 m

.02756 .0242 L

s

.02381 .00042 m

.02756 .00042 L

s

.02381 .57112 m

.02756 .57112 L

s

.02381 .5949 m

.02756 .5949 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

.5 Mabswid

.02567 .28208 m

.02753 .26823 L

.02939 .28389 L

.03125 .30741 L

.03311 .2965 L

.03497 .3621 L

.03683 .35225 L

.03869 .32156 L

.04055 .28645 L

.04241 .37769 L

.04427 .37297 L

.04613 .34471 L

.04799 .36878 L

.04985 .38396 L

.05171 .32834 L

.05357 .36533 L

.05543 .35813 L

.05729 .3925 L

.05915 .32529 L

.06101 .41464 L

.06287 .36677 L

.06473 .40762 L

.06659 .35353 L

.06845 .39634 L

.07031 .34603 L

.07217 .40362 L

.07403 .33675 L

.07589 .3589 L

.07775 .44128 L

.07961 .43614 L

.08147 .38198 L

.08333 .43768 L

.08519 .43912 L

.08705 .3456 L

.08891 .41789 L

.09077 .3858 L

.09263 .36601 L

.09449 .37902 L

.09635 .39086 L

.09821 .44348 L

.10007 .43369 L

.10193 .41512 L

.10379 .37806 L

.10565 .463 L

.10751 .38495 L

.10937 .44718 L

.11124 .46695 L

.1131 .39293 L

.11496 .48681 L

.11682 .49416 L

Mistroke

.11868 .4646 L

.12054 .49 L

.1224 .50418 L

.12426 .40043 L

.12612 .42767 L

.12798 .40001 L

.12984 .41535 L

.1317 .40773 L

.13356 .48416 L

.13542 .49116 L

.13728 .40995 L

.13914 .51074 L

.141 .45896 L

.14286 .53474 L

.14472 .46581 L

.14658 .46873 L

.14844 .45646 L

.1503 .44972 L

.15216 .46125 L

.15402 .52323 L

.15588 .49356 L

.15774 .4443 L

.1596 .48317 L

.16146 .54011 L

.16332 .54228 L

.16518 .46988 L

.16704 .49683 L

.1689 .54083 L

.17076 .51796 L

.17262 .47539 L

.17448 .48915 L

.17634 .54291 L

.1782 .5646 L

.18006 .5171 L

.18192 .49523 L

.18378 .56912 L

.18564 .5257 L

.1875 .5233 L

.18936 .57231 L

.19122 .52631 L

.19308 .49706 L

.19494 .50327 L

.1968 .5426 L

.19866 .55534 L

.20052 .55754 L

.20238 .49589 L

.20424 .49807 L

.2061 .57448 L

.20796 .57618 L

.20982 .58858 L

Mistroke

.21168 .56543 L

.21354 .48053 L

.2154 .50667 L

.21726 .56316 L

.21912 .52776 L

.22098 .50947 L

.22284 .51535 L

.2247 .50186 L

.22656 .48971 L

.22842 .51776 L

.23028 .56839 L

.23214 .55857 L

.234 .49866 L

.23586 .57393 L

.23772 .53611 L

.23958 .52123 L

.24144 .54201 L

.2433 .48673 L

.24516 .56666 L

.24702 .49557 L

.24888 .51516 L

.25074 .50333 L

.2526 .58248 L

.25446 .49988 L

.25632 .54348 L

.25818 .49847 L

.26004 .55227 L

.2619 .53282 L

.26376 .49365 L

.26563 .58652 L

.26749 .51619 L

.26935 .51086 L

.27121 .60332 L

.27307 .5498 L

.27493 .54824 L

.27679 .55321 L

.27865 .58712 L

.28051 .57764 L

.28237 .49538 L

.28423 .51557 L

.28609 .529 L

.28795 .57506 L

.28981 .53201 L

.29167 .50459 L

.29353 .49859 L

.29539 .55661 L

.29725 .55339 L

.29911 .48974 L

.30097 .55905 L

.30283 .54317 L

Mistroke

.30469 .48611 L

.30655 .56071 L

.30841 .55018 L

.31027 .56017 L

.31213 .57324 L

.31399 .53405 L

.31585 .5497 L

.31771 .49402 L

.31957 .50831 L

.32143 .58268 L

.32329 .56402 L

.32515 .51738 L

.32701 .49456 L

.32887 .54824 L

.33073 .5156 L

.33259 .54123 L

.33445 .56085 L

.33631 .5224 L

.33817 .49509 L

.34003 .46198 L

.34189 .48407 L

.34375 .50849 L

.34561 .52994 L

.34747 .51186 L

.34933 .47124 L

.35119 .53903 L

.35305 .45117 L

.35491 .54101 L

.35677 .4863 L

.35863 .47334 L

.36049 .48764 L

.36235 .51315 L

.36421 .443 L

.36607 .47337 L

.36793 .50513 L

.36979 .45713 L

.37165 .52741 L

.37351 .5028 L

.37537 .44696 L

.37723 .49086 L

.37909 .54012 L

.38095 .43363 L

.38281 .52253 L

.38467 .47915 L

.38653 .50479 L

.38839 .49123 L

.39025 .43819 L

.39211 .41128 L

.39397 .4759 L

.39583 .51177 L

Mistroke

.39769 .42599 L

.39955 .42641 L

.40141 .42509 L

.40327 .47214 L

.40513 .48915 L

.40699 .46221 L

.40885 .41028 L

.41071 .42506 L

.41257 .40839 L

.41443 .42751 L

.41629 .42221 L

.41815 .45961 L

.42001 .37787 L

.42188 .46992 L

.42374 .4133 L

.4256 .43618 L

.42746 .38232 L

.42932 .39672 L

.43118 .43117 L

.43304 .46543 L

.4349 .4624 L

.43676 .38256 L

.43862 .35014 L

.44048 .34625 L

.44234 .42669 L

.4442 .34411 L

.44606 .42956 L

.44792 .37625 L

.44978 .4373 L

.45164 .37925 L

.4535 .39531 L

.45536 .32478 L

.45722 .40004 L

.45908 .32039 L

.46094 .33925 L

.4628 .34771 L

.46466 .38327 L

.46652 .32791 L

.46838 .40083 L

.47024 .38382 L

.4721 .35175 L

.47396 .39828 L

.47582 .31522 L

.47768 .38021 L

.47954 .34852 L

.4814 .35332 L

.48326 .3 L

.48512 .36618 L

.48698 .37024 L

.48884 .33601 L

Mistroke

.4907 .3134 L

.49256 .31125 L

.49442 .3704 L

.49628 .27256 L

.49814 .35001 L

.5 .29672 L

.50186 .27783 L

.50372 .25683 L

.50558 .31262 L

.50744 .24804 L

.5093 .30966 L

.51116 .34119 L

.51302 .32123 L

.51488 .27082 L

.51674 .24276 L

.5186 .22491 L

.52046 .28514 L

.52232 .28578 L

.52418 .28655 L

.52604 .26102 L

.5279 .25281 L

.52976 .30328 L

.53162 .29711 L

.53348 .30293 L

.53534 .31445 L

.5372 .24529 L

.53906 .29599 L

.54092 .27787 L

.54278 .20905 L

.54464 .19031 L

.5465 .25701 L

.54836 .25701 L

.55022 .24842 L

.55208 .29138 L

.55394 .1747 L

.5558 .25919 L

.55766 .26771 L

.55952 .23932 L

.56138 .26673 L

.56324 .24734 L

.5651 .19278 L

.56696 .16092 L

.56882 .18472 L

.57068 .18804 L

.57254 .25776 L

.5744 .17262 L

.57626 .19978 L

.57813 .19449 L

.57999 .24992 L

.58185 .23115 L

Mistroke

.58371 .20486 L

.58557 .21493 L

.58743 .21753 L

.58929 .21478 L

.59115 .11907 L

.59301 .12643 L

.59487 .13492 L

.59673 .20541 L

.59859 .22371 L

.60045 .14392 L

.60231 .14125 L

.60417 .1186 L

.60603 .10688 L

.60789 .16278 L

.60975 .21208 L

.61161 .09983 L

.61347 .18066 L

.61533 .1118 L

.61719 .08885 L

.61905 .17814 L

.62091 .11042 L

.62277 .16329 L

.62463 .08247 L

.62649 .1881 L

.62835 .14426 L

.63021 .18467 L

.63207 .09888 L

.63393 .08602 L

.63579 .13556 L

.63765 .16631 L

.63951 .06974 L

.64137 .10301 L

.64323 .13201 L

.64509 .12143 L

.64695 .14424 L

.64881 .07909 L

.65067 .11766 L

.65253 .16795 L

.65439 .13935 L

.65625 .06548 L

.65811 .14006 L

.65997 .13829 L

.66183 .13063 L

.66369 .08438 L

.66555 .10584 L

.66741 .04928 L

.66927 .12054 L

.67113 .08569 L

.67299 .14914 L

.67485 .05035 L

Mistroke

.67671 .08671 L

.67857 .06296 L

.68043 .07513 L

.68229 .06279 L

.68415 .07515 L

.68601 .13537 L

.68787 .11692 L

.68973 .11357 L

.69159 .10156 L

.69345 .10651 L

.69531 .04798 L

.69717 .11176 L

.69903 .12692 L

.70089 .08544 L

.70275 .06985 L

.70461 .13404 L

.70647 .03665 L

.70833 .04014 L

.71019 .12073 L

.71205 .12137 L

.71391 .07043 L

.71577 .10761 L

.71763 .12363 L

.71949 .10308 L

.72135 .01472 L

.72321 .07462 L

.72507 .07749 L

.72693 .06831 L

.72879 .08556 L

.73065 .08435 L

.73251 .10482 L

.73438 .09816 L

.73624 .12663 L

.7381 .11973 L

.73996 .0791 L

.74182 .12687 L

.74368 .02064 L

.74554 .05459 L

.7474 .02897 L

.74926 .1309 L

.75112 .12154 L

.75298 .03264 L

.75484 .04488 L

.7567 .02686 L

.75856 .06807 L

.76042 .06054 L

.76228 .05645 L

.76414 .05872 L

.766 .06916 L

.76786 .12043 L

Mistroke

.76972 .11331 L

.77158 .12463 L

.77344 .11773 L

.7753 .05125 L

.77716 .02365 L

.77902 .04163 L

.78088 .12521 L

.78274 .06572 L

.7846 .07887 L

.78646 .04923 L

.78832 .12034 L

.79018 .02712 L

.79204 .06616 L

.7939 .05378 L

.79576 .13458 L

.79762 .13063 L

.79948 .03893 L

.80134 .04502 L

.8032 .08507 L

.80506 .08916 L

.80692 .12099 L

.80878 .12538 L

.81064 .15561 L

.8125 .10908 L

.81436 .1487 L

.81622 .14249 L

.81808 .06147 L

.81994 .0822 L

.8218 .15024 L

.82366 .12689 L

.82552 .08208 L

.82738 .16322 L

.82924 .10017 L

.8311 .10744 L

.83296 .11144 L

.83482 .16795 L

.83668 .06694 L

.83854 .08771 L

.8404 .13095 L

.84226 .07369 L

.84412 .18449 L

.84598 .08152 L

.84784 .08599 L

.8497 .14485 L

.85156 .10627 L

.85342 .11917 L

.85528 .09482 L

.85714 .08274 L

.859 .12489 L

.86086 .14551 L

Mistroke

.86272 .2037 L

.86458 .17244 L

.86644 .14814 L

.8683 .19372 L

.87016 .17946 L

.87202 .18764 L

.87388 .10919 L

.87574 .14923 L

.8776 .13274 L

.87946 .20508 L

.88132 .11056 L

.88318 .13167 L

.88504 .1927 L

.8869 .20529 L

.88876 .12079 L

.89063 .12792 L

.89249 .18645 L

.89435 .14219 L

.89621 .21719 L

.89807 .21346 L

.89993 .17953 L

.90179 .14944 L

.90365 .1844 L

.90551 .16221 L

.90737 .19116 L

.90923 .19451 L

.91109 .256 L

.91295 .19046 L

.91481 .23592 L

.91667 .23339 L

.91853 .25672 L

.92039 .27237 L

.92225 .21777 L

.92411 .26416 L

.92597 .2655 L

.92783 .26245 L

.92969 .26814 L

.93155 .18548 L

.93341 .27379 L

.93527 .26608 L

.93713 .21573 L

.93899 .29875 L

.94085 .1957 L

.94271 .31316 L

.94457 .29932 L

.94643 .29611 L

.94829 .27959 L

.95015 .30296 L

.95201 .2628 L

.95387 .25887 L

Mistroke

.95573 .30242 L

.95759 .2751 L

.95945 .31105 L

.96131 .31236 L

.96317 .33528 L

.96503 .29502 L

.96689 .26942 L

.96875 .34598 L

.97061 .25141 L

.97247 .33587 L

.97433 .30735 L

.97619 .35045 L

Mfstroke

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{394, 243.375},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006:0000la000`40O003h00OogooRgoo003oOon;

Ool00?mooh]oo`00ogooRgoo003oOon;Ool00?mooh]oo`0077oo0`00ogooK7oo000LOol00`00Oomo

o`3oOom/Ool001aoo`03001oogoo0?moofaoo`0077oo00<007ooOol0ogooK7oo000LOol00`00Oomo

o`3oOom/Ool001aoo`03001oogoo0?moo`=oo`03001oogoo06Ioo`0077oo00<007ooOol0ogoo0goo

00<007ooOol0IWoo000LOol00`00Oomoo`3oOol3Ool00`00Oomoo`1VOol001aoo`03001oogoo0?mo

o`=oo`03001oogoo00Eoo`03001oogoo05ioo`0077oo0`00ogoo0goo00<007ooOol01Goo00<007oo

Ool02Goo00<007ooOol0DWoo000LOol00`00Oomoo`3oOol3Ool00`00Oomoo`05Ool00`00Oomoo`02

Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`1=Ool001aoo`03001oogoo0?moo`=oo`03

001oogoo00Eoo`8000=oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo04eoo`0077oo00<0

07ooOol0ogoo0goo00<007ooOol01Goo0P0000Aoo`00Ool000Ioo`03001oogoo009oo`03001oogoo

04eoo`0077oo00<007ooOol0ogoo0goo00<007ooOol01Goo0P0000Aoo`00Ool000Ioo`8000=oo`03

001oogoo04eoo`0077oo00<007ooOol0o7oo00<007ooOol00goo00<007ooOol01Goo0P0000Aoo`00

000000Ioo`8000=oo`03001oogoo04eoo`0077oo00<007ooOol0o7oo0P0017oo00<007ooOol01Goo

0P0000Aoo`00000000Ioo`8000=oo`05001oogooOol0001;Ool001aoo`03001oogoo0?aoo`8000Ao

o`03001oogoo00Eoo`800004Ool000000006Ool20003Ool01@00Oomoogoo0000Bgoo000LOol00`00

Oomoo`3lOol20004Ool00`00Oomoo`05Ool2000017oo000000001Woo0P000goo00D007ooOomoo`00

04]oo`0077oo0`00kGoo00<007ooOol027oo00@007ooOomoo`8000Aoo`03001oogoo00Eoo`800004

Ool007oo0006Ool20002Ool30002Ool00`00Oomoo`19Ool001aoo`03001oogoo0>eoo`04001oogoo

0007Ool01000Oomoogoo0P0017oo00<007ooOol01Goo0P0000Aoo`00Ool000Ioo`80009oo`<0009o

o`03001oogoo04Uoo`0077oo00<007ooOol0kGoo00@007ooOol000Moo`04001oogooOol20004Ool0

0`00Oomoo`05Ool2000017oo001oo`001Woo0P000Woo100000=oo`00Ool0BWoo000LOol00`00Oomo

o`3]Ool01000Oomoo`001goo00@007ooOomoo`8000Aoo`03001oogoo00Eoo`800006Ool007oo001o

o`0017oo0P000Woo100000=oo`00Ool0BWoo000LOol00`00Oomoo`3]Ool01000Oomoo`001goo00@0

07ooOomoo`8000=oo`8000Moo`800003Ool007oo00<000Aoo`80009oo`@00003Ool007oo04Yoo`00

77oo00<007ooOol0kGoo00D007ooOol007oo008000Aoo`04001oogooOol20003Ool20007Ool20000

0goo001oo`030004Ool20002Ool400000goo001oo`05Ool00`00Oomoo`12Ool001aoo`03001oogoo

0>Uoo`05001oogooOol00002Ool01000Ool0000017oo00@007ooOomoo`8000=oo`8000Moo`800006

Ool007oo001oo`0017oo0P0000=oo`0000000`0000=oo`00Ool01Goo00<007ooOol0@Woo000COol5

0004Ool00`00Oomoo`3YOol01@00Oomoogoo00000Woo00@007oo000000Aoo`04001oogooOol20003

Ool200000goo001oo`04Ool2000017oo001oo`000Woo00@007ooOomoo`P00003Ool0000000Eoo`03

001oogoo00Aoo`03001oogoo03]oo`005Goo00<007ooOol017oo00<007ooOol0hgoo00<007ooOol0

0goo00D007ooOomoo`00009oo`<00003Ool007oo009oo`03001oogoo00<00003Ool007oo00800003

Ool007oo00Aoo`800003Ool007oo00=oo`04001oogooOol600000goo001oo`020005Ool00`00Oomo

o`04Ool00`00Oomoo`0kOol000moo`<000=oo`03001oogoo00Aoo`@00>9oo`03001oogoo00=oo`05

001oogooOol00002Ool300000goo001oo`02Ool00`00Oomoo`0300000goo001oo`040005Ool20000

0goo001oo`03Ool01000Oomoogoo1P0000=oo`00Ool00P001Goo00<007ooOol017oo00<007oo0000

>goo000EOol00`00Oomoo`04Ool00`00Oomoo`3SOol00`00Oomoo`03Ool01@00Oomoogoo00000Woo

0`0000=oo`00Ool00Woo00<007ooOol00`0000=oo`00Ool0100017oo00D007oo001oo`0000Aoo`04

001oogooOol50002Ool01000Ool000001Goo00<007ooOol017oo00<007oo0000>goo000EOol00`00

Oomoo`04Ool00`00Oomoo`3SOol01000Oomoo`000Woo00D007ooOomoo`00009oo`80009oo`03001o

ogoo00800003Ool0000000800005Ool007oo001oo`020004Ool01@00Ool007oo000017oo00@007oo

Oomoo`D0009oo`04001oo`000005Ool00`00Oomoo`04Ool00`00Ool0000kOol001Aoo`8000Ioo`03

001oogoo0>=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo0P000Woo00<007ooOol00P0000=o

o`0000000P0000Aoo`00Ool0009oo`04001oogooOol2000017oo001oo`0017oo00@007ooOomoo`<0

0006Ool007ooOol007oo0P001Goo00<007ooOol017oo00@007oo000003Yoo`0077oo00<007ooOol0

gGoo00<007ooOol00goo00@007ooOol0009oo`03001oogoo0080009oo`80009oo`03001oogoo0080

0003Ool0000000800004Ool007oo0002Ool20002Ool20002Ool20004Ool01000Oomoogoo0`0000Io

o`00Oomoo`00Ool20005Ool00`00Ool00004Ool01000Ool000000goo00<007ooOol0=7oo000LOol0

0`00Oomoo`3MOol01`00Oomoogoo001oo`00009oo`04001oogoo0002Ool60002Ool00`00Oomoo`02

00002Goo000007oo001oo`00Ool00002Ool20002Ool20002Ool20004Ool01000Oomoo`000Woo00<0

07oo00000Woo0P0000=oo`00Ool017oo00<007oo000017oo00<007oo00000P000Woo00<007ooOol0

=7oo000LOol00`00Oomoo`3KOol00`00Ool00003Ool01P00Ool00000Ool0009oo`03001oogoo00D0

00=oo`03001oogoo00800009Ool00000Ool007oo001oo`0000=oo`03001oogoo0080009oo`8000Ao

o`04001oogoo0002Ool00`00Ool00002Ool20002Ool00`00Oomoo`02Ool00`00Ool00004Ool00`00

Ool0000200000goo0000000fOol001aoo`03001oogoo0=]oo`03001oo`0000=oo`06001oo`00001o

o`000Woo00<007ooOol01@000goo00<007ooOol00P0000Uoo`00001oo`00Ool007oo00000goo00<0

07ooOol00P000Woo0P0017oo00@007ooOol0009oo`03001oo`00009oo`80009oo`03001oogoo009o

o`03001oo`0000Aoo`03001oo`0000800003Ool0000003Ioo`0077oo00<007ooOol0fgoo00<007oo

00000Woo0P0000Eoo`00001oo`00009oo`03001oogoo00D000=oo`03001oogoo00800009Ool00000

Ool007oo001oo`0000=oo`03001oogoo0080009oo`8000Aoo`04001oogoo0002Ool00`00Ool00002

Ool20002Ool00`00Oomoo`02Ool00`00Ool00004Ool00`00Ool0000200000goo0000000fOol001ao

o`<00=]oo`03001oo`00009oo`800005Ool00000Ool00002Ool00`00Oomoo`050003Ool00`00Oomo

o`02000017oo000007oo0`0000=oo`00Ool00goo00@007oo0000009oo`8000Eoo`03001oo`00009o

o`03001oo`00009oo`80009oo`03001oogoo009oo`03001oo`0000Aoo`03001oo`0000800003Ool0

000003Ioo`0077oo00<007ooOol0fGoo00D007oo001oo`00009oo`800004Ool00000Ool2000017oo

001oogoo1@000goo00<007ooOol00P0000Aoo`00001oo`<00003Ool007oo00=oo`04001oo`000002

Ool20005Ool00`00Ool00002Ool00`00Ool00002Ool20002Ool00`00Oomoo`02Ool01@00Ool007oo

00000Woo00<007oo00000P0000=oo`000000=Woo000LOol00`00Oomoo`3IOol3000017oo001oogoo

0P0000Aoo`00001oo`800004Ool007ooOol40004Ool00`00Ool00002000017oo000007oo0`0000=o

o`00Ool00goo00@007oo0000009oo`8000Eoo`03001oo`00009oo`03001oo`00009oo`80009oo`04

001oogooOol2000017oo001oo`000Woo1@0000=oo`000000=Woo000LOol00`00Oomoo`3IOol30000

17oo001oogoo0P0000Aoo`00001oo`800004Ool00000Ool40004Ool00`00Ool00002000017oo0000

07oo0`0000=oo`00Ool00goo00@007oo0000009oo`8000Eoo`03001oo`00009oo`03001oo`00009o

o`80009oo`04001oogooOol2000017oo001oo`000Woo1@0000=oo`000000=Woo000LOol00`00Oomo

o`3FOol00`00Oomoo`03000017oo001oogoo0P0000Aoo`00001oo`800004Ool000000002Ool20004

Ool00`00Ool0000300000goo001oo`0300000goo001oo`03Ool01000Ool000000Woo0P001Goo00<0

07oo00000Woo00<007oo00000Woo0P000Woo00@007ooOomoo`800004Ool007oo0002Ool700000goo

001oo`0dOol001aoo`03001oogoo0=Ioo`03001oogoo00D0009oo`800004Ool00000Ool2000017oo

000000000Woo0P0017oo00@007oo001oo`800003Ool007oo00<00003Ool007oo00=oo`04001oo`00

0002Ool20005Ool00`00Ool00002Ool00`00Ool00002Ool20002Ool00`00Oomoo`03000017oo001o

o`000Woo1`0000=oo`00Ool00goo00@007ooOol002eoo`0077oo00<007ooOol0eWoo00<007ooOol0

1@000Woo00<007oo00000P0000Aoo`00001oo`<0009oo`8000Aoo`04001oo`00Ool200000goo001o

o`040005Ool01000Ool000000Woo0P001Goo0`000Woo00<007oo00000Woo0P000Woo00<007ooOol0

0`0000=oo`00Ool00P0000=oo`0000001@0000=oo`00Ool00goo00@007ooOol002eoo`0077oo00<0

07ooOol0eWoo00<007ooOol01@000Woo00<007oo00000P0000Aoo`00001oo`<0009oo`8000Aoo`80

009oo`800003Ool007oo00@000Ioo`<0009oo`8000Eoo`<0009oo`03001oo`00009oo`80009oo`03

001oogoo00<00003Ool007oo00800003Ool0000000D00003Ool007oo00=oo`04001oogoo000]Ool0

01aoo`03001oogoo0=5oo`03001oogoo009oo`03001oogoo00D0009oo`06001oo`00Ool007oo0P00

00Aoo`000000009oo`8000Aoo`80009oo`800003Ool007oo00800003Ool007oo00Eoo`<0009oo`80

00Eoo`<0009oo`03001oo`00009oo`80009oo`03001oogoo00800004Ool00000Ool300000goo0000

000400000goo001oo`03Ool01000Oomoo`00;Goo000LOol3003AOol00`00Oomoo`02Ool00`00Oomo

o`050002Ool01000Ool007oo100000Aoo`000000009oo`8000Aoo`8000=oo`04001oo`00Ool20000

0goo001oo`05Ool30002Ool20005Ool20003Ool00`00Ool00002Ool20002Ool00`00Oomoo`020000

17oo000007oo0`0000=oo`0000000`000Woo00<007ooOol00Woo00@007ooOol0009oo`03001oogoo

02Qoo`0077oo00<007ooOol0dGoo0P000goo00<007ooOol01@000Woo00@007oo001oo`@00004Ool0

00000003Ool00`00Oomoo`02Ool20003Ool00`00Ool00004Ool00`00Oomoo`04Ool00`00Ool00002

Ool20006Ool01@00Oomoogoo000017oo0P000Woo00<007ooOol00P0000Aoo`00001oo`<00003Ool0

000000<0009oo`03001oogoo009oo`03001oogoo00800003Ool007oo02Uoo`0077oo00<007ooOol0

dGoo0P000goo00<007ooOol01@000Woo00@007oo001oo`@00004Ool000000003Ool00`00Oomoo`02

Ool20003Ool00`00Ool0000;Ool00`00Ool00002Ool00`00Oomoo`09Ool00`00Oomoo`02Ool20003

Ool01@00Ool00000Ool01P0000=oo`0000000P000goo00<007ooOol00Woo00<007ooOol00P0000=o

o`000000:Goo000LOol00`00Oomoo`3AOol20003Ool00`00Oomoo`050002Ool01000Ool007oo1000

00Aoo`00000000=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00io

o`8000=oo`05001oo`00001oo`0600000goo000000020003Ool00`00Oomoo`02Ool00`00Oomoo`02

00000goo0000000YOol001aoo`03001oogoo0=5oo`80009oo`80009oo`D0009oo`04001oo`00Ool4

000017oo000000000goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol03Woo00<007ooOol0

3Woo0P000goo00D007oo000007oo00<00004Ool00000Ool40003Ool00`00Oomoo`02Ool2000017oo

000007oo0P00:Goo000LOol00`00Oomoo`3AOol20002Ool20002Ool50002Ool00`00Ool00003Ool2

000017oo000000000goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol07goo00<007ooOol0

0Woo100000Eoo`00000007oo0080009oo`03001oo`0000=oo`03001oogoo009oo`D00003Ool00000

02Uoo`0077oo00<007ooOol0dGoo0P000Woo00@007oo001oo`H00004Ool007oo0003Ool2000017oo

000000000goo00<007ooOol00Woo00<007ooOol0:goo100000Eoo`00000007oo0080009oo`03001o

o`0000Aoo`04001oogooOol500000goo0000000YOol001aoo`03001oogoo0=5oo`80009oo`04001o

o`00Ool6000017oo001oo`000goo0P0000Aoo`00000000=oo`03001oogoo031oo`@00005Ool007oo

001oo`020002Ool00`00Ool00004Ool01000Oomoogoo1@0000=oo`000000:Goo000LOol3003AOol2

0002Ool01000Ool007oo1`000Woo00@007ooOomoo`800003Ool007oo00Aoo`03001oogoo035oo`<0

0004Ool007oo0002Ool01P00Oomoo`00Ool000Aoo`04001oogooOol5000017oo00000000:7oo000L

Ool00`00Oomoo`3AOol200001Woo001oogoo001oo`<00004Ool000000002Ool01P00Oomoogoo001o

o`8000Eoo`03001oogoo035oo`80009oo`03001oo`00009oo`06001oogoo001oo`0017oo00@007oo

Oomoo`D00004Ool00000000XOol001aoo`03001oogoo0=5oo`80000:Ool007ooOol007oo001oo`00

Ool30002Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0aOol20002Ool00`00Ool00002Ool01000

Oomoo`001Woo00@007oo001oo`D00004Ool00000000XOol001aoo`03001oogoo0=5oo`80000:Ool0

07ooOol007oo001oo`00Ool30002Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0aOol01`00Oomo

ogoo001oo`00009oo`04001oogoo0006Ool01000Ool007oo1@0000Aoo`000000009oo`03001oogoo

02=oo`0077oo00<007ooOol0dGoo0P0000Yoo`00Oomoo`00Ool007oo001oo`<0009oo`03001oogoo

00=oo`8003Uoo`03001oogoo00=oo`04001oogoo0002Ool00`00Oomoo`04Ool01P00Ool007oo001o

o`<00004Ool000000002Ool00`00Oomoo`0SOol001aoo`03001oogoo0=5oo`800004Ool007ooOol3

00000goo001oo`030002Ool00`00Oomoo`03Ool00`00Oomoo`0hOol00`00Oomoo`03Ool01000Oomo

o`000Woo00<007ooOol017oo00H007oo001oo`00Ool3000017oo000000000Woo00<007ooOol08goo

000LOol00`00Oomoo`3AOol2000017oo001oogoo0`0000=oo`00Ool00`000Woo00<007ooOol00goo

00<007ooOol0?Woo00@007ooOol0009oo`03001oogoo00Aoo`06001oo`00Ool007oo0`0000Aoo`00

0000009oo`03001oogoo02=oo`0077oo00<007ooOol0b7oo00<007ooOol01Woo0P0000Aoo`00Oomo

o`<00003Ool007oo00<0009oo`03001oogoo00=oo`03001oogoo03ioo`04001oogoo0002Ool00`00

Oomoo`04Ool300000goo001oo`03000017oo000000000Woo00<007ooOol08goo000LOol00`00Oomo

o`38Ool00`00Oomoo`06Ool2000017oo001oogoo0`0000=oo`00Ool00`000Woo00<007ooOol00goo

00<007ooOol0?Woo00@007ooOol0009oo`03001oogoo00Aoo`<00003Ool007oo00800003Ool007oo

0080009oo`8002Aoo`0077oo0`00b7oo00<007ooOol01Goo00D007oo001oo`00009oo`<00004Ool0

07ooOol20002Ool00`00Oomoo`03Ool00`00Oomoo`11Ool01000Oomoo`001Woo0`0000=oo`00Ool0

0P0000=oo`00Ool00P0000Aoo`00000002Aoo`0077oo00<007ooOol0b7oo00<007ooOol01Goo00D0

07oo001oo`00009oo`<00004Ool007ooOol20008Ool00`00Oomoo`11Ool01000Oomoo`001Woo0`00

00=oo`00Ool00P0000=oo`00Ool00P0000Aoo`00Ool002Aoo`0077oo00<007ooOol0b7oo00@007oo

Ool000Aoo`03001oogoo0080009oo`<00004Ool007ooOol2001?Ool00`00Oomoo`04Ool3000027oo

001oogoo001oo`00Ool2000017oo001oo`0097oo000LOol00`00Oomoo`33Ool00`00Oomoo`02Ool2

00000goo001oo`03Ool00`00Oomoo`020002Ool3000017oo001oogoo0P00Cgoo00<007ooOol017oo

0`0000Qoo`00Oomoo`00Ool007oo0P0000Aoo`00Ool002Aoo`0077oo00<007ooOol0`goo00T007oo

Oomoo`00Ool007oo000017oo00<007ooOol00P000Woo0`0000Aoo`00Oomoo`8004moo`03001oogoo

00Aoo`<00008Ool007ooOol007oo001oo`800004Ool007oo000TOol001aoo`03001oogoo0<=oo`09

001oogooOol007oo001oo`0000Aoo`03001oogoo0080009oo`<000Aoo`8004moo`03001oogoo00Ao

o`D0009oo`04001oo`00Ool200000goo001oo`02000SOol001aoo`03001oogoo0<=oo`09001oogoo

Ool007oo001oo`0000Aoo`03001oogoo0080009oo`8000Eoo`8004moo`03001oogoo00Aoo`D0009o

o`06001oo`00Ool007oo0P0000=oo`0000008goo000;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0

0`00Oomoo`04Ool00`00Oomoo`33Ool02@00Oomoogoo001oo`00Ool00004Ool00`00Oomoo`020002

Ool20005Ool2001?Ool00`00Oomoo`04Ool50002Ool01P00Ool007oo001oo`800003Ool0000000Qo

o`03001oogoo01Qoo`002Woo00<007oo00001goo00<007oo00001Goo00<007ooOol0`goo00T007oo

Oomoo`00Ool007oo000017oo00<007ooOol00P000Woo0P001Goo00<007ooOol0EGoo00D007oo001o

o`00009oo`06001oo`00Ool007oo0P000Woo00<007ooOol01Woo00<007ooOol067oo0005Ool30002

Ool00`00Ool00009Ool00`00Oomoo`03Ool4002oOol01000Oomoo`000goo00D007oo001oo`0000Ao

o`03001oogoo008000=oo`03001oogoo05]oo`03001oo`0000Aoo`03001oo`0000=oo`80009oo`03

001oo`0000Ioo`03001oogoo01Qoo`002Woo00<007oo00001goo0P001Woo00<007ooOol0`7oo00@0

07ooOol000=oo`05001oo`00Ool00004Ool00`00Oomoo`020003Ool00`00Oomoo`1KOol00`00Ool0

0004Ool00`00Ool00003Ool20002Ool00`00Ool00006Ool00`00Oomoo`0HOol000Yoo`03001oo`00

00Moo`03001oogoo00Eoo`03001oogoo0<1oo`04001oogoo0003Ool01000Ool007oo0P000goo00<0

07ooOol00P000goo00<007ooOol0Fgoo00<007ooOol017oo00<007oo00000goo0P000goo0P001Woo

00@007ooOol001Moo`002goo00<007ooOol01Woo0`001Goo00<007ooOol0`7oo00@007ooOol000=o

o`04001oo`00Ool20003Ool00`00Oomoo`020003Ool00`00Oomoo`1KOol00`00Oomoo`04Ool00`00

Ool00003Ool00`00Oomoo`02Ool20006Ool01000Oomoo`005goo000LOol00`00Oomoo`2oOol20002

Ool02000Oomoogoo001oo`00Ool20003Ool00`00Oomoo`020003Ool00`00Oomoo`1KOol00`00Oomo

o`04Ool00`00Ool00003Ool00`00Oomoo`02Ool20006Ool01000Oomoo`005goo000LOol00`00Oomo

o`2oOol20002Ool02000Oomoogoo001oo`00Ool2000017oo001oo`000Woo0P000goo00<007ooOol0

Fgoo00<007ooOol017oo00<007oo00000goo00<007ooOol00Woo0P001Woo00@007ooOol001Moo`00

77oo00<007ooOol0_goo0P000Woo00P007ooOomoo`00Ool007oo0P0000Aoo`00Ool0009oo`8000=o

o`03001oogoo069oo`03001oo`0000=oo`03001oogoo009oo`8000Ioo`04001oogoo000GOol001ao

o`03001oogoo0;moo`80009oo`08001oogooOol007oo001oo`800004Ool007oo0002Ool20003Ool0

0`00Oomoo`1XOol00`00Oomoo`02Ool20006Ool01000Oomoo`005goo000LOol00`00Oomoo`2oOol2

0002Ool02000Oomoogoo001oo`00Ool2000017oo000000000Woo0P000goo00<007ooOol0J7oo00<0

07ooOol00Woo0P001Woo00@007ooOol001Moo`0077oo0`00_goo0P000Woo00H007ooOomoo`00Ool2

00000goo001oo`030002Ool2001^Ool00`00Oomoo`02Ool30005Ool01000Ool000005goo000LOol0

0`00Oomoo`2oOol20002Ool01P00Oomoogoo001oo`800003Ool00000009oo`05001oogooOol0001^

Ool00`00Oomoo`02Ool300000goo001oo`02Ool01000Ool000005goo000LOol00`00Oomoo`2oOol2

0002Ool2000017oo001oogoo0P0000=oo`0000001Woo00<007ooOol0LGoo0`0000=oo`00Ool00Woo

00@007oo000001Moo`0077oo00<007ooOol0_goo0P000Woo0P0000Aoo`00Oomoo`800003Ool00000

00Ioo`03001oogoo075oo`<00003Ool007oo009oo`04001oo`00000GOol001aoo`03001oogoo0;Io

o`03001oogoo00Ioo`80009oo`800003Ool007oo009oo`04001oogoo001jOol01@00Ool007oo0000

0goo00@007oo000001Moo`0077oo00<007ooOol0]Woo00<007ooOol01Woo0P000Woo0P0000=oo`00

Ool00Woo00@007ooOol007Yoo`05001oo`00Ool00002Ool200000goo0000000GOol001aoo`03001o

ogoo0;Ioo`03001oogoo00Ioo`80009oo`800003Ool007oo009oo`04001oogoo001jOol01@00Ool0

07oo00000Woo00<007oo00000P005goo000LOol00`00Oomoo`2fOol00`00Oomoo`06Ool200001Woo

001oo`00Ool000=oo`04001oogoo001jOol01@00Ool007oo00000Woo00<007oo00000P005goo000L

Ool00`00Oomoo`2eOol20008Ool200001Woo001oo`00Ool000=oo`04001oogoo001jOol01@00Ool0

07oo00000Woo00<007oo00000P005goo000LOol3002eOol20008Ool200000goo001oo`030003Ool0

1000Oomoo`00NWoo00D007oo001oo`00009oo`03001oo`00008001Moo`0077oo00<007ooOol0]Goo

0P0027oo0P0000=oo`00Ool00`000goo00@007ooOol007Yoo`05001oo`00Ool00002Ool00`00Ool0

0002000GOol001aoo`03001oogoo0;Eoo`8000Moo`06001oo`00Ool007oo0`000goo00@007ooOol0

07Yoo`04001oo`00Ool200000goo001oo`03000GOol001aoo`03001oogoo0;Eoo`8000Ioo`800005

Ool007oo001oo`030003Ool01000Oomoo`00NWoo00<007ooOol00`0000=oo`00Ool00`005goo000L

Ool00`00Oomoo`2bOol00`00Oomoo`020006Ool200001Goo001oo`00Ool00`000goo00@007ooOol0

07Yoo`03001oogoo00<00003Ool007oo00<001Moo`0077oo00<007ooOol0/Woo00<007ooOol00P00

0Woo00@007ooOomoo`800005Ool007oo001oo`030003Ool00`00Oomoo`1kOol00`00Oomoo`030000

0goo001oo`03000;Ool00`00Oomoo`09Ool001aoo`03001oogoo0;9oo`03001oogoo0080009oo`04

001oogooOol2000027oo00000000Ool007oo0003Ool00`00Oomoo`1kOol00`00Oomoo`0300000goo

001oo`03000;Ool00`00Oomoo`09Ool001aoo`03001oogoo0;1oo`05001oo`00Ool00002Ool00`00

Ool00003Ool2000027oo00000000Ool007oo0003Ool00`00Oomoo`1kOol00`00Oomoo`0300001Goo

001oo`00Ool00P002Woo00<007ooOol02Goo000LOol00`00Oomoo`2`Ool01@00Ool007oo00000Woo

00<007oo00000goo0P000goo00D007oo001oo`0008Aoo`<00005Ool007oo001oo`020003Ool00`00

Oomoo`04Ool00`00Oomoo`09Ool001aoo`<00;1oo`05001oo`00Ool00002Ool00`00Ool00003Ool2

0003Ool01@00Ool007oo0000Q7oo0`0000Eoo`00Ool007oo008000=oo`03001oogoo00Aoo`03001o

ogoo00Uoo`0077oo00<007ooOol0/7oo00D007oo001oo`00009oo`03001oo`0000=oo`8000=oo`05

001oo`00Ool00024Ool500000goo001oo`020003Ool00`00Oomoo`04Ool00`00Oomoo`09Ool001ao

o`03001oo`000;1oo`05001oo`00Ool00002Ool00`00Ool00003Ool20003Ool01@00Ool007oo0000

QGoo00L007ooOol007oo001oo`020003Ool00`00Oomoo`04Ool00`00Oomoo`09Ool001aoo`03001o

o`000;1oo`05001oo`00Ool00002Ool00`00Ool00003Ool20003Ool00`00Oomoo`27Ool00`00Oomo

o`02Ool01000Ool000000goo00<007ooOol00Woo00<007oo00002goo000LOol00`00Ool0002^Ool0

1`00Ool007oo001oo`00009oo`<000=oo`8000=oo`03001oogoo08Moo`03001oogoo009oo`04001o

o`000003Ool00`00Oomoo`02Ool00`00Ool0000;Ool001aoo`<003]oo`D0009oo`03001oogoo009o

o`03001oogoo03Qoo`<000=oo`03001oogoo009oo`03001oogoo01ioo`07001oo`00Ool007oo0000

0Woo0`000goo0P000goo00<007ooOol00Woo0P0017oo00<007ooOol00Woo00<007ooOol0>7oo0`00

0Woo00<007ooOol00Woo00<007ooOol0>Goo0P000goo00<007oo00000Woo00<007oo00002goo000L

Ool3000mOol01`00Oomoogoo001oo`00009oo`03001oo`0003Uoo`03001oogoo009oo`03001oo`00

009oo`03001oo`0001moo`07001oo`00Ool007oo00000Woo0P0000Aoo`00Oomoo`8000=oo`03001o

ogoo00Aoo`06001oogoo001oo`000Woo00<007oo0000>Woo00H007ooOol007oo0002Ool00`00Ool0

000iOol300000goo0000000300000goo00000002000;Ool001aoo`<003eoo`07001oogooOol007oo

00000Woo00<007oo0000>Woo00L007ooOomoo`00Ool00002Ool00`00Ool0000OOol00`00Ool00002

000017oo001oogoo0P0000=oo`00Ool00`000goo00<007ooOol00goo00L007ooOomoo`00Ool00002

Ool00`00Ool0000hOol4000017oo001oo`000Woo00<007oo0000>Woo0P0000=oo`0000000`0000=o

o`0000000P002goo000LOol00`00Ool0000mOol01`00Oomoogoo001oo`00009oo`03001oo`0003Yo

o`07001oogooOol007oo00000Woo00<007oo00007goo00<007oo00000P0000Aoo`00Oomoo`800003

Ool007oo00<000=oo`03001oogoo00Aoo`06001oogoo001oo`000Woo00<007oo0000>7oo00<007oo

00000Woo00<007oo00000Woo00<007oo0000>Goo0`0000Aoo`00001oo`800003Ool00000008000]o

o`0077oo0`000goo00<007ooOol0=goo00L007ooOomoo`00Ool00002Ool00`00Ool0000iOol00`00

Ool00002Ool00`00Ool00002Ool00`00Ool0000OOol00`00Ool00002000017oo001oogoo0P0000=o

o`00Ool00P0017oo00<007ooOol00Woo00<007oo00000Woo00<007oo00000Woo00<007oo0000>Goo

0P000Woo00<007oo00000Woo00<007oo0000>Goo0`0000Aoo`00001oo`800003Ool00000008000]o

o`0077oo00<007oo00000goo00<007ooOol0=Woo0P0017oo00<007ooOol00Woo00<007ooOol0>Goo

00<007ooOol00Woo00<007ooOol00Woo00<007ooOol07Woo0P0000Eoo`00001oo`0000Eoo`04001o

o`000004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0iOol01@00

Oomoogoo000017oo00<007ooOol0>7oo0`0000=oo`0000000`0000Eoo`00001oo`0000]oo`0077oo

00<007oo00000goo00<007ooOol0Z7oo0P0000Eoo`00001oo`0000Eoo`04001oo`000004Ool00`00

Oomoo`2>Ool2000017oo000007oo0P0000Eoo`00001oo`0000]oo`0077oo00<007oo00000goo00<0

07ooOol0Z7oo0P0000Eoo`00001oo`0000Eoo`04001oo`00002EOol2000017oo000007oo0P0000Eo

o`00001oo`0000]oo`0077oo00<007ooOol00P0000=oo`00Ool0ZGoo0P0000Eoo`00001oo`0000Eo

o`<009Ioo`<00003Ool007oo00800005Ool00000Ool0000;Ool001aoo`03001oogoo00800003Ool0

07oo0:Aoo`03001oogoo009oo`800005Ool00000Ool00005Ool3002GOol200000goo001oo`020000

0goo00000002000;Ool001aoo`03001oogoo00800003Ool007oo0:Aoo`03001oogoo009oo`800005

Ool00000Ool00005Ool3002GOol200000goo001oo`0200000goo00000002000;Ool001aoo`03001o

ogoo00800003Ool007oo0:Aoo`03001oogoo009oo`800005Ool00000Ool00006Ool2002GOol20004

Ool00`00Ool00003000;Ool001aoo`03001oogoo00800003Ool007oo0:Aoo`03001oogoo009oo`80

0005Ool00000Ool00006Ool2002GOol00`00Oomoo`03Ool00`00Ool00004000:Ool001=oool007P0

000077oo00L007ooOomoo`00Ool00007Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;

Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;

Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool01@00Ool00000

Ool00P0000Eoo`00001oo`0000Moo`05001oogooOol0000<Ool00`00Oomoo`0;Ool00`00Oomoo`0;

Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;

Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo0P0000Ao

o`00000000Eoo`03001oogoo009oo`0077oo00L007ooOomoo`00Ool0000oOol00`00Oomoo`12Ool0

0`00Oomoo`0KOol01@00Oomoo`00Ool00P0000=oo`0000000Woo00<007oo000067oo00<007ooOol0

@goo00<007ooOol0@Woo00<007ooOol00P0000Aoo`00000000Yoo`0077oo00L007ooOomoo`00Ool0

002ROol01@00Oomoo`00Ool00P0000=oo`0000000Woo00<007oo0000YWoo0P0000Aoo`00000000Yo

o`0077oo00L007ooOomoo`00Ool0002LOol00`00Oomoo`03Ool01@00Oomoo`00Ool01@000Woo00<0

07oo0000YWoo0P0000Aoo`00000000Yoo`0077oo00L007ooOomoo`00Ool00006Ool00`00Oomoo`2A

Ool00`00Ool00005Ool01@00Oomoo`00Ool010000goo00<007oo0000YWoo0P0000Aoo`00000000Yo

o`0077oo00L007ooOomoo`00Ool00006Ool00`00Oomoo`2AOol01@00Ool007oo00000goo00D007oo

000007oo00@000Aoo`800:Moo`03001oo`00008000Yoo`0077oo00L007ooOomoo`00Ool00004Ool0

0`00Ool0002COol01@00Ool007oo00000goo00D007oo000007oo00@000Aoo`800:Moo`03001oo`00

008000Yoo`0077oo0`0000Aoo`00Ool000Aoo`03001oo`0009=oo`05001oo`00Ool00003Ool01@00

Ool00000Ool0100017oo00<007ooOol0YWoo00H007oo000007oo0009Ool001aoo`06001oogooOol0

07oo0P000goo00<007oo0000Tgoo00D007oo001oo`0000=oo`05001oo`00001oo`040004Ool00`00

Oomoo`2VOol01P00Ool00000Ool000Uoo`0077oo00@007ooOomoo`800003Ool007oo009oo`03001o

o`0000Eoo`03001oogoo08]oo`05001oo`00Ool00003Ool01@00Ool00000Ool0100017oo00<007oo

Ool0Z7oo00@007ooOol000Uoo`0077oo00@007ooOomoo`800003Ool007oo009oo`03001oo`0000Eo

o`03001oogoo08]oo`05001oo`00Ool00003Ool01@00Ool00000Ool0100017oo00<007ooOol0Z7oo

00@007ooOol000Uoo`0077oo00@007ooOomoo`800003Ool007oo009oo`03001oo`0000Eoo`03001o

ogoo08Moo`09001oogooOol007oo001oo`0000=oo`07001oo`00001oo`00Ool00P00[goo00@007oo

Ool000Uoo`0077oo00@007ooOomoo`800003Ool00000009oo`03001oo`0000Aoo`8000Aoo`03001o

ogoo085oo`8000=oo`03001oo`00008000=oo`07001oo`00001oo`00Ool00P00[goo00@007ooOol0

00Uoo`0077oo00@007ooOomoo`800003Ool00000009oo`03001oo`0000Aoo`8000Aoo`03001oogoo

081oo`<000=oo`03001oo`00008000=oo`@00003Ool007oo00800;9oo`03001oogoo00Moo`0077oo

00@007ooOomoo`800003Ool00000009oo`03001oo`0000Aoo`<000=oo`03001oogoo081oo`<000=o

o`03001oo`0000800003Ool007oo00@00003Ool007oo00800;9oo`03001oogoo00Moo`0077oo00@0

07ooOomoo`800003Ool00000009oo`03001oo`00009oo`03001oo`00008000=oo`03001oogoo081o

o`<000=oo`03001oo`0000800003Ool007oo00D0009oo`03001oogoo0;]oo`0077oo0`0000Aoo`00

Oomoo`800005Ool00000Ool00002Ool00`00Ool000020003Ool00`00Oomoo`20Ool30003Ool00`00

Ool0000200000goo001oo`0200000goo00000002Ool00`00Oomoo`2kOol001aoo`05001oogooOol0

0002Ool70002Ool00`00Ool000020003Ool00`00Oomoo`20Ool30003Ool00`00Ool0000200001Woo

000007oo001oo`80009oo`03001oogoo0;]oo`0077oo00D007ooOomoo`00009oo`L0009oo`03001o

o`00008000=oo`03001oogoo081oo`<000=oo`800004Ool00000Ool200000goo001oo`020002Ool0

0`00Oomoo`2kOol001aoo`03001oogoo00Aoo`L0009oo`03001oo`00008000=oo`03001oogoo081o

o`<000=oo`800004Ool00000Ool200000goo001oo`020002Ool00`00Oomoo`2kOol001aoo`03001o

ogoo00Aoo`@00004Ool00000Ool2000017oo000000000goo00<007oo0000Ogoo00@007oo000000=o

o`80009oo`@00003Ool007oo0080009oo`03001oogoo0;]oo`0077oo00<007ooOol017oo100000Ao

o`00001oo`800004Ool000000003Ool00`00Ool0001oOol01000Ool000000goo0P000Woo100000Eo

o`00Oomoo`00009oo`03001oogoo0;]oo`0077oo00<007ooOol017oo100000=oo`0000001@0000=o

o`00Ool00Woo00<007oo0000Ogoo00@007oo000000=oo`80009oo`@00003Ool007oo0<9oo`0077oo

00<007ooOol017oo00D007oo000007oo00L00003Ool007oo009oo`04001oo`00001nOol00`00Ool0

00020002Ool20002Ool400000goo001oo`32Ool001aoo`03001oogoo00Aoo`04001oogoo0002Ool6

00000goo001oo`02Ool200001Goo001oogoo0000MGoo00<007ooOol00goo00<007oo00000P000Woo

0P000Woo100000=oo`00Ool0`Woo000LOol30007Ool00`00Oomoo`0300001Goo000007oo00000goo

0P0000Eoo`00Oomoo`0007Eoo`03001oogoo00=oo`03001oo`0000800004Ool000000002Ool40000

0goo001oo`32Ool001aoo`03001oogoo00Moo`03001oogoo00<00008Ool00000Ool007oo001oo`80

0005Ool007ooOol0001eOol01000Oomoo`000Woo00<007oo00000P0000Aoo`000000009oo`@00<Eo

o`0077oo00<007ooOol02Woo0`0000Qoo`00001oo`00Ool007oo0P0000Aoo`00Oomoo`8007Aoo`04

001oogoo0002Ool00`00Ool00002000017oo000000000goo0`00aGoo000LOol00`00Oomoo`0:Ool3

000027oo000007oo001oo`00Ool2000017oo001oogoo0P00M7oo00@007ooOol0009oo`06001oo`00

Ool007oo0`000goo0`00aGoo000LOol00`00Oomoo`0:Ool3000027oo000007oo001oo`00Ool20000

17oo001oogoo0P00M7oo00<007ooOol00P0000Moo`00Ool007oo001oo`030003Ool30035Ool001ao

o`03001oogoo00]oo`800006Ool00000Ool007oo100000Aoo`00Oomoo`800003Ool007oo075oo`03

001oogoo00800007Ool007oo001oo`00Ool00`000goo00<007oo0000aGoo000LOol00`00Oomoo`0;

Ool200001Woo000007oo001oo`@00003Ool007oo00<00003Ool007oo075oo`03001oogoo00800007

Ool007oo001oo`00Ool00`000goo00<007oo0000aGoo000LOol00`00Oomoo`0;Ool20002Ool01000

Ool007oo100000=oo`00Ool00`0000=oo`00Ool00goo0P00K7oo00<007ooOol00P0000Yoo`00Ool0

07oo001oo`00Ool000=oo`03001oo`000<Eoo`0077oo00<007ooOol02goo0P000Woo00@007oo001o

o`<0009oo`03001oo`0000800003Ool007oo00=oo`8006aoo`03001oogoo00800008Ool007oo001o

o`00Ool000Eoo`03001oogoo0<Eoo`0077oo0`002goo0P000Woo00@007oo001oo`<0009oo`03001o

o`0000800003Ool007oo00=oo`8006aoo`03001oogoo00800008Ool007oo001oo`00Ool00<eoo`00

77oo00<007ooOol02goo0P0017oo00<007oo00000P000Woo00<007oo00000P0000=oo`00Ool00goo

0`00J7oo00@007ooOol0009oo`800005Ool007oo001oo`03003=Ool001aoo`03001oogoo00]oo`03

001oogoo00=oo`D0009oo`03001oo`0000800003Ool007oo00=oo`<0009oo`03001oogoo05aoo`03

001oogoo00=oo`80009oo`0:001oo`00Ool007oo001oo`00Ool2003>Ool001aoo`03001oogoo00]o

o`03001oogoo00=oo`D0009oo`03001oo`0000800003Ool007oo00=oo`<0009oo`03001oogoo05ao

o`03001oogoo00=oo`80009oo`<00007Ool007oo001oo`00Ool00P00cWoo000LOol00`00Oomoo`0;

Ool00`00Oomoo`03Ool50002Ool00`00Ool0000200000goo001oo`03Ool00`00Ool00002Ool00`00

Oomoo`1LOol00`00Oomoo`03Ool20002Ool300001goo001oo`00Ool007oo00800<ioo`0077oo00<0

07ooOol04Goo1@000goo1P0017oo00<007oo00000Woo00<007ooOol0G7oo00<007ooOol00goo0P00

0Woo0`0000Moo`00Ool007oo001oo`02003>Ool001aoo`03001oogoo015oo`@000Aoo`H000Aoo`03

001oo`00009oo`03001oogoo05aoo`03001oogoo00=oo`L00007Ool007oo001oo`00Ool00P00cWoo

000;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0AOol40004Ool2

000017oo0000000017oo00<007oo00000Woo00<007ooOol0G7oo00<007ooOol00goo1`0000Moo`00

Ool007oo001oo`02003>Ool000Yoo`03001oo`0000Moo`03001oo`0000Eoo`03001oogoo015oo`@0

00Aoo`800004Ool000000004Ool00`00Ool00002Ool00`00Oomoo`1KOol200000goo00000002Ool4

00002Woo000007oo001oo`00Ool007oo0P00cWoo000:Ool00`00Ool00009Ool00`00Oomoo`03Ool4

000@Ool40004Ool2000017oo0000000017oo00<007oo00000Woo00<007ooOol0Fgoo0P0000=oo`00

00000Woo00D007oo000007oo00800004Ool007oo0003Ool2003>Ool000Yoo`03001oo`0000Moo`80

00Ioo`03001oogoo015oo`@000Aoo`800004Ool000000004Ool00`00Ool00002Ool00`00Oomoo`1K

Ool200000goo00000002Ool01@00Oomoo`00Ool00P0000Aoo`00Ool000Aoo`03001oogoo0<aoo`00

2Woo00<007oo00001goo00<007ooOol01Goo00<007ooOol04Goo100017oo0P0000Aoo`00000000Ao

o`03001oo`00009oo`03001oogoo05Moo`04001oogooOol200000goo00000002Ool01@00Oomoo`00

Ool00P0000Aoo`00Ool000Aoo`03001oogoo0<aoo`002goo00<007ooOol01Woo0`001Goo00<007oo

Ool04Goo100017oo0P0000Aoo`00000000Aoo`03001oo`00009oo`03001oogoo05Moo`04001oogoo

Ool200001Goo000007oo00000goo00P007oo000007oo001oo`0017oo00<007ooOol0c7oo000LOol0

0`00Oomoo`0AOol01000Oomoo`0017oo00<007ooOol00`0017oo00<007oo00000Woo00<007ooOol0

Egoo00@007ooOomoo`800005Ool00000Ool00003Ool00`00Ool00002Ool00`00Ool0003COol001ao

o`03001oogoo015oo`03001oogoo00Eoo`03001oogoo00@000=oo`03001oo`00009oo`03001oogoo

055oo`03001oogoo00=oo`04001oogooOol200001Goo000007oo00000goo00<007oo00000Woo00<0

07oo0000dgoo000LOol00`00Oomoo`0LOol40003Ool00`00Ool00002Ool00`00Oomoo`04Ool00`00

Oomoo`1:Ool00`00Oomoo`03Ool01000Oomoogoo0P0000Eoo`00001oo`0000=oo`03001oo`00009o

o`03001oo`000==oo`0077oo00<007ooOol077oo10000goo00H007ooOol007oo0006Ool00`00Oomo

o`1:Ool01`00Oomoogoo001oo`0000=oo`800005Ool00000Ool00003Ool00`00Ool00002Ool00`00

Ool0003COol001aoo`03001oogoo01aoo`@000=oo`03001oogoo00<000=oo`04001oogoo0018Ool0

1@00Oomoogoo00000goo00<007oo00000goo0P0000=oo`00Ool00P000goo00<007oo00000goo0P00

dgoo000LOol3000LOol40002Ool01000Oomoogoo0`000goo00@007ooOol004Qoo`05001oogooOol0

0003Ool00`00Ool00003Ool200000goo001oo`020003Ool00`00Ool00003Ool2003COol001aoo`03

001oogoo01aoo`@0009oo`04001oogooOol30003Ool01000Oomoo`00B7oo00D007ooOomoo`0000=o

o`03001oo`0000=oo`800003Ool007oo008000=oo`03001oo`0000=oo`800==oo`0077oo00<007oo

Ool077oo00@007oo0000009oo`04001oogooOol40002Ool200000goo001oo`17Ool02`00Oomoogoo

001oo`00Ool007oo00000goo0P0000=oo`00Ool00P000goo00<007oo00000goo0P00dgoo000LOol0

0`00Oomoo`0LOol01000Ool000000Woo00@007ooOomoo`@0009oo`800003Ool007oo049oo`03001o

ogoo009oo`04001oogooOol3000017oo001oo`000goo0P0000=oo`00Ool00P000goo00<007oo0000

0goo0P00dgoo000LOol00`00Oomoo`0LOol01@00Ool00000Ool00P000goo100000Ioo`00Ool007oo

0013Ool00`00Oomoo`02Ool01000Oomoogoo0`0000Aoo`00Ool000=oo`800003Ool007oo008000Eo

o`04001oogooOol2003COol001aoo`03001oogoo01ioo`800003Ool0000000=oo`H00003Ool007oo

0080049oo`03001oogoo009oo`04001oogooOol3000017oo001oo`000Woo00H007oo001oo`00Ool2

0005Ool01@00Oomoogoo0000e7oo000LOol00`00Oomoo`0OOol01000Ool000000goo1P0000Moo`00

001oo`00Ool00010Ool00`00Oomoo`02Ool01000Oomoogoo0`0000Aoo`00Ool0009oo`04001oo`00

0002Ool20005Ool00`00Oomoo`3FOol001aoo`03001oogoo01moo`04001oo`000003Ool50002Ool2

000017oo001oo`00@7oo00@007ooOomoo`8000=oo`<00004Ool000000002Ool01000Ool000000Woo

0P00gWoo000LOol00`00Oomoo`0OOol01000Ool000000goo1@000Woo0P0000Aoo`00Ool0009oo`03

001oogoo03]oo`80009oo`800003Ool007oo00<00004Ool000000002Ool01000Ool000000Woo0P00

gWoo000LOol3000OOol01000Ool000000goo1@000Woo0P0000Aoo`00Ool0009oo`03001oogoo03]o

o`80009oo`800003Ool007oo00<00004Ool000000002Ool01000Ool000000Woo00<007ooOol0gGoo

000LOol00`00Oomoo`0OOol40003Ool50002Ool2000017oo001oo`000Woo00<007ooOol037oo00<0

07ooOol0:goo00<007oo00000Woo100000Eoo`00000007oo00H00003Ool00000009oo`03001oogoo

0=eoo`0077oo00<007ooOol07goo10000goo1@000Woo0P0000Aoo`00Ool0009oo`03001oogoo00ao

o`03001oogoo02]oo`03001oo`00009oo`<00003Ool0000000800003Ool0000000@00003Ool00000

009oo`03001oogoo0=eoo`0077oo00<007ooOol07goo10000goo1@000Woo0P0000=oo`00Ool00P00

00=oo`00Ool03Goo00<007ooOol07goo00<007ooOol02Goo00<007oo00000Woo0`0000=oo`000000

0P0000=oo`000000100000=oo`0000000Woo00<007ooOol0gGoo000LOol00`00Oomoo`0OOol40003

Ool50002Ool200000goo001oo`0200000goo001oo`0=Ool00`00Oomoo`08Ool00`00Oomoo`0DOol0

0`00Oomoo`09Ool00`00Ool00002Ool300000goo0000000200000goo0000000400000goo00000002

Ool00`00Oomoo`3MOol001aoo`03001oogoo01moo`@000Aoo`@0009oo`800003Ool007oo00800003

Ool007oo00eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo019oo`03001oo`0000]oo`03

001oo`00009oo`<00003Ool0000000800003Ool0000000@00003Ool00000009oo`03001oogoo0=eo

o`0077oo00<007ooOol087oo0`001Goo0`000goo00@007oo001oo`800003Ool007oo00eoo`03001o

ogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Yoo`03001oo`0000Aoo`03001o

ogoo00Aoo`04001oo`00Ool400001Woo000007oo001oo`H00003Ool000000>9oo`0077oo00<007oo

Ool08Goo0P001Goo0`000goo00@007oo001oo`@0009oo`05001oogooOol00003Ool01000Oomoogoo

0P000Woo0P001Goo0P001Woo00<007ooOol017oo00<007ooOol00goo00<007oo000017oo00@007oo

Ool000=oo`04001oo`00Ool4000017oo000007oo20000Woo00<007ooOol0h7oo000LOol00`00Oomo

o`0ROol00`00Oomoo`03Ool00`00Ool00003Ool01000Ool007oo10000Woo00D007ooOomoo`0000=o

o`80009oo`80009oo`80009oo`03001oogoo008000Aoo`03001oo`0000Ioo`09001oogooOol007oo

001oo`0000Aoo`04001oogoo0003Ool00`00Oomoo`0300000goo001oo`0200000goo000000060002

Ool00`00Oomoo`3POol001aoo`<0029oo`03001oogoo00=oo`03001oo`0000=oo`04001oo`00Ool4

0002Ool01000Oomoogoo0P000Woo0P000Woo0P000Woo0P000Woo00<007ooOol00P000Woo00D007oo

001oo`0000Ioo`03001oogoo00800004Ool007oo0004Ool01000Oomoo`000goo00<007ooOol00`00

00Ioo`00Oomoo`00Ool600001Goo001oogoo0000hWoo000LOol00`00Oomoo`0ROol00`00Oomoo`03

Ool00`00Ool00003Ool01000Ool007oo10000Woo00@007ooOomoo`80009oo`80009oo`80009oo`80

009oo`03001oogoo00800007Ool00000Ool007oo00001Woo00<007ooOol00P0000Aoo`00Ool000Ao

o`800003Ool007oo009oo`03001oogoo00<00006Ool007ooOol007oo1P0000Eoo`00Oomoo`000>9o

o`0077oo00<007ooOol0:7oo00<007oo00000goo00D007oo000007oo00<00003Ool0000000=oo`80

009oo`80009oo`80009oo`05001oo`00Ool00002Ool5000017oo001oo`001Woo00<007ooOol00P00

00Aoo`00Ool000Aoo`800003Ool007oo009oo`03001oogoo00<00006Ool007ooOol007oo1P0017oo

00<007ooOol0h7oo000LOol00`00Oomoo`0XOol00`00Ool00003Ool01@00Ool00000Ool00`0000=o

o`0000000goo0P000Woo0P000Woo0P0000Moo`00Oomoo`00Ool00002Ool5000017oo001oo`001Woo

00<007ooOol00P0000Aoo`00Ool000Aoo`800003Ool007oo009oo`03001oogoo00<00005Ool007oo

Ool00002Ool50004Ool00`00Oomoo`3POol001aoo`03001oogoo02Qoo`03001oo`0000=oo`05001o

o`00001oo`0300000goo00000003Ool20002Ool20002Ool200001goo001oogoo001oo`00009oo`D0

0006Ool007oo001oo`0017oo00<007ooOol00P0000Aoo`00Ool000Aoo`800003Ool007oo009oo`03

001oogoo00<00005Ool007ooOol00002Ool50004Ool00`00Oomoo`3POol001aoo`03001oogoo02Yo

o`05001oogooOol00002Ool00`00Ool0000200000goo00000003Ool20002Ool20002Ool2000027oo

001oogoo001oo`00Ool600000goo000000030004Ool00`00Oomoo`02000017oo0000000017oo0P00

00Ioo`00Ool007oo0002Ool300000goo001oo`04Ool5003WOol001aoo`03001oogoo02Yoo`05001o

ogooOol00002Ool00`00Ool0000200000goo00000003Ool20002Ool20002Ool2000027oo001oogoo

001oo`00Ool3000017oo000007oo1@0017oo00<007ooOol00P0000Aoo`00000000Aoo`800006Ool0

07oo001oo`000Woo0`0000=oo`00Ool017oo00<007ooOol00P00igoo000LOol00`00Oomoo`0ZOol0

1@00Oomoogoo00000Woo00D007oo000007oo00<000=oo`80009oo`80009oo`<000=oo`04001oo`00

Ool3000017oo000007oo1@0017oo00H007oo001oo`00Ool30004Ool200001Woo001oo`00Ool0009o

o`<00003Ool007oo00Aoo`03001oogoo00800>Moo`0077oo0`00:Woo00D007ooOomoo`00009oo`05

001oo`00001oo`0300000goo001oo`020002Ool200000goo001oo`020003Ool01000Ool007oo0`00

00=oo`0000001P0017oo0`0000=oo`0000000`000goo00T007oo001oo`00Ool007oo00000Woo00D0

07oo001oo`0000Eoo`03001oogoo00800>Moo`0077oo00<007ooOol0:Woo00<007ooOol017oo00D0

07oo000007oo00<00007Ool007oo001oo`00Ool00P0000=oo`00Ool00P000goo00@007oo001oo`<0

0003Ool0000000H000Aoo`<00003Ool0000000800008Ool007ooOol007oo001oo`<00009Ool007oo

Ool007oo001oo`0000Eoo`04001oogoo003XOol001aoo`03001oogoo02Yoo`03001oogoo00Aoo`05

001oo`00001oo`0300001Goo001oo`00Ool00P0000Eoo`00Ool007oo008000=oo`<00005Ool007oo

001oo`080004Ool300001goo000007oo001oo`00009oo`04001oo`00Ool300002Goo001oogoo001o

o`00Ool00005Ool01000Oomoo`00j7oo000LOol00`00Oomoo`0ZOol00`00Oomoo`04Ool00`00Ool0

0002Ool300001Goo001oo`00Ool00P0000Eoo`00Ool007oo008000=oo`D00003Ool007oo00P000Ao

o`<0009oo`05001oo`00Ool00002Ool01000Ool007oo0`0000Uoo`00Oomoo`00Ool007oo000027oo

00<007ooOol0iWoo000LOol00`00Oomoo`0ZOol00`00Oomoo`04Ool00`00Ool00002Ool200001Woo

000007oo001oo`800005Ool007oo001oo`020003Ool500000goo001oo`080004Ool30002Ool01P00

Ool007oo001oo`800003Ool007oo00<00003Ool007oo00=oo`03001oo`0000Qoo`03001oogoo0>Io

o`0077oo00<007ooOol0:Woo00<007ooOol017oo00<007oo00000Woo0P0000Ioo`00001oo`00Ool2

00001Goo001oo`00Ool00P000goo1@0000=oo`00Ool0200017oo0`000Woo00H007oo001oo`00Ool2

00000goo001oo`0300000goo001oo`03Ool00`00Ool00008Ool00`00Oomoo`3VOol001aoo`03001o

ogoo035oo`03001oo`00009oo`800006Ool00000Ool007oo0P0000Eoo`00Ool007oo008000=oo`D0

0003Ool007oo00P000=oo`04001oo`000002Ool01P00Ool007oo001oo`800003Ool007oo00<00003

Ool007oo00=oo`03001oo`0000Qoo`03001oogoo0>Ioo`004goo1@0017oo00<007ooOol0<Goo00<0

07oo00000Woo0P0000Ioo`00001oo`00Ool200001Goo001oo`00Ool00P000goo1@0000=oo`00Ool0

20000goo00@007oo0000009oo`06001oo`00Ool007oo0P0000Aoo`00001oo`<000Moo`03001oogoo

00Ioo`03001oogoo0>Ioo`005Goo00<007ooOol017oo00<007ooOol0=Woo0P0000Ioo`00001oo`00

Ool200001Goo001oo`00Ool00P000goo10000Woo00<007ooOol00`0000Aoo`00000000=oo`04001o

o`000002Ool01P00Ool007oo001oo`800004Ool00000Ool3003iOol001Eoo`03001oogoo00Aoo`@0

03Eoo`800006Ool00000Ool007oo0P0000Ioo`00Ool007oo0004Ool40002Ool01`00Oomoo`00Ool0

07oo00<000=oo`04001oo`000002Ool01P00Ool007oo001oo`800004Ool00000Ool3003iOol001Eo

o`03001oogoo00Aoo`03001oogoo03Ioo`800004Ool007oo0002Ool200001Woo001oo`00Ool000Ao

o`@0009oo`07001oogoo001oo`00Ool01@0000=oo`00Ool00P000Woo00H007oo001oo`00Ool20000

17oo000007oo0`00nGoo000EOol00`00Oomoo`04Ool00`00Oomoo`0fOol2000017oo001oo`000Woo

0P0000Ioo`00Ool007oo0004Ool40002Ool02@00Oomoo`00Ool007oo001oo`02000017oo000007oo

0P000Woo00L007oo001oo`00Ool00002Ool20003Ool00`00Oomoo`3gOol001Aoo`8000Ioo`03001o

ogoo03Ioo`800004Ool007oo0002Ool200001Woo001oo`00Ool000Aoo`<000=oo`04001oogoo0003

Ool01@00Ool00000Ool00P000Woo00X007ooOol007oo001oo`00Ool0009oo`8000=oo`03001oogoo

0?Moo`0077oo00<007ooOol0=goo00D007oo001oo`0000=oo`07001oo`00Ool007oo000017oo0`00

0goo00@007ooOol000=oo`05001oo`00001oo`020002Ool01`00Oomoo`00Ool007oo00<0009oo`80

00=oo`03001oogoo0?Moo`0077oo00<007ooOol0=goo00D007oo001oo`0000Eoo`05001oo`00Ool0

0004Ool30003Ool01000Oomoo`000goo00D007ooOol007oo0080009oo`03001oogoo009oo`03001o

o`000080009oo`8000=oo`03001oogoo0?Moo`0077oo00<007ooOol0=goo00D007oo001oo`0000Eo

o`05001oo`00Ool00004Ool00`00Ool00003Ool01000Oomoo`000goo00D007ooOol007oo0080009o

o`03001oogoo00Eoo`80009oo`800?eoo`0077oo00<007ooOol0=goo00D007oo001oo`0000Eoo`03

001oo`0000Ioo`03001oo`0000=oo`04001oogoo0003Ool01@00Oomoo`00Ool00P000Woo00<007oo

Ool01Goo0P000Woo0P00oGoo000LOol00`00Oomoo`0iOol00`00Ool00005Ool00`00Ool00006Ool0

0`00Ool00006Ool01@00Oomoogoo00000Woo00@007oo0000009oo`03001oogoo00Ioo`03001oogoo

00800?eoo`0077oo0`00>goo00<007ooOol00goo00<007oo000027oo00<007ooOol017oo00D007oo

Oomoo`00009oo`04001oo`000002Ool00`00Oomoo`06Ool00`00Oomoo`02003mOol001aoo`03001o

ogoo03]oo`03001oogoo00=oo`03001oo`0000Qoo`03001oogoo00Aoo`05001oogooOol00002Ool0

1000Ool000000Woo00<007ooOol01Woo00@007ooOol00?ioo`0077oo00<007ooOol0@Woo0P003goo

00D007ooOomoo`00009oo`04001oo`000002Ool00`00Oomoo`09Ool00`00Oomoo`3lOol001aoo`03

001oogoo049oo`8000moo`05001oogooOol00002Ool01000Ool000003Woo00<007ooOol0o7oo000L

Ool00`00Oomoo`12Ool2000?Ool01@00Oomoogoo00000Woo00@007oo000000ioo`03001oogoo0?ao

o`0077oo00<007ooOol0@goo00<007ooOol04Goo00H007ooOol007oo003oOol?Ool001aoo`03001o

ogoo04=oo`03001oogoo015oo`06001oogoo001oo`00ogoo3goo000LOol00`00Oomoo`13Ool00`00

Oomoo`0DOol00`00Oomoo`3oOol?Ool001aoo`03001oogoo05Yoo`03001oogoo0?moo`moo`0077oo

0`00FWoo00<007ooOol0ogoo3goo000LOol00`00Oomoo`1JOol00`00Oomoo`3oOol?Ool001aoo`03

001oogoo05Yoo`03001oogoo0?moo`moo`0077oo00<007ooOol0FWoo00<007ooOol0ogoo3goo000L

Ool00`00Oomoo`3oOom/Ool001aoo`03001oogoo0?moofaoo`0077oo00<007ooOol0ogooK7oo000L

Ool00`00Oomoo`3oOom/Ool001aoo`03001oogoo0?moofaoo`0077oo00<007ooOol0ogooK7oo003o

Oon;Ool00?mooh]oo`00ogooRgoo003oOon;Ool00?mooh]oo`00\

\>"],

  ImageRangeCache->{{{0, 393}, {242.375, 0}} -> {-41.2931, -1.36777, 1.44045, 

  0.0112679}}]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{



Cell["The first smooth is grossly oversmoothed", "Subsubtitle"],



Cell[BoxData[

    \(LinkObject::"linkw" \( : \ \) 

      "\!\(LinkObject[\(\"psrender\", 3, 2\)]\) is closed; attempt to write \

failed."\)], "Message"],



Cell[BoxData[

    \(LinkObject::"linkw" \( : \ \) 

      "\!\(LinkObject[\(\"psrender\", 3, 2\)]\) is closed; attempt to write \

failed."\)], "Message"],



Cell[BoxData[

    \(LinkObject::"linkd" \( : \ \) 

      "\!\(LinkObject[\(\"psrender\", 3, 2\)]\) is closed; the connection is \

dead."\)], "Message"],



Cell[BoxData[

    \(LinkObject::"linkx" \( : \ \) 

      "Argument \!\(LinkObject[\(\"psrender\", 3, 2\)]\) in \

\!\(LinkClose[\(LinkObject[\(\"psrender\", 3, 2\)]\)]\) is not an open \

LinkObject."\)], "Message"],



Cell[BoxData[

    \(LinkObject::"linkd" \( : \ \) 

      "\!\(LinkObject[\(\"psrender\", 4, 2\)]\) is closed; the connection is \

dead."\)], "Message"],



Cell["Note the sparsity of the wavelet coefficient vector.", "Text"],



Cell[CellGroupData[{



Cell[BoxData[

    \(wdata\  = \ DWT[data]\)], "Input"],



Cell[BoxData[

    \({0.171911670088211838`, \(-0.25614074089561658`\), 

      \(-0.0793619007060381242`\), \(-0.0470769966446703058`\), 

      \(-0.0780107648931375052`\), \(-0.0373743626972768971`\), 

      0.0821345747086510691`, \(-0.132698922904856853`\), 

      \(-0.0777928136292105776`\), \(-0.140464917681613687`\), 

      \(-0.0157216417965877619`\), 0.0836534038218103503`, 

      \(-0.196194487488941398`\), \(-0.0223064798957071364`\), 

      \(-0.125360730684310306`\), 0.0162666000010075473`, 

      \(-0.0558245329442096949`\), 0.0452008499025348164`, 

      \(-0.146359682082971298`\), \(-0.184009593658434447`\), 

      \(-0.0768732124413392892`\), \(-0.0517963846484016343`\), 

      0.284209717113691304`, \(-0.143577350851867358`\), 

      0.118792687820548636`, 0.224298683555051603`, 

      \(-0.117304708899407583`\), \(-0.153342183061275294`\), 

      \(-0.0692124801850219029`\), 0.147371282842799367`, 

      0.0696059580474532335`, \(-0.0296113844430577763`\), 

      \(-0.214406236058678478`\), \(-0.33858913541305724`\), 

      \(-0.152167687168351939`\), 0.151556381740074241`, 

      0.0757318992475296504`, \(-0.0794751773567155517`\), 

      \(-0.167117361540501825`\), \(-0.286150691593270956`\), 

      0.249324368779487937`, \(-0.0861487486291145998`\), 

      \(-0.179867446275392861`\), \(-0.0624184984958472455`\), 

      0.0288125301532572422`, \(-0.0829506893416472834`\), 

      \(-0.177979431056557118`\), 0.113804996134886926`, 

      \(-0.258784562095307757`\), 0.188378089210955899`, 

      0.257158206100665864`, 0.116424354576729172`, 0.00346249136422405179`, 

      \(-0.155169310531764859`\), 0.17932576061880578`, 

      0.256985659626580043`, \(-0.206667521799225895`\), 

      \(-0.0170526610502368392`\), \(-0.0319298984328729718`\), 

      0.219649690196665581`, \(-0.129547170841072034`\), 

      \(-0.324930918420444747`\), \(-0.0356002043278522695`\), 

      \(-0.0900477148348299749`\), \(-0.041104789769068617`\), 

      \(-0.290268920538280674`\), 0.131491789614300857`, 

      \(-0.195125182627955418`\), \(-0.0166101569412149263`\), 

      0.174473439068759113`, 0.014521566197664204`, 

      \(-0.0457646909781471755`\), 0.143690387086411464`, 

      \(-0.0745551953015212198`\), \(-0.17422041231149099`\), 

      0.0157452998866279836`, \(-0.132652600968735989`\), 

      \(-0.0468661862811939933`\), 0.0902915408305635658`, 

      \(-0.204202828102619582`\), 0.108201631720608148`, 

      \(-0.0236153578559415988`\), \(-0.258159129647740925`\), 

      0.024069172677995021`, \(-0.0461717988914494004`\), 

      0.100951903307284096`, \(-0.22297543578737522`\), 

      0.0879362272839294156`, \(-0.0873945727012971396`\), 

      0.137927550060928938`, \(-0.174365985122960527`\), 

      \(-0.00790989202893566112`\), 0.0746897699700181938`, 

      0.0195981067180212029`, \(-0.0166255501951151352`\), 

      \(-0.000208282291594807933`\), \(-0.319563083082066823`\), 

      \(-0.0965375285723684761`\), 0.261764214020989616`, 

      0.17405102873594358`, 0.000746718822688841044`, 

      \(-0.312121757470420035`\), \(-0.17296889787937653`\), 

      0.0549736522394950721`, 0.11168379556828416`, 0.0413180769615764642`, 

      0.13440175626046491`, 0.0477649789669269164`, 0.106792519768464821`, 

      \(-0.202731204447898383`\), \(-0.148317335270178212`\), 

      \(-0.0164438115689831976`\), \(-0.142152438081021914`\), 

      \(-0.0508414069887754305`\), 0.0379686821513395855`, 

      \(-0.0985489604566686594`\), 0.287213875540344822`, 

      \(-0.132386382246478628`\), 0.160393325192441338`, 

      \(-0.172474171195011205`\), \(-0.292184035497268013`\), 

      0.0381122630947128939`, 0.217623868681075016`, 0.0625704203922268753`, 

      0.014309601768802076`, 0.121565981735404804`, 0.338111021561882196`, 

      \(-0.125164129492986186`\), \(-0.294329302246767365`\), 

      0.0155968026565243427`, \(-0.0927521238805573311`\), 

      0.196525579725144616`, \(-0.145634472933162406`\), 

      0.166927610588532404`, \(-0.00116849784047304283`\), 

      0.112910660558988684`, \(-0.0069127643551110367`\), 

      \(-0.0000832804684493607183`\), 0.0171031873612560891`, 

      0.133650809280898896`, \(-0.0335597253811086648`\), 

      \(-0.226952149949038517`\), 0.0677205424008557699`, 

      \(-0.0614204223329542475`\), 0.22182958248705491`, 

      \(-0.219907920125736922`\), \(-0.122154735835635297`\), 

      0.0290907857811004699`, \(-0.106935627492945717`\), 

      0.0374257749211306922`, 0.237706678573902774`, 0.265455918615160957`, 

      0.279324530143822036`, 0.146838514052987934`, 

      \(-0.134044666039314974`\), \(-0.137473578185286005`\), 

      0.00541144629672801791`, \(-0.263479973866158578`\), 

      \(-0.218445964610414655`\), 0.0684215012970322256`, 

      \(-0.104178321163271814`\), \(-0.315336919192244602`\), 

      0.0187735154453550485`, \(-0.220254222922122044`\), 

      \(-0.253689898341622921`\), \(-0.00680647084009800007`\), 

      0.240508737385130544`, \(-0.21642197654352917`\), 

      \(-0.112131959046565032`\), 0.0532381621089476642`, 

      \(-0.241206918615270371`\), \(-0.00930220487829425124`\), 

      0.222251052771303658`, \(-0.041950740613739601`\), 

      0.20888379511084123`, 0.183544805685047727`, 0.11409353465041172`, 

      0.195253360805792368`, 0.231866171796356379`, 0.062672982390271521`, 

      \(-0.00518391379339844249`\), 0.0136238434256586993`, 

      \(-0.113526208750590607`\), 0.0267429672347291313`, 

      0.0214034907428805043`, 0.0721293272736588342`, 0.169314893915517465`, 

      \(-0.108369435199904273`\), 0.0580698031753389365`, 

      0.0525797234004574676`, \(-0.171348150641629342`\), 

      \(-0.00784742655888404083`\), 0.189431247822035135`, 

      \(-0.0196341443426010222`\), \(-0.0489648834295492996`\), 

      \(-0.0449531185209612882`\), \(-0.0691522964109616555`\), 

      \(-0.116075015847824425`\), \(-0.237669015032485031`\), 

      \(-0.00711714079767944429`\), 0.0581929223377745152`, 

      \(-0.0595288320475918553`\), \(-0.124054704481388999`\), 

      0.301619204751246616`, 0.0396044167161631044`, 

      \(-0.0329730253865970768`\), 0.0876867593253855481`, 

      0.010888526990471381`, 0.155539121787517897`, 

      \(-0.228097366477140983`\), 0.0379405508041402717`, 

      \(-0.222900065235251076`\), \(-0.0223766987830633645`\), 

      \(-0.16569876851542709`\), \(-0.254404726280805348`\), 

      \(-0.116494206536673527`\), 0.0566159854789635197`, 

      0.266907072947391865`, \(-0.0343909022553225973`\), 

      0.252505425556130935`, 0.159919370330120607`, 0.123156760548983168`, 

      0.117899878745580832`, \(-0.0117593484774185519`\), 

      \(-0.217720871879502553`\), \(-0.204236627581776142`\), 

      0.0318853836788950406`, 0.26083957554920305`, 

      \(-0.0298719244937440961`\), \(-0.0113756518460279565`\), 

      \(-0.000952811006668941118`\), \(-0.269513204489864044`\), 

      \(-0.166661254161194367`\), \(-0.0450591058856757431`\), 

      0.0628998471894330357`, \(-0.0395383771220129975`\), 

      \(-0.0793137425435456222`\), 0.158178571853683269`, 

      \(-0.117853485204787578`\), \(-0.1094460347171053`\), 

      \(-0.0948931767228888212`\), \(-0.105104420574138401`\), 

      \(-0.101092588069204047`\), \(-0.196410705449149709`\), 

      0.0581930677279748387`, \(-0.158832254735240852`\), 

      \(-0.0122879853740200939`\), \(-0.126971067631622469`\), 

      0.0592572074974964735`, 0.0605485212661421723`, 

      \(-0.184379876205881423`\), \(-0.191573180338556703`\), 

      \(-0.0975733850829710291`\), \(-0.0946229141188201694`\), 

      \(-0.00469750836491260326`\), \(-0.260039918171158301`\), 

      0.0391501903412199414`, \(-0.225467025760705874`\), 

      \(-0.00784930426022806315`\), \(-0.116950081780751879`\), 

      \(-0.111980487890952384`\), \(-0.102396293821903716`\), 

      0.0842576599299551531`, \(-0.214363192395432777`\), 

      0.269564241407686733`, 0.112816090241555411`, 

      \(-0.298620926185261303`\), 0.0306950067670200255`, 

      \(-0.0762502679734751165`\), 0.115872712121779408`, 

      0.0745692395437193056`, \(-0.309432729026382613`\), 

      \(-0.0313932896912846315`\), \(-0.0820158092255366355`\), 

      0.225008927187337226`, 0.0906589807010751513`, 

      \(-0.00159468273500984469`\), 0.0409890361972536965`, 

      \(-0.19359067966621879`\), \(-0.126633391086626079`\), 

      0.134249923284112893`, 0.0304679331709146739`, 

      \(-0.230044029997284127`\), \(-0.0320941826184348855`\), 

      0.151507557301503563`, 0.0192482495502421802`, 

      \(-0.122776708372956511`\), \(-0.159883281244696417`\), 

      \(-0.185325502945462119`\), \(-0.157551967161421835`\), 

      \(-0.312204157616997068`\), 0.166586549055717458`, 

      0.038590527354885328`, \(-0.0511087461965208333`\), 

      \(-0.114176628431536308`\), 0.0461672526892106205`, 

      0.112341897440063953`, 0.20089484344145605`, 

      \(-0.0813995624268274475`\), 0.227146763777652882`, 

      \(-0.150115487043188222`\), 0.0633812972651398531`, 

      0.211783071560933588`, 0.272685652147408674`, 0.116907969866424821`, 

      \(-0.0964215984954208593`\), 0.0684722372531918477`, 

      0.0207948396466332008`, 0.0756033866276600896`, 0.320357101243269504`, 

      0.221694233398880236`, 0.0871227151265013333`, 0.28837335306916092`, 

      \(-0.212030133551835442`\), \(-0.0166228138795853075`\), 

      0.184599527819533477`, 0.235001487237335071`, 

      \(-0.0795615168620847335`\), \(-0.0949659890136252471`\), 

      0.140386861300402205`, \(-0.0693699586807580104`\), 

      0.019891625485097041`, 0.0589345125705238981`, 

      \(-0.0873342589110369615`\), 0.0318685521401382398`, 

      0.16572723463129777`, 0.259293049218976889`, 0.0134893018199739311`, 

      \(-0.0215233402934416595`\), 0.0895091515644790192`, 

      0.0810581037421094841`, \(-0.0615887700195659704`\), 

      \(-0.048194204428002596`\), \(-0.0394432939477986632`\), 

      0.00381927751601629505`, \(-0.0645039957199156077`\), 

      0.125019387388138003`, 0.206535670174936214`, 0.0239554061635400827`, 

      0.0818759344758209728`, \(-0.154258919147829747`\), 

      0.177094086666205523`, 0.0680477048328244116`, 

      \(-0.123429444696167789`\), 0.116722907582215817`, 

      0.0479699825185178063`, \(-0.0356644524304435828`\), 

      0.048302577327247631`, 0.240243812240703569`, 0.122565955774758816`, 

      \(-0.236381917168371114`\), 0.222286740013936245`, 

      0.0134374441424297552`, 0.219455513649576827`, 

      \(-0.0176436654370550893`\), \(-0.138248577434770814`\), 

      0.348906069807388474`, 0.126201884589555279`, 0.111157825627603012`, 

      0.388910398018701108`, 0.152583576321899787`, 0.0356926586995618411`, 

      0.180490467405570278`, 0.0468510028080555418`, 

      \(-0.072867943567169302`\), 0.0285576214165905728`, 

      \(-0.134769626641166762`\), 0.0677402906313403541`, 

      \(-0.125572932066418729`\), 0.0637588697097186685`, 

      0.121848464571463366`, 0.0775869434962915249`, 

      \(-0.0542350484045021019`\), \(-0.389414705798860882`\), 

      \(-0.0320868757544772176`\), \(-0.114852628696395742`\), 

      \(-0.256423968463710849`\), \(-0.104402264985638248`\), 

      \(-0.0711779228810473529`\), \(-0.203342660024574595`\), 

      0.056648022913221121`, 0.148940940582534731`, 

      \(-0.117603971871374368`\), 0.21347557635207206`, 

      \(-0.124223968780779236`\), 0.117938021319283148`, 

      0.053788519612580572`, \(-0.0252645033141969932`\), 

      \(-0.0476276856845699825`\), \(-0.0311602991193751233`\), 

      \(-0.0529836765419785571`\), 0.0876118125944305248`, 

      \(-0.0859978042740245918`\), \(-0.127019963262005486`\), 

      \(-0.238546642415512488`\), \(-0.00622719350687561679`\), 

      \(-0.00907756353540478677`\), \(-0.0904490838888563075`\), 

      0.0844075357896054612`, \(-0.0296723611899774031`\), 

      \(-0.0275709476762651117`\), \(-0.0578695179789068259`\), 

      \(-0.190980258466665766`\), \(-0.0501761369095570231`\), 

      0.173160774349475188`, 0.266337890294203072`, 

      \(-0.0814404424130787951`\), 0.0572942497968156327`, 

      \(-0.0156955732846859596`\), 0.129924101745376274`, 

      \(-0.0321284764572612457`\), 0.227321685408349516`, 

      0.0267711632455862602`, 0.0238923151746189832`, 

      \(-0.237426805046807132`\), 0.119271706558914702`, 

      0.297412802622826255`, 0.036954523326896691`, 0.150934945228255301`, 

      0.0897400821668292181`, \(-0.0736155541591766393`\), 

      0.23655725113480388`, 0.133017332306733071`, 0.0800157782116376381`, 

      \(-0.00833858319832803118`\), \(-0.0150826192958510851`\), 

      0.235985508682540867`, \(-0.189834812593457016`\), 

      0.0171870667860316572`, 0.112829959095995802`, 

      \(-0.105896346799358553`\), \(-0.0427095690598087163`\), 

      0.0897650960418081567`, \(-0.348003486722258781`\), 

      \(-0.0782383889855540193`\), \(-0.0122582918876152913`\), 

      \(-0.10946716392111111`\), 0.0546215546951127617`, 

      \(-0.06525548925871405`\), \(-0.102281092920806671`\), 

      \(-0.225214817069080552`\), \(-0.368561590551659801`\), 

      \(-0.180228936529403185`\), \(-0.278817762676796077`\), 

      \(-0.161403112416221521`\), \(-0.0423759858412079459`\), 

      0.0325155933809684061`, \(-0.169834921670472693`\), 

      \(-0.0808965840344730224`\), \(-0.344657084778752897`\), 

      \(-0.18070064313548805`\), \(-0.333104964488687871`\), 

      \(-0.079773005985841916`\), 0.00856531944330396477`, 

      0.0106963190483770897`, 0.0127346351581680838`, 

      \(-0.01267221588617784`\), \(-0.0392726866647088446`\), 

      \(-0.110127269518608184`\), 0.263749701596395436`, 

      0.0883643354835275118`, 0.112791766118340075`, 0.188983668455821263`, 

      0.280390394069107493`, 0.356480086383749039`, 0.371117789789589247`, 

      0.0702041593983426803`, 0.073825289588818288`, 0.324806688867969928`, 

      0.190301564798150977`, 0.0388929815155496516`, 0.079993789193357756`, 

      0.16527369020204996`, 0.0544187396022006719`, 

      \(-0.0447094089864632504`\), \(-0.122834527461146647`\), 

      0.027600357983064816`, \(-0.212889550554411854`\), 

      0.126288647196363124`, \(-0.222943606676942973`\), 

      \(-0.534516294113836565`\), \(-0.47686153779546414`\), 

      \(-0.266544297936520901`\), \(-0.133252684019121048`\), 

      \(-0.0187737786773656267`\), 0.3322888477090018`, 

      0.547650744817865309`, 0.678934638621480157`, 0.0449824974432817015`, 

      0.436285994923801823`, 0.412345206384248985`, 0.153230332960369253`, 

      \(-0.160243443052081602`\), \(-0.232576654880354283`\), 

      \(-0.441454388080352533`\), \(-0.798038502988777764`\), 

      \(-1.45421820618545734`\), \(-0.561084170775530299`\), 

      0.535862716199049238`, 1.31116388391977012`, 1.51023152905274677`, 

      0.781968859033122409`, \(-0.697679194034670935`\), 

      \(-1.42410652141746618`\), \(-2.98855380960470782`\), 

      2.9118878941551781`, 3.15314664507648156`, \(-2.78857863398421423`\), 

      \(-0.0453691282726875755`\), 0.0233719222608215204`, 

      14.1601911688808694`, \(-0.234307118826117211`\)}\)], "Output"]

}, Closed]],



Cell[CellGroupData[{



Cell[BoxData[

    \(swdata\  = \ thresh[wdata, 10]\)], "Input"],



Cell[BoxData[

    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 14.1601911688808694`, 0}\)], "Output",

  FontSize->12]

}, Open  ]],



Cell[BoxData[

    \(\(sdata\  = \ IDWT[swdata]; \)\)], "Input"],



Cell[CellGroupData[{



Cell[BoxData[

    \(Plot2Lists[udata, sdata]\)], "Input"],



Cell[GraphicsData["PostScript", "\<\



%!



%%Creator: Mathematica



%%AspectRatio: .61803 



MathPictureStart



/Mabs {



Mgmatrix idtransform



Mtmatrix dtransform



} bind def



/Mabsadd { Mabs



3 -1 roll add



3 1 roll add



exch } bind def



%% Graphics



%%IncludeResource: font Courier



%%IncludeFont: Courier



/Courier findfont 10  scalefont  setfont



% Scaling calculations



0.0238095 0.00186012 0.309017 0.294302 [



[.20982 .29652 -9 -9 ]



[.20982 .29652 9 0 ]



[.39583 .29652 -9 -9 ]



[.39583 .29652 9 0 ]



[.58185 .29652 -9 -9 ]



[.58185 .29652 9 0 ]



[.76786 .29652 -9 -9 ]



[.76786 .29652 9 0 ]



[.95387 .29652 -9 -9 ]



[.95387 .29652 9 0 ]



[.01131 .01472 -12 -4.5 ]



[.01131 .01472 0 4.5 ]



[.01131 .16187 -24 -4.5 ]



[.01131 .16187 0 4.5 ]



[.01131 .45617 -18 -4.5 ]



[.01131 .45617 0 4.5 ]



[.01131 .60332 -6 -4.5 ]



[.01131 .60332 0 4.5 ]



[ 0 0 0 0 ]



[ 1 .61803 0 0 ]



] MathScale



% Start of Graphics



1 setlinecap



1 setlinejoin



newpath



0 g



.25 Mabswid



.20982 .30902 m



.20982 .31527 L



s



[(100)] .20982 .29652 0 1 Mshowa



.39583 .30902 m



.39583 .31527 L



s



[(200)] .39583 .29652 0 1 Mshowa



.58185 .30902 m



.58185 .31527 L



s



[(300)] .58185 .29652 0 1 Mshowa



.76786 .30902 m



.76786 .31527 L



s



[(400)] .76786 .29652 0 1 Mshowa



.95387 .30902 m



.95387 .31527 L



s



[(500)] .95387 .29652 0 1 Mshowa



.125 Mabswid



.06101 .30902 m



.06101 .31277 L



s



.09821 .30902 m



.09821 .31277 L



s



.13542 .30902 m



.13542 .31277 L



s



.17262 .30902 m



.17262 .31277 L



s



.24702 .30902 m



.24702 .31277 L



s



.28423 .30902 m



.28423 .31277 L



s



.32143 .30902 m



.32143 .31277 L



s



.35863 .30902 m



.35863 .31277 L



s



.43304 .30902 m



.43304 .31277 L



s



.47024 .30902 m



.47024 .31277 L



s



.50744 .30902 m



.50744 .31277 L



s



.54464 .30902 m



.54464 .31277 L



s



.61905 .30902 m



.61905 .31277 L



s



.65625 .30902 m



.65625 .31277 L



s



.69345 .30902 m



.69345 .31277 L



s



.73065 .30902 m



.73065 .31277 L



s



.80506 .30902 m



.80506 .31277 L



s



.84226 .30902 m



.84226 .31277 L



s



.87946 .30902 m



.87946 .31277 L



s



.91667 .30902 m



.91667 .31277 L



s



.99107 .30902 m



.99107 .31277 L



s



.25 Mabswid



0 .30902 m



1 .30902 L



s



.02381 .01472 m



.03006 .01472 L



s



[(-1)] .01131 .01472 1 0 Mshowa



.02381 .16187 m



.03006 .16187 L



s



[(-0.5)] .01131 .16187 1 0 Mshowa



.02381 .45617 m



.03006 .45617 L



s



[(0.5)] .01131 .45617 1 0 Mshowa



.02381 .60332 m



.03006 .60332 L



s



[(1)] .01131 .60332 1 0 Mshowa



.125 Mabswid



.02381 .04415 m



.02756 .04415 L



s



.02381 .07358 m



.02756 .07358 L



s



.02381 .10301 m



.02756 .10301 L



s



.02381 .13244 m



.02756 .13244 L



s



.02381 .1913 m



.02756 .1913 L



s



.02381 .22073 m



.02756 .22073 L



s



.02381 .25016 m



.02756 .25016 L



s



.02381 .27959 m



.02756 .27959 L



s



.02381 .33845 m



.02756 .33845 L



s



.02381 .36788 m



.02756 .36788 L



s



.02381 .39731 m



.02756 .39731 L



s



.02381 .42674 m



.02756 .42674 L



s



.02381 .4856 m



.02756 .4856 L



s



.02381 .51503 m



.02756 .51503 L



s



.02381 .54446 m



.02756 .54446 L



s



.02381 .57389 m



.02756 .57389 L



s



.25 Mabswid



.02381 0 m



.02381 .61803 L



s



0 0 m



1 0 L



1 .61803 L



0 .61803 L



closepath



clip



newpath



1 0 0 r



.5 Mabswid



.02567 .30902 m



.02753 .31263 L



.02939 .31624 L



.03125 .31985 L



.03311 .32346 L



.03497 .32706 L



.03683 .33067 L



.03869 .33427 L



.04055 .33786 L



.04241 .34146 L



.04427 .34504 L



.04613 .34862 L



.04799 .3522 L



.04985 .35577 L



.05171 .35933 L



.05357 .36289 L



.05543 .36643 L



.05729 .36997 L



.05915 .3735 L



.06101 .37702 L



.06287 .38053 L



.06473 .38402 L



.06659 .38751 L



.06845 .39099 L



.07031 .39445 L



.07217 .3979 L



.07403 .40133 L



.07589 .40476 L



.07775 .40816 L



.07961 .41156 L



.08147 .41493 L



.08333 .4183 L



.08519 .42164 L



.08705 .42497 L



.08891 .42828 L



.09077 .43157 L



.09263 .43485 L



.09449 .4381 L



.09635 .44134 L



.09821 .44455 L



.10007 .44775 L



.10193 .45092 L



.10379 .45408 L



.10565 .45721 L



.10751 .46032 L



.10937 .4634 L



.11124 .46647 L



.1131 .46951 L



.11496 .47252 L



.11682 .47551 L



Mistroke



.11868 .47848 L



.12054 .48142 L



.1224 .48433 L



.12426 .48722 L



.12612 .49008 L



.12798 .49291 L



.12984 .49572 L



.1317 .4985 L



.13356 .50125 L



.13542 .50397 L



.13728 .50666 L



.13914 .50932 L



.141 .51195 L



.14286 .51455 L



.14472 .51712 L



.14658 .51966 L



.14844 .52216 L



.1503 .52464 L



.15216 .52708 L



.15402 .52949 L



.15588 .53186 L



.15774 .53421 L



.1596 .53652 L



.16146 .53879 L



.16332 .54103 L



.16518 .54323 L



.16704 .5454 L



.1689 .54754 L



.17076 .54963 L



.17262 .5517 L



.17448 .55372 L



.17634 .55571 L



.1782 .55766 L



.18006 .55957 L



.18192 .56145 L



.18378 .56329 L



.18564 .56509 L



.1875 .56685 L



.18936 .56857 L



.19122 .57025 L



.19308 .57189 L



.19494 .5735 L



.1968 .57506 L



.19866 .57659 L



.20052 .57807 L



.20238 .57951 L



.20424 .58092 L



.2061 .58228 L



.20796 .5836 L



.20982 .58488 L



Mistroke



.21168 .58612 L



.21354 .58731 L



.2154 .58846 L



.21726 .58958 L



.21912 .59065 L



.22098 .59167 L



.22284 .59266 L



.2247 .5936 L



.22656 .5945 L



.22842 .59536 L



.23028 .59617 L



.23214 .59694 L



.234 .59766 L



.23586 .59835 L



.23772 .59899 L



.23958 .59958 L



.24144 .60013 L



.2433 .60064 L



.24516 .60111 L



.24702 .60153 L



.24888 .6019 L



.25074 .60223 L



.2526 .60252 L



.25446 .60277 L



.25632 .60296 L



.25818 .60312 L



.26004 .60323 L



.2619 .6033 L



.26376 .60332 L



.26563 .6033 L



.26749 .60323 L



.26935 .60312 L



.27121 .60296 L



.27307 .60277 L



.27493 .60252 L



.27679 .60223 L



.27865 .6019 L



.28051 .60153 L



.28237 .60111 L



.28423 .60064 L



.28609 .60013 L



.28795 .59958 L



.28981 .59899 L



.29167 .59835 L



.29353 .59766 L



.29539 .59694 L



.29725 .59617 L



.29911 .59536 L



.30097 .5945 L



.30283 .5936 L



Mistroke



.30469 .59266 L



.30655 .59167 L



.30841 .59065 L



.31027 .58958 L



.31213 .58846 L



.31399 .58731 L



.31585 .58612 L



.31771 .58488 L



.31957 .5836 L



.32143 .58228 L



.32329 .58092 L



.32515 .57951 L



.32701 .57807 L



.32887 .57659 L



.33073 .57506 L



.33259 .5735 L



.33445 .57189 L



.33631 .57025 L



.33817 .56857 L



.34003 .56685 L



.34189 .56509 L



.34375 .56329 L



.34561 .56145 L



.34747 .55957 L



.34933 .55766 L



.35119 .55571 L



.35305 .55372 L



.35491 .5517 L



.35677 .54963 L



.35863 .54754 L



.36049 .5454 L



.36235 .54323 L



.36421 .54103 L



.36607 .53879 L



.36793 .53652 L



.36979 .53421 L



.37165 .53186 L



.37351 .52949 L



.37537 .52708 L



.37723 .52464 L



.37909 .52216 L



.38095 .51966 L



.38281 .51712 L



.38467 .51455 L



.38653 .51195 L



.38839 .50932 L



.39025 .50666 L



.39211 .50397 L



.39397 .50125 L



.39583 .4985 L



Mistroke



.39769 .49572 L



.39955 .49291 L



.40141 .49008 L



.40327 .48722 L



.40513 .48433 L



.40699 .48142 L



.40885 .47848 L



.41071 .47551 L



.41257 .47252 L



.41443 .46951 L



.41629 .46647 L



.41815 .4634 L



.42001 .46032 L



.42188 .45721 L



.42374 .45408 L



.4256 .45092 L



.42746 .44775 L



.42932 .44455 L



.43118 .44134 L



.43304 .4381 L



.4349 .43485 L



.43676 .43157 L



.43862 .42828 L



.44048 .42497 L



.44234 .42164 L



.4442 .4183 L



.44606 .41493 L



.44792 .41156 L



.44978 .40816 L



.45164 .40476 L



.4535 .40133 L



.45536 .3979 L



.45722 .39445 L



.45908 .39099 L



.46094 .38751 L



.4628 .38402 L



.46466 .38053 L



.46652 .37702 L



.46838 .3735 L



.47024 .36997 L



.4721 .36643 L



.47396 .36289 L



.47582 .35933 L



.47768 .35577 L



.47954 .3522 L



.4814 .34862 L



.48326 .34504 L



.48512 .34146 L



.48698 .33786 L



.48884 .33427 L



Mistroke



.4907 .33067 L



.49256 .32706 L



.49442 .32346 L



.49628 .31985 L



.49814 .31624 L



.5 .31263 L



.50186 .30902 L



.50372 .30541 L



.50558 .30179 L



.50744 .29818 L



.5093 .29458 L



.51116 .29097 L



.51302 .28737 L



.51488 .28377 L



.51674 .28017 L



.5186 .27658 L



.52046 .27299 L



.52232 .26941 L



.52418 .26583 L



.52604 .26226 L



.5279 .2587 L



.52976 .25515 L



.53162 .2516 L



.53348 .24806 L



.53534 .24454 L



.5372 .24102 L



.53906 .23751 L



.54092 .23401 L



.54278 .23052 L



.54464 .22705 L



.5465 .22359 L



.54836 .22014 L



.55022 .2167 L



.55208 .21328 L



.55394 .20987 L



.5558 .20648 L



.55766 .2031 L



.55952 .19974 L



.56138 .19639 L



.56324 .19306 L



.5651 .18975 L



.56696 .18646 L



.56882 .18319 L



.57068 .17993 L



.57254 .1767 L



.5744 .17348 L



.57626 .17028 L



.57813 .16711 L



.57999 .16396 L



.58185 .16082 L



Mistroke



.58371 .15772 L



.58557 .15463 L



.58743 .15157 L



.58929 .14853 L



.59115 .14551 L



.59301 .14252 L



.59487 .13956 L



.59673 .13662 L



.59859 .1337 L



.60045 .13081 L



.60231 .12795 L



.60417 .12512 L



.60603 .12231 L



.60789 .11954 L



.60975 .11679 L



.61161 .11407 L



.61347 .11138 L



.61533 .10871 L



.61719 .10608 L



.61905 .10348 L



.62091 .10091 L



.62277 .09838 L



.62463 .09587 L



.62649 .0934 L



.62835 .09095 L



.63021 .08854 L



.63207 .08617 L



.63393 .08383 L



.63579 .08152 L



.63765 .07924 L



.63951 .07701 L



.64137 .0748 L



.64323 .07263 L



.64509 .0705 L



.64695 .0684 L



.64881 .06634 L



.65067 .06431 L



.65253 .06233 L



.65439 .06037 L



.65625 .05846 L



.65811 .05659 L



.65997 .05475 L



.66183 .05295 L



.66369 .05119 L



.66555 .04947 L



.66741 .04778 L



.66927 .04614 L



.67113 .04454 L



.67299 .04297 L



.67485 .04145 L



Mistroke



.67671 .03996 L



.67857 .03852 L



.68043 .03712 L



.68229 .03576 L



.68415 .03444 L



.68601 .03316 L



.68787 .03192 L



.68973 .03072 L



.69159 .02957 L



.69345 .02846 L



.69531 .02739 L



.69717 .02636 L



.69903 .02538 L



.70089 .02443 L



.70275 .02353 L



.70461 .02268 L



.70647 .02187 L



.70833 .0211 L



.71019 .02037 L



.71205 .01969 L



.71391 .01905 L



.71577 .01845 L



.71763 .0179 L



.71949 .01739 L



.72135 .01693 L



.72321 .01651 L



.72507 .01613 L



.72693 .0158 L



.72879 .01551 L



.73065 .01527 L



.73251 .01507 L



.73438 .01491 L



.73624 .0148 L



.7381 .01474 L



.73996 .01472 L



.74182 .01474 L



.74368 .0148 L



.74554 .01491 L



.7474 .01507 L



.74926 .01527 L



.75112 .01551 L



.75298 .0158 L



.75484 .01613 L



.7567 .01651 L



.75856 .01693 L



.76042 .01739 L



.76228 .0179 L



.76414 .01845 L



.766 .01905 L



.76786 .01969 L



Mistroke



.76972 .02037 L



.77158 .0211 L



.77344 .02187 L



.7753 .02268 L



.77716 .02353 L



.77902 .02443 L



.78088 .02538 L



.78274 .02636 L



.7846 .02739 L



.78646 .02846 L



.78832 .02957 L



.79018 .03072 L



.79204 .03192 L



.7939 .03316 L



.79576 .03444 L



.79762 .03576 L



.79948 .03712 L



.80134 .03852 L



.8032 .03996 L



.80506 .04145 L



.80692 .04297 L



.80878 .04454 L



.81064 .04614 L



.8125 .04778 L



.81436 .04947 L



.81622 .05119 L



.81808 .05295 L



.81994 .05475 L



.8218 .05659 L



.82366 .05846 L



.82552 .06037 L



.82738 .06233 L



.82924 .06431 L



.8311 .06634 L



.83296 .0684 L



.83482 .0705 L



.83668 .07263 L



.83854 .0748 L



.8404 .07701 L



.84226 .07924 L



.84412 .08152 L



.84598 .08383 L



.84784 .08617 L



.8497 .08854 L



.85156 .09095 L



.85342 .0934 L



.85528 .09587 L



.85714 .09838 L



.859 .10091 L



.86086 .10348 L



Mistroke



.86272 .10608 L



.86458 .10871 L



.86644 .11138 L



.8683 .11407 L



.87016 .11679 L



.87202 .11954 L



.87388 .12231 L



.87574 .12512 L



.8776 .12795 L



.87946 .13081 L



.88132 .1337 L



.88318 .13662 L



.88504 .13956 L



.8869 .14252 L



.88876 .14551 L



.89063 .14853 L



.89249 .15157 L



.89435 .15463 L



.89621 .15772 L



.89807 .16082 L



.89993 .16396 L



.90179 .16711 L



.90365 .17028 L



.90551 .17348 L



.90737 .1767 L



.90923 .17993 L



.91109 .18319 L



.91295 .18646 L



.91481 .18975 L



.91667 .19306 L



.91853 .19639 L



.92039 .19974 L



.92225 .2031 L



.92411 .20648 L



.92597 .20987 L



.92783 .21328 L



.92969 .2167 L



.93155 .22014 L



.93341 .22359 L



.93527 .22705 L



.93713 .23052 L



.93899 .23401 L



.94085 .23751 L



.94271 .24102 L



.94457 .24454 L



.94643 .24806 L



.94829 .2516 L



.95015 .25515 L



.95201 .2587 L



.95387 .26226 L



Mistroke



.95573 .26583 L



.95759 .26941 L



.95945 .27299 L



.96131 .27658 L



.96317 .28017 L



.96503 .28377 L



.96689 .28737 L



.96875 .29097 L



.97061 .29458 L



.97247 .29818 L



.97433 .30179 L



.97619 .30541 L



Mfstroke



0 0 1 r



.02567 .49319 m



.02753 .49319 L



.02939 .49319 L



.03125 .49319 L



.03311 .49319 L



.03497 .49319 L



.03683 .49319 L



.03869 .49319 L



.04055 .49319 L



.04241 .49319 L



.04427 .49319 L



.04613 .49319 L



.04799 .49319 L



.04985 .49319 L



.05171 .49319 L



.05357 .49319 L



.05543 .49319 L



.05729 .49319 L



.05915 .49319 L



.06101 .49319 L



.06287 .49319 L



.06473 .49319 L



.06659 .49319 L



.06845 .49319 L



.07031 .49319 L



.07217 .49319 L



.07403 .49319 L



.07589 .49319 L



.07775 .49319 L



.07961 .49319 L



.08147 .49319 L



.08333 .49319 L



.08519 .49319 L



.08705 .49319 L



.08891 .49319 L



.09077 .49319 L



.09263 .49319 L



.09449 .49319 L



.09635 .49319 L



.09821 .49319 L



.10007 .49319 L



.10193 .49319 L



.10379 .49319 L



.10565 .49319 L



.10751 .49319 L



.10937 .49319 L



.11124 .49319 L



.1131 .49319 L



.11496 .49319 L



.11682 .49319 L



Mistroke



.11868 .49319 L



.12054 .49319 L



.1224 .49319 L



.12426 .49319 L



.12612 .49319 L



.12798 .49319 L



.12984 .49319 L



.1317 .49319 L



.13356 .49319 L



.13542 .49319 L



.13728 .49319 L



.13914 .49319 L



.141 .49319 L



.14286 .49319 L



.14472 .49319 L



.14658 .49319 L



.14844 .49319 L



.1503 .49319 L



.15216 .49319 L



.15402 .49319 L



.15588 .49319 L



.15774 .49319 L



.1596 .49319 L



.16146 .49319 L



.16332 .49319 L



.16518 .49319 L



.16704 .49319 L



.1689 .49319 L



.17076 .49319 L



.17262 .49319 L



.17448 .49319 L



.17634 .49319 L



.1782 .49319 L



.18006 .49319 L



.18192 .49319 L



.18378 .49319 L



.18564 .49319 L



.1875 .49319 L



.18936 .49319 L



.19122 .49319 L



.19308 .49319 L



.19494 .49319 L



.1968 .49319 L



.19866 .49319 L



.20052 .49319 L



.20238 .49319 L



.20424 .49319 L



.2061 .49319 L



.20796 .49319 L



.20982 .49319 L



Mistroke



.21168 .49319 L



.21354 .49319 L



.2154 .49319 L



.21726 .49319 L



.21912 .49319 L



.22098 .49319 L



.22284 .49319 L



.2247 .49319 L



.22656 .49319 L



.22842 .49319 L



.23028 .49319 L



.23214 .49319 L



.234 .49319 L



.23586 .49319 L



.23772 .49319 L



.23958 .49319 L



.24144 .49319 L



.2433 .49319 L



.24516 .49319 L



.24702 .49319 L



.24888 .49319 L



.25074 .49319 L



.2526 .49319 L



.25446 .49319 L



.25632 .49319 L



.25818 .49319 L



.26004 .49319 L



.2619 .49319 L



.26376 .49319 L



.26563 .49319 L



.26749 .49319 L



.26935 .49319 L



.27121 .49319 L



.27307 .49319 L



.27493 .49319 L



.27679 .49319 L



.27865 .49319 L



.28051 .49319 L



.28237 .49319 L



.28423 .49319 L



.28609 .49319 L



.28795 .49319 L



.28981 .49319 L



.29167 .49319 L



.29353 .49319 L



.29539 .49319 L



.29725 .49319 L



.29911 .49319 L



.30097 .49319 L



.30283 .49319 L



Mistroke



.30469 .49319 L



.30655 .49319 L



.30841 .49319 L



.31027 .49319 L



.31213 .49319 L



.31399 .49319 L



.31585 .49319 L



.31771 .49319 L



.31957 .49319 L



.32143 .49319 L



.32329 .49319 L



.32515 .49319 L



.32701 .49319 L



.32887 .49319 L



.33073 .49319 L



.33259 .49319 L



.33445 .49319 L



.33631 .49319 L



.33817 .49319 L



.34003 .49319 L



.34189 .49319 L



.34375 .49319 L



.34561 .49319 L



.34747 .49319 L



.34933 .49319 L



.35119 .49319 L



.35305 .49319 L



.35491 .49319 L



.35677 .49319 L



.35863 .49319 L



.36049 .49319 L



.36235 .49319 L



.36421 .49319 L



.36607 .49319 L



.36793 .49319 L



.36979 .49319 L



.37165 .49319 L



.37351 .49319 L



.37537 .49319 L



.37723 .49319 L



.37909 .49319 L



.38095 .49319 L



.38281 .49319 L



.38467 .49319 L



.38653 .49319 L



.38839 .49319 L



.39025 .49319 L



.39211 .49319 L



.39397 .49319 L



.39583 .49319 L



Mistroke



.39769 .49319 L



.39955 .49319 L



.40141 .49319 L



.40327 .49319 L



.40513 .49319 L



.40699 .49319 L



.40885 .49319 L



.41071 .49319 L



.41257 .49319 L



.41443 .49319 L



.41629 .49319 L



.41815 .49319 L



.42001 .49319 L



.42188 .49319 L



.42374 .49319 L



.4256 .49319 L



.42746 .49319 L



.42932 .49319 L



.43118 .49319 L



.43304 .49319 L



.4349 .49319 L



.43676 .49319 L



.43862 .49319 L



.44048 .49319 L



.44234 .49319 L



.4442 .49319 L



.44606 .49319 L



.44792 .49319 L



.44978 .49319 L



.45164 .49319 L



.4535 .49319 L



.45536 .49319 L



.45722 .49319 L



.45908 .49319 L



.46094 .49319 L



.4628 .49319 L



.46466 .49319 L



.46652 .49319 L



.46838 .49319 L



.47024 .49319 L



.4721 .49319 L



.47396 .49319 L



.47582 .49319 L



.47768 .49319 L



.47954 .49319 L



.4814 .49319 L



.48326 .49319 L



.48512 .49319 L



.48698 .49319 L



.48884 .49319 L



Mistroke



.4907 .49319 L



.49256 .49319 L



.49442 .49319 L



.49628 .49319 L



.49814 .49319 L



.5 .49319 L



.50186 .12484 L



.50372 .12484 L



.50558 .12484 L



.50744 .12484 L



.5093 .12484 L



.51116 .12484 L



.51302 .12484 L



.51488 .12484 L



.51674 .12484 L



.5186 .12484 L



.52046 .12484 L



.52232 .12484 L



.52418 .12484 L



.52604 .12484 L



.5279 .12484 L



.52976 .12484 L



.53162 .12484 L



.53348 .12484 L



.53534 .12484 L



.5372 .12484 L



.53906 .12484 L



.54092 .12484 L



.54278 .12484 L



.54464 .12484 L



.5465 .12484 L



.54836 .12484 L



.55022 .12484 L



.55208 .12484 L



.55394 .12484 L



.5558 .12484 L



.55766 .12484 L



.55952 .12484 L



.56138 .12484 L



.56324 .12484 L



.5651 .12484 L



.56696 .12484 L



.56882 .12484 L



.57068 .12484 L



.57254 .12484 L



.5744 .12484 L



.57626 .12484 L



.57813 .12484 L



.57999 .12484 L



.58185 .12484 L



Mistroke



.58371 .12484 L



.58557 .12484 L



.58743 .12484 L



.58929 .12484 L



.59115 .12484 L



.59301 .12484 L



.59487 .12484 L



.59673 .12484 L



.59859 .12484 L



.60045 .12484 L



.60231 .12484 L



.60417 .12484 L



.60603 .12484 L



.60789 .12484 L



.60975 .12484 L



.61161 .12484 L



.61347 .12484 L



.61533 .12484 L



.61719 .12484 L



.61905 .12484 L



.62091 .12484 L



.62277 .12484 L



.62463 .12484 L



.62649 .12484 L



.62835 .12484 L



.63021 .12484 L



.63207 .12484 L



.63393 .12484 L



.63579 .12484 L



.63765 .12484 L



.63951 .12484 L



.64137 .12484 L



.64323 .12484 L



.64509 .12484 L



.64695 .12484 L



.64881 .12484 L



.65067 .12484 L



.65253 .12484 L



.65439 .12484 L



.65625 .12484 L



.65811 .12484 L



.65997 .12484 L



.66183 .12484 L



.66369 .12484 L



.66555 .12484 L



.66741 .12484 L



.66927 .12484 L



.67113 .12484 L



.67299 .12484 L



.67485 .12484 L



Mistroke



.67671 .12484 L



.67857 .12484 L



.68043 .12484 L



.68229 .12484 L



.68415 .12484 L



.68601 .12484 L



.68787 .12484 L



.68973 .12484 L



.69159 .12484 L



.69345 .12484 L



.69531 .12484 L



.69717 .12484 L



.69903 .12484 L



.70089 .12484 L



.70275 .12484 L



.70461 .12484 L



.70647 .12484 L



.70833 .12484 L



.71019 .12484 L



.71205 .12484 L



.71391 .12484 L



.71577 .12484 L



.71763 .12484 L



.71949 .12484 L



.72135 .12484 L



.72321 .12484 L



.72507 .12484 L



.72693 .12484 L



.72879 .12484 L



.73065 .12484 L



.73251 .12484 L



.73438 .12484 L



.73624 .12484 L



.7381 .12484 L



.73996 .12484 L



.74182 .12484 L



.74368 .12484 L



.74554 .12484 L



.7474 .12484 L



.74926 .12484 L



.75112 .12484 L



.75298 .12484 L



.75484 .12484 L



.7567 .12484 L



.75856 .12484 L



.76042 .12484 L



.76228 .12484 L



.76414 .12484 L



.766 .12484 L



.76786 .12484 L



Mistroke



.76972 .12484 L



.77158 .12484 L



.77344 .12484 L



.7753 .12484 L



.77716 .12484 L



.77902 .12484 L



.78088 .12484 L



.78274 .12484 L



.7846 .12484 L



.78646 .12484 L



.78832 .12484 L



.79018 .12484 L



.79204 .12484 L



.7939 .12484 L



.79576 .12484 L



.79762 .12484 L



.79948 .12484 L



.80134 .12484 L



.8032 .12484 L



.80506 .12484 L



.80692 .12484 L



.80878 .12484 L



.81064 .12484 L



.8125 .12484 L



.81436 .12484 L



.81622 .12484 L



.81808 .12484 L



.81994 .12484 L



.8218 .12484 L



.82366 .12484 L



.82552 .12484 L



.82738 .12484 L



.82924 .12484 L



.8311 .12484 L



.83296 .12484 L



.83482 .12484 L



.83668 .12484 L



.83854 .12484 L



.8404 .12484 L



.84226 .12484 L



.84412 .12484 L



.84598 .12484 L



.84784 .12484 L



.8497 .12484 L



.85156 .12484 L



.85342 .12484 L



.85528 .12484 L



.85714 .12484 L



.859 .12484 L



.86086 .12484 L



Mistroke



.86272 .12484 L



.86458 .12484 L



.86644 .12484 L



.8683 .12484 L



.87016 .12484 L



.87202 .12484 L



.87388 .12484 L



.87574 .12484 L



.8776 .12484 L



.87946 .12484 L



.88132 .12484 L



.88318 .12484 L



.88504 .12484 L



.8869 .12484 L



.88876 .12484 L



.89063 .12484 L



.89249 .12484 L



.89435 .12484 L



.89621 .12484 L



.89807 .12484 L



.89993 .12484 L



.90179 .12484 L



.90365 .12484 L



.90551 .12484 L



.90737 .12484 L



.90923 .12484 L



.91109 .12484 L



.91295 .12484 L



.91481 .12484 L



.91667 .12484 L



.91853 .12484 L



.92039 .12484 L



.92225 .12484 L



.92411 .12484 L



.92597 .12484 L



.92783 .12484 L



.92969 .12484 L



.93155 .12484 L



.93341 .12484 L



.93527 .12484 L



.93713 .12484 L



.93899 .12484 L



.94085 .12484 L



.94271 .12484 L



.94457 .12484 L



.94643 .12484 L



.94829 .12484 L



.95015 .12484 L



.95201 .12484 L



.95387 .12484 L



Mistroke



.95573 .12484 L



.95759 .12484 L



.95945 .12484 L



.96131 .12484 L



.96317 .12484 L



.96503 .12484 L



.96689 .12484 L



.96875 .12484 L



.97061 .12484 L



.97247 .12484 L



.97433 .12484 L



.97619 .12484 L



Mfstroke



% End of Graphics



MathPictureEnd





\

\>"], "Graphics",

  ImageSize->{410, 253.312},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006J0000oA000`40O003h00OognLVgnL003oOibK

Oi`00?moW9]oW000ognLVgnL003oOibKOi`00?moW9]oW00077nL00<007nLOi`0ognLO7nL000LOi`0

0`00OiaoW03oOialOi`001aoW003001oW7nL0?moW7aoW00077nL00<007nLOi`0ognLO7nL000COi`3

0006Oi`00`00OiaoW03oOialOi`001AoW003001oW7nL00EoW003001oW7nL0?moW7aoW0003GnL1@00

0WnL00<007nLOi`01GnL1000ognL3WnL3W`0GgnL000DOi`00`00OiaoW005Oi`00`00OiaoW03oOi`;

Oi`4O00=Oi`4O01LOi`001AoW003001oW7nL00EoW003001oW7nL0?moW0UoW09l01EoW0=l05UoW000

4gnL0P001gnL00<007nLOi`0ognL1gnL0W`06GnL0g`0EgnL000LOi`00`00OiaoW03oOi`5Oi`2O00M

Oi`3O01EOi`001aoW003001oW7nL0?moW0=oW09l029oW003O01oW7nL059oW00077nL00<007nLOi`0

ognL0GnL0W`09GnL0g`0DGnL000LOi`00`00OiaoW03oOi`00g`0OiaoW00WOi`2O01@Oi`001aoW003

001oW7nL0?eoW09l02aoW003O01oW7nL04eoW00077nL00<007nLOi`0o7nL00=l07nLOi`0;GnL00=l

07nLOi`0C7nL000LOi`00`00OiaoW03kOi`2O00`Oi`2O01<Oi`001aoW0<00?UoW09l03=oW09l04]o

W00077nL00<007nLOi`0nGnL00=l07nLOi`0=7nL00=l07nLOi`0B7nL000LOi`00`00OiaoW03gOi`2

O00gOi`2O019Oi`001aoW003001oW7nL0?MoW003O01oW7nL03QoW003O01oW7nL04IoW00077nL00<0

07nLOi`0mGnL0W`0?7nL00=l07nLOi`0AGnL000LOi`00`00OiaoW03dOi`00g`0OiaoW00mOi`00g`0

OiaoW014Oi`001aoW003001oW7nL0?AoW003O01oW7nL03ioW003O01oW7nL04=oW00077nL00<007nL

Oi`0lWnL0W`0@WnL00=l07nLOi`0@WnL000LOi`00`00OiaoW03aOi`00g`0OiaoW013Oi`00g`0Oiao

W011Oi`001aoW003001oW7nL0?5oW003O01oW7nL04AoW003O01oW7nL041oW00077nL00<007nLOi`0

kgnL0W`0AgnL0W`0@GnL000LOi`00`00OiaoW03_Oi`00g`0OiaoW018Oi`00g`0OiaoW00nOi`001ao

W0<00>ioW003O01oW7nL04YoW003O01oW7nL03eoW00077nL00<007nLOi`0kGnL00=l07nLOi`0BgnL

00=l07nLOi`0?GnL000LOi`00`00OiaoW03/Oi`00g`0OiaoW01=Oi`00g`0OiaoW00lOi`001aoW003

001oW7nL0>aoW003O01oW7nL04ioW003O01oW7nL03]oW00077nL00<007nLOi`0jgnL00=l07nLOi`0

D7nL00=l07nLOi`0>WnL000LOi`00`00OiaoW03ZOi`00g`0OiaoW01AOi`2O00kOi`001aoW003001o

W7nL0>UoW003O01oW7nL05AoW003O01oW7nL03QoW00077nL00<007nLOi`0j7nL00=l07nLOi`0EGnL

00=l07nLOi`0>7nL000LOi`00`00OiaoW03WOi`00g`0OiaoW01GOi`00g`0OiaoW00gOi`001aoW003

001oW7nL0>MoW003O01oW7nL05QoW003O01oW7nL03IoW00077nL00<007nLOi`0iWnL00=l07nLOi`0

FWnL00=l07nLOi`0=GnL000LOi`3003UOi`00g`0OiaoW01KOi`00g`0OiaoW00eOi`001aoW003001o

W7nL0>AoW003O01oW7nL05eoW003O01oW7nL03AoW00077nL00<007nLOi`0i7nL00=l07nLOi`0GWnL

00=l07nLOi`0<gnL000LOi`00`00OiaoW03SOi`00g`0OiaoW01OOi`00g`0OiaoW00cOi`001aoW003

001oW7nL0>9oW003O01oW7nL065oW003O01oW7nL039oW00077nL00<007nLOi`0hWnL00=l07nLOi`0

HWnL00=l07nLOi`0<GnL000LOi`00`00OiaoW03ROi`00g`0OiaoW01ROi`00g`0OiaoW00aOi`001ao

W003001oW7nL0>5oW003O01oW7nL06AoW003O01oW7nL031oW00077nL00<007nLOi`0h7nL00=l07nL

Oi`0IGnL00=l07nLOi`0<7nL000LOi`00`00OiaoW02hOibi01l:Oi`001aoW003001oW7nL0;QoW003

01moW7nL02AoW003O01oW7nL06QoW003O01oW7nL02ioW00077nL00<007nLOi`0^7nL00<07gnLOi`0

8gnL00=l07nLOi`0JWnL00=l07nLOi`0;GnL000LOi`3002hOi`00`0OOiaoW00ROi`00g`0OiaoW01[

Oi`00g`0OiaoW00]Oi`001aoW003001oW7nL0;QoW00301moW7nL025oW003O01oW7nL06eoW003O01o

W7nL02aoW00077nL00<007nLOi`0^7nL00<07gnLOi`08GnL00=l07nLOi`0KWnL00=l07nLOi`0:gnL

000LOi`00`00OiaoW02hOi`00`0OOiaoW00QOi`00g`0OiaoW01^Oi`00g`0OiaoW00[Oi`001aoW003

001oW7nL0;QoW00301moW7nL021oW003O01oW7nL06moW003O01oW7nL02]oW00077nL00<007nLOi`0

^7nL00<07gnLOi`07gnL00=l07nLOi`0LGnL00=l07nLOi`0:WnL000LOi`00`00OiaoW02hOi`00`0O

OiaoW00OOi`00g`0OiaoW01bOi`00g`0OiaoW00YOi`001aoW003001oW7nL0;QoW00301moW7nL01io

W003O01oW7nL07AoW003O01oW7nL02QoW00077nL00<007nLOi`0^7nL00<07gnLOi`07GnL00=l07nL

Oi`0MGnL00=l07nLOi`0:7nL0008Oi`20004Oi`20003Oi`30006Oi`00`00OiaoW02hOi`00`0OOiao

W00LOi`00g`0OiaoW01gOi`00g`0OiaoW00WOi`000MoW004001oW7nL0003Oi`20006Oi`00`00Oiao

W003Oi`00`00OiaoW02hOi`00`0OOiaoW00LOi`00g`0OiaoW01gOi`00g`0OiaoW00WOi`00003Oi`0

000000<00005Oi`007nLOi`0000;Oi`00`00OiaoW003Oi`4002gOi`00`0OOiaoW00LOi`00g`0Oiao

W01hOi`00g`0OiaoW00VOi`000MoW004001oW7nL0008Oi`30006Oi`00`00OiaoW02hOi`00`0OOiao

W00KOi`00g`0OiaoW01jOi`00g`0OiaoW00UOi`000MoW004001oW7nL0008Oi`00`00OiaoW006Oi`0

0`00OiaoW02hOi`00`0OOiaoW00JOi`00g`0OiaoW01kOi`00g`0OiaoW00UOi`000QoW08000UoW0@0

00EoW003001oW7nL0;QoW00301moW7nL01UoW003O01oW7nL07eoW003O01oW7nL02AoW00077nL00<0

07nLOi`0^7nL00<07gnLOi`06GnL00=l07nLOi`0OGnL00=l07nLOi`097nL000LOi`00`00OiaoW02h

Oi`00`0OOiaoW00IOi`00g`0OiaoW01nOi`00g`0OiaoW00SOi`001aoW003001oW7nL0;QoW00301mo

W7nL01QoW003O01oW7nL07moW003O01oW7nL02=oW00077nL00<007nLOi`0^7nL00<07gnLOi`05gnL

00=l07nLOi`0PGnL00=l07nLOi`08WnL000LOi`00`00OiaoW02hOi`00`0OOiaoW00GOi`00g`0Oiao

W022Oi`00g`0OiaoW00QOi`001aoW003001oW7nL0;QoW00301moW7nL01MoW003O01oW7nL089oW003

O01oW7nL025oW00077nL00<007nLOi`0^7nL00<07gnLOi`05WnL00=l07nLOi`0Q7nL00=l07nLOi`0

87nL000LOi`00`00OiaoW02hOi`00`0OOiaoW00EOi`00g`0OiaoW025Oi`00g`0OiaoW00POi`001ao

W0<00;QoW00301moW7nL01AoW003O01oW7nL08MoW003O01oW7nL01moW00077nL00<007nLOi`0^7nL

00<07gnLOi`057nL00=l07nLOi`0R7nL00=l07nLOi`07WnL000LOi`00`00OiaoW02hOi`00`0OOiao

W00DOi`00g`0OiaoW028Oi`00g`0OiaoW00NOi`001aoW003001oW7nL0;QoW00301moW7nL01=oW003

O01oW7nL08UoW003O01oW7nL01ioW00077nL00<007nLOi`0^7nL00<07gnLOi`04WnL00=l07nLOi`0

RgnL00=l07nLOi`07GnL000LOi`00`00OiaoW02hOi`00`0OOiaoW00BOi`00g`0OiaoW02<Oi`00g`0

OiaoW00LOi`001aoW003001oW7nL0;QoW00301moW7nL019oW003O01oW7nL08aoW003O01oW7nL01ao

W00077nL00<007nLOi`0^7nL00<07gnLOi`04GnL00=l07nLOi`0SWnL00=l07nLOi`06gnL000LOi`0

0`00OiaoW02hOi`00`0OOiaoW00@Oi`00g`0OiaoW02?Oi`00g`0OiaoW00KOi`001aoW003001oW7nL

0;QoW00301moW7nL00moW003O01oW7nL095oW003O01oW7nL01YoW00077nL00<007nLOi`0^7nL00<0

7gnLOi`03gnL00=l07nLOi`0TGnL00=l07nLOi`06WnL000LOi`3002hOi`00`0OOiaoW00?Oi`00g`0

OiaoW02BOi`00g`0OiaoW00IOi`001aoW003001oW7nL0;QoW00301moW7nL00ioW003O01oW7nL09Ao

W003O01oW7nL01QoW00077nL00<007nLOi`0^7nL00<07gnLOi`03GnL00=l07nLOi`0UGnL00=l07nL

Oi`067nL000LOi`00`00OiaoW02hOi`00`0OOiaoW00=Oi`00g`0OiaoW02EOi`00g`0OiaoW00HOi`0

01aoW003001oW7nL0;QoW00301moW7nL00aoW003O01oW7nL09MoW003O01oW7nL01MoW00077nL00<0

07nLOi`0^7nL00<07gnLOi`037nL00=l07nLOi`0V7nL00=l07nLOi`05WnL000LOi`00`00OiaoW02h

Oi`00`0OOiaoW00;Oi`00g`0OiaoW02IOi`00g`0OiaoW00FOi`001aoW003001oW7nL0;QoW00301mo

W7nL00]oW003O01oW7nL09UoW003O01oW7nL01IoW00077nL00<007nLOi`0^7nL00<07gnLOi`02WnL

00=l07nLOi`0VgnL00=l07nLOi`05GnL000LOi`00`00OiaoW02hOi`00`0OOiaoW00:Oi`00g`0Oiao

W02LOi`00g`0OiaoW00DOi`001aoW003001oW7nL0;QoW00301moW7nL00YoW003O01oW7nL09aoW003

O01oW7nL01AoW00077nL0`00^7nL00<07gnLOi`02GnL00=l07nLOi`0WWnL00=l07nLOi`04gnL000L

Oi`00`00OiaoW02hOi`00`0OOiaoW008Oi`00g`0OiaoW02OOi`00g`0OiaoW00COi`001aoW003001o

W7nL0;QoW00301moW7nL00MoW003O01oW7nL0:5oW003O01oW7nL019oW00077nL00<007nLOi`0^7nL

00<07gnLOi`01gnL00=l07nLOi`0XGnL00=l07nLOi`04WnL000LOi`00`00OiaoW02hOi`00`0OOiao

W007Oi`00g`0OiaoW02ROi`00g`0OiaoW00AOi`001aoW003001oW7nL0;QoW00301moW7nL00IoW003

O01oW7nL0:AoW003O01oW7nL011oW00077nL00<007nLOi`0^7nL00<07gnLOi`01WnL00=l07nLOi`0

Y7nL00=l07nLOi`047nL000LOi`00`00OiaoW02hOi`00`0OOiaoW005Oi`00g`0OiaoW02UOi`00g`0

OiaoW00@Oi`001aoW003001oW7nL0;QoW00301moW7nL00AoW003O01oW7nL0:MoW003O01oW7nL00mo

W00077nL00<007nLOi`0^7nL00<07gnLOi`017nL00=l07nLOi`0Z7nL00=l07nLOi`03WnL000LOi`0

0`00OiaoW02hOi`00`0OOiaoW004Oi`00g`0OiaoW02XOi`00g`0OiaoW00>Oi`001aoW003001oW7nL

03ioW0<000AoW08000AoW08003UoW0@000=oW08000AoW08002=oW00301moW7nL00=oW003O01oW7nL

00ioW0<000AoW08000AoW08003YoW0<000=oW08000AoW08003YoW0<000AoW0800004Oial07nLOi`2

000<Oi`001aoW0<003moW003001oW7nL009oW004001oW7nL0002Oi`01000OiaoW000>GnL00<007nL

Oi`00WnL00@007nLOi`0009oW004001oW7nL000ROi`00`0OOiaoW002Oi`00g`0OiaoW00BOi`01000

OiaoW0000WnL00@007nLOi`0009oW003001oW7nL03QoW005001oW7nLOi`00002Oi`01000OiaoW000

0WnL00<007nLOi`0>WnL00@007nLOi`0009oW004001oW7`00002Oi`00`00OiaoW009Oi`001aoW003

001oW7nL03moW003001oW7nL009oW004001oW7nL0002Oi`01000OiaoW000>WnL00D007nLOiaoW000

009oW004001oW7nL0002Oi`00`00OiaoW00POi`00`0OOiaoW002Oi`00g`0OiaoW00BOi`01000Oiao

W0000WnL00@007nLOi`0009oW003001oW7nL03IoW0@0009oW004001oW7nL0002Oi`01000OiaoW000

?7nL00@007nLOi`0009oW004001oW7`00002Oi`00`00OiaoW009Oi`001aoW003001oW7nL03moW003

001oW7nL009oW004001oW7nL0002Oi`01000OiaoW000>gnL00@007nLOi`0009oW004001oW7nL0002

Oi`00`00OiaoW00POi`00`0OOiaoW002Oi`00g`0OiaoW00@Oi`20003Oi`01000OiaoW0000WnL00@0

07nLOi`003QoW003001oW00000=oW004001oW7nL0002Oi`01000OiaoW000>GnL0`000gnL00@007nL

Oi`0009oW004O01oW7nL000;Oi`001aoW003001oW7nL03moW003001oW7nL009oW004001oW7nL0002

Oi`01000OiaoW000>7nL00@007nLOi`0009oW004001oW7nL0002Oi`01000OiaoW0008WnL00D07gnL

OiaoW7`001EoW004001oW7nL0002Oi`01000OiaoW0000WnL00<007nLOi`0=WnL00<007nL00000gnL

00@007nLOi`0009oW004001oW7nL000iOi`00`00OiaoW003Oi`01000OiaoW0000WnL00@007`0Oi`0

00]oW00077nL00<007nLOi`0?WnL0P001GnL0P0017nL0P00>WnL0P0017nL0P0017nL0P008gnL00@0

7gnLOial01=oW0<000AoW08000AoW08003YoW08000AoW08000AoW08003YoW0@000=oW08000AoW003

O00007nL00]oW00077nL00<007nLOi`0^7nL00@07gnLOial0;5oW003O01oW7nL00]oW00077nL00<0

07nLOi`0^7nL00<07gnLO000/gnL00=l07nLOi`02WnL000LOi`00`00OiaoW02hOi`00`0OOial002d

Oi`00g`0OiaoW009Oi`001aoW003001oW7nL0;QoW00301moW7`00;AoW003O01oW7nL00UoW00077nL

00<007nLOi`0^7nL00<07g`0Oi`0]GnL00=l07nLOi`027nL000LOi`00`00OiaoW02hOi`00`0OOiao

W02eOi`00g`0OiaoW008Oi`001=oW0X00003O00000000;L0000301l000000<00000077nL00<007`0

Oi`037nL00<007nLOi`02gnL00<007nLOi`037nL00<007nLOi`02gnL00<007nLOi`037nL00<007nL

Oi`02gnL00<007nLOi`037nL00<007nLOi`02gnL00<007nLOi`037nL00<007nLOi`02gnL00<007nL

Oi`037nL00<007nLOi`02gnL00<007nLOi`02GnL00@07g`0Oi`000eoW003001oW7nL00aoW003001o

W7nL00]oW003001oW7nL00aoW003001oW7nL00]oW003001oW7nL00aoW003001oW7nL00]oW003001o

W7nL00aoW003001oW7nL00]oW003001oW7nL00aoW003001oW7nL00]oW003001oW7nL00aoW003001o

W7nL00]oW003001oW7nL009oW00077nL00<007nLO00037nL00<007nLOi`02gnL00<007nLOi`037nL

00<007nLOi`02gnL00<007nLOi`037nL00<007nLOi`02gnL00<007nLOi`037nL00<007nLOi`02gnL

00<007nLOi`037nL00<007nLOi`02gnL00<007nLOi`037nL00<007nLOi`02gnL00<007nLOi`02GnL

00@07gnLOi`000eoW003001oW7nL00aoW003001oW7nL00]oW003001oW7nL00aoW003001oW7nL00]o

W003001oW7nL00aoW003001oW7nL00]oW003001oW7nL00aoW003001oW7nL00]oW003001oW7nL00ao

W003001oW7nL00]oW003001oW7nL00aoW003001oW7nL00]oW003001oW7nL009oW00077nL00@007nL

Oial04EoW003001oW7nL04EoW003001oW7nL02EoW003O0007gnL01ioW003001oW7nL04EoW003001o

W7nL04IoW003001oW7nL011oW00077nL00@007nLOial0;EoW003O0007gnL0<9oW00077nL00@007nL

Oial0;AoW003O01oW00O0<=oW00077nL00D007nLOiaoW7`00;=oW003O01oW00O0<=oW00077nL00<0

07nLOi`00WnL00=l07nLOi`0[gnL00Al07nLOi`07l=oW00077nL00<007nLOi`00WnL00=l07nLOi`0

[gnL00Al07nLOi`07l=oW00077nL00<007nLOi`00WnL00=l07nLOi`0[WnL00El07nLOiaoW00O0<=o

W00077nL00<007nLOi`00gnL00=l07nLOi`0[7nL00=l07nLOi`00WnL00<07gnLOi`0`GnL000LOi`0

0`00OiaoW003Oi`00g`0OiaoW02/Oi`00g`0OiaoW002Oi`00`0OOiaoW031Oi`001aoW0<000AoW003

O01oW7nL0:]oW003O01oW7nL009oW00301moW7nL0<5oW00077nL00<007nLOi`01GnL00=l07nLOi`0

ZGnL00=l07nLOi`00gnL00<07gnLOi`0`GnL000LOi`00`00OiaoW005Oi`00g`0OiaoW02XOi`00g`0

OiaoW004Oi`00`0OOiaoW031Oi`001aoW003001oW7nL00EoW003O01oW7nL0:QoW003O01oW7nL00Ao

W00301moW7nL0<5oW00077nL00<007nLOi`01WnL00=l07nLOi`0YgnL00=l07nLOi`017nL00<07gnL

Oi`0`GnL000LOi`00`00OiaoW007Oi`00g`0OiaoW02UOi`00g`0OiaoW005Oi`00`0OOiaoW031Oi`0

01aoW003001oW7nL00MoW003O01oW7nL0:EoW003O01oW7nL00EoW00301moW7nL0<5oW00077nL00<0

07nLOi`027nL00=l07nLOi`0XgnL00=l07nLOi`01WnL00<07gnLOi`0`GnL000LOi`00`00OiaoW008

Oi`00g`0OiaoW02ROi`00g`0OiaoW007Oi`00`0OOiaoW031Oi`001aoW003001oW7nL00UoW003O01o

W7nL0:5oW003O01oW7nL00MoW00301moW7nL0<5oW00077nL00<007nLOi`02GnL00=l07nLOi`0XGnL

00=l07nLOi`01gnL00<07gnLOi`0`GnL000LOi`3000:Oi`00g`0OiaoW02OOi`00g`0OiaoW008Oi`0

0`0OOiaoW031Oi`001aoW003001oW7nL00YoW003O01oW7nL09ioW003O01oW7nL00UoW00301moW7nL

0<5oW00077nL00<007nLOi`02gnL00=l07nLOi`0W7nL00=l07nLOi`02WnL00<07gnLOi`0`GnL000L

Oi`00`00OiaoW00;Oi`00g`0OiaoW02LOi`00g`0OiaoW00:Oi`00`0OOiaoW031Oi`001aoW003001o

W7nL00aoW003O01oW7nL09]oW003O01oW7nL00YoW00301moW7nL0<5oW00077nL00<007nLOi`03GnL

00=l07nLOi`0VGnL00=l07nLOi`02gnL00<07gnLOi`0`GnL000LOi`00`00OiaoW00=Oi`00g`0Oiao

W02IOi`00g`0OiaoW00;Oi`00`0OOiaoW031Oi`001aoW003001oW7nL00eoW003O01oW7nL09QoW003

O01oW7nL00aoW00301moW7nL0<5oW00077nL00<007nLOi`03WnL00=l07nLOi`0UgnL00=l07nLOi`0

37nL00<07gnLOi`0`GnL000LOi`00`00OiaoW00?Oi`00g`0OiaoW02EOi`00g`0OiaoW00=Oi`00`0O

OiaoW031Oi`001aoW003001oW7nL00moW003O01oW7nL09EoW003O01oW7nL00eoW00301moW7nL0<5o

W00077nL00<007nLOi`03gnL00=l07nLOi`0U7nL00=l07nLOi`03WnL00<07gnLOi`0`GnL000LOi`3

000@Oi`00g`0OiaoW02BOi`00g`0OiaoW00?Oi`00`0OOiaoW031Oi`001aoW003001oW7nL015oW003

O01oW7nL095oW003O01oW7nL00moW00301moW7nL0<5oW00077nL00<007nLOi`04GnL00=l07nLOi`0

TGnL00=l07nLOi`03gnL00<07gnLOi`0`GnL000LOi`00`00OiaoW00BOi`00g`0OiaoW02?Oi`00g`0

OiaoW00@Oi`00`0OOiaoW031Oi`001aoW003001oW7nL019oW003O01oW7nL08ioW003O01oW7nL015o

W00301moW7nL0<5oW00077nL00<007nLOi`04gnL00=l07nLOi`0SGnL00=l07nLOi`04GnL00<07gnL

Oi`0`GnL000LOi`00`00OiaoW00COi`00g`0OiaoW02=Oi`00g`0OiaoW00AOi`00`0OOiaoW031Oi`0

01aoW003001oW7nL01AoW003O01oW7nL08]oW003O01oW7nL019oW00301moW7nL0<5oW00077nL00<0

07nLOi`05GnL00=l07nLOi`0RGnL00=l07nLOi`04gnL00<07gnLOi`0`GnL000LOi`00`00OiaoW00E

Oi`00g`0OiaoW028Oi`00g`0OiaoW00DOi`00`0OOiaoW031Oi`001aoW003001oW7nL01IoW003O01o

W7nL08MoW003O01oW7nL01AoW00301moW7nL0<5oW00077nL0`005WnL00=l07nLOi`0QgnL00=l07nL

Oi`057nL00<07gnLOi`0`GnL000LOi`00`00OiaoW00GOi`00g`0OiaoW025Oi`00g`0OiaoW00EOi`0

0`0OOiaoW031Oi`001aoW003001oW7nL01MoW003O01oW7nL08AoW003O01oW7nL01IoW00301moW7nL

0<5oW00077nL00<007nLOi`067nL00=l07nLOi`0PWnL00=l07nLOi`05gnL00<07gnLOi`0`GnL000L

Oi`00`00OiaoW00HOi`00g`0OiaoW022Oi`00g`0OiaoW00GOi`00`0OOiaoW031Oi`001aoW003001o

W7nL01UoW003O01oW7nL085oW003O01oW7nL01MoW00301moW7nL0<5oW00077nL00<007nLOi`06WnL

00=l07nLOi`0OgnL00=l07nLOi`067nL00<07gnLOi`0`GnL000LOi`00`00OiaoW00JOi`00g`0Oiao

W01nOi`00g`0OiaoW00IOi`00`0OOiaoW031Oi`001aoW003001oW7nL01]oW003O01oW7nL07eoW003

O01oW7nL01UoW00301moW7nL0<5oW00077nL00<007nLOi`06gnL00=l07nLOi`0OGnL00=l07nLOi`0

6GnL00<07gnLOi`0`GnL0008Oi`20004Oi`20003Oi`30006Oi`00`00OiaoW00LOi`00g`0OiaoW01k

Oi`00g`0OiaoW00JOi`00`0OOiaoW031Oi`000MoW004001oW7nL0003Oi`20006Oi`00`00OiaoW003

Oi`00`00OiaoW00MOi`00g`0OiaoW01iOi`00g`0OiaoW00KOi`00`0OOiaoW031Oi`000MoW004001o

W7nL000;Oi`00`00OiaoW003Oi`4000LOi`00g`0OiaoW01hOi`00g`0OiaoW00LOi`00`0OOiaoW031

Oi`000MoW004001oW7nL0008Oi`30006Oi`00`00OiaoW00NOi`00g`0OiaoW01gOi`00g`0OiaoW00L

Oi`00`0OOiaoW031Oi`000MoW004001oW7nL0008Oi`00`00OiaoW006Oi`00`00OiaoW00OOi`00g`0

OiaoW01eOi`00g`0OiaoW00MOi`00`0OOiaoW031Oi`000QoW08000UoW0@000EoW003001oW7nL01mo

W003O01oW7nL07EoW003O01oW7nL01eoW00301moW7nL0<5oW00077nL00<007nLOi`07gnL00=l07nL

Oi`0M7nL00=l07nLOi`07WnL00<07gnLOi`0`GnL000LOi`00`00OiaoW00POi`00g`0OiaoW01bOi`0

0g`0OiaoW00OOi`00`0OOiaoW031Oi`001aoW003001oW7nL025oW003O01oW7nL075oW003O01oW7nL

01moW00301moW7nL0<5oW00077nL00<007nLOi`08WnL00=l07nLOi`0KgnL00=l07nLOi`087nL00<0

7gnLOi`0`GnL000LOi`00`00OiaoW00ROi`00g`0OiaoW01^Oi`00g`0OiaoW00QOi`00`0OOiaoW031

Oi`001aoW003001oW7nL02=oW003O01oW7nL06eoW003O01oW7nL025oW00301moW7nL0<5oW00077nL

00<007nLOi`08gnL00=l07nLOi`0KGnL00=l07nLOi`08GnL00<07gnLOi`0`GnL000LOi`3000TOi`0

0g`0OiaoW01[Oi`00g`0OiaoW00ROi`00`0OOiaoW031Oi`001aoW003001oW7nL02AoW003O01oW7nL

06YoW003O01oW7nL02=oW00301moW7nL0<5oW00077nL00<007nLOi`09GnL00=l07nLOi`0J7nL00=l

07nLOi`097nL00<07gnLOi`0`GnL000LOi`00`0001l07`2h01o3Oi`001aoW003001oW7nL02MoW003

O01oW7nL06EoW003O01oW7nL0>UoW00077nL00<007nLOi`09gnL00=l07nLOi`0I7nL00=l07nLOi`0

jWnL000LOi`00`00OiaoW00XOi`00g`0OiaoW01SOi`00g`0OiaoW03ZOi`001aoW003001oW7nL02Uo

W003O01oW7nL065oW003O01oW7nL0>]oW00077nL00<007nLOi`0:WnL00=l07nLOi`0GgnL00=l07nL

Oi`0k7nL000LOi`00`00OiaoW00ZOi`00g`0OiaoW01NOi`00g`0OiaoW03]Oi`001aoW003001oW7nL

02]oW003O01oW7nL05eoW003O01oW7nL0>eoW00077nL00<007nLOi`0;7nL00=l07nLOi`0FgnL00=l

07nLOi`0kWnL000LOi`3000/Oi`00g`0OiaoW01JOi`00g`0OiaoW03_Oi`001aoW003001oW7nL02eo

W003O01oW7nL05QoW003O01oW7nL0?1oW00077nL00<007nLOi`0;WnL00=l07nLOi`0EgnL00=l07nL

Oi`0l7nL000LOi`00`00OiaoW00_Oi`00g`0OiaoW01EOi`00g`0OiaoW03aOi`001aoW003001oW7nL

02moW003O01oW7nL05AoW003O01oW7nL0?9oW00077nL00<007nLOi`0<7nL00=l07nLOi`0DgnL00=l

07nLOi`0lWnL000LOi`00`00OiaoW00aOi`00g`0OiaoW01AOi`00g`0OiaoW03cOi`001aoW003001o

W7nL039oW003O01oW7nL04moW003O01oW7nL0?AoW00077nL00<007nLOi`0<WnL00=l07nLOi`0CWnL

00=l07nLOi`0mGnL000LOi`00`00OiaoW00cOi`00g`0OiaoW01=Oi`00g`0OiaoW03eOi`001aoW003

001oW7nL03AoW003O01oW7nL04]oW003O01oW7nL0?IoW00077nL0`00=7nL0W`0BWnL0W`0nGnL000L

Oi`00`00OiaoW00fOi`00g`0OiaoW017Oi`00g`0OiaoW03hOi`001aoW003001oW7nL03MoW003O01o

W7nL04EoW003O01oW7nL0?UoW00077nL00<007nLOi`0=gnL00=l07nLOi`0A7nL00=l07nLOi`0nWnL

000LOi`00`00OiaoW00hOi`2O013Oi`2O03lOi`001aoW003001oW7nL03UoW003O01oW7nL041oW003

O01oW7nL0?aoW00077nL00<007nLOi`0>WnL00=l07nLOi`0?WnL00=l07nLOi`0oGnL000LOi`00`00

OiaoW00kOi`2O00mOi`2O03oOi`001aoW003001oW7nL03aoW003O01oW7nL03YoW003O01oW7nL0?mo

W00077nL00<007nLOi`0?GnL0W`0>GnL0W`0ognL0WnL000LOi`00`00OiaoW00oOi`00g`0OiaoW00e

Oi`00g`0OiaoW03oOi`2Oi`001aoW0<003moW09l03EoW003O01oW7nL0?moW0=oW00077nL00<007nL

Oi`0@GnL00=l07nLOi`0<GnL00=l07nLOi`0ognL17nL000LOi`00`00OiaoW011Oi`2O00`Oi`2O03o

Oi`7Oi`001aoW003001oW7nL04=oW09l02eoW09l0?moW0QoW00077nL00<007nLOi`0A7nL0W`0:gnL

00=l07nLOi`0ognL27nL000LOi`00`00OiaoW016Oi`2O00WOi`2O03oOi`;Oi`001aoW003001oW7nL

04MoW09l02EoW003O01oW7nL0?moW0]oW00077nL00<007nLOi`0BGnL0W`087nL0g`0ognL3WnL000L

Oi`00`00OiaoW01;Oi`2O00MOi`2O03oOi`@Oi`001aoW003001oW7nL04aoW0=l01QoW0=l0?moW19o

W0004gnL0`001WnL00<007nLOi`0CgnL0g`04WnL0g`0ognL5GnL000DOi`00`00OiaoW005Oi`00`00

OiaoW01BOi`4O00;Oi`4O03oOi`GOi`001AoW003001oW7nL00EoW0@005EoW0]l0?moW1]oW00057nL

00<007nLOi`01GnL00<007nLOi`0ognLO7nL000DOi`00`00OiaoW005Oi`00`00OiaoW03oOialOi`0

01=oW08000MoW003001oW7nL0?moW7aoW00077nL00<007nLOi`0ognLO7nL000LOi`00`00OiaoW03o

OialOi`001aoW003001oW7nL0?moW7aoW000ognLVgnL003oOibKOi`00?moW9]oW000ognLVgnL003o

OibKOi`00001\

\>"],

  ImageRangeCache->{{{0, 409}, {252.312, 0}} -> {-39.8564, -1.10083, 1.38058, 

  0.00872591}}]

}, Open  ]],



Cell[BoxData[

    \(\(wdata\  = \ DWT[data]; \)\)], "Input"],



Cell[CellGroupData[{



Cell[BoxData[{

    \(Max[wdata]\), 

    \(Min[wdata]\)}], "Input"],



Cell[BoxData[

    \(14.1306966394984261`\)], "Output"],



Cell[BoxData[

    \(\(-3.20680114785988035`\)\)], "Output"]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{



Cell["This is a better smoothing of the data", "Subsubtitle"],



Cell[CellGroupData[{



Cell[BoxData[

    \(swdata\  = \ thresh2[wdata, 1]\)], "Input"],



Cell[BoxData[

    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      \(-1.29887313383273085`\), 0, 0, 1.34183460162570122`, 

      1.50108201979227402`, 0, 0, \(-1.77162917817635019`\), 

      \(-2.93941747509233444`\), 2.92281199433181981`, 2.86810968799443912`, 

      \(-3.20680114785988035`\), 0, 0, 14.1306966394984261`, 0}\)], "Output"]

}, Open  ]],



Cell[BoxData[

    \(\(sdata\  = \ IDWT[swdata]; \)\)], "Input"],



Cell[CellGroupData[{



Cell[BoxData[

    \(Plot2Lists[sdata, udata]\)], "Input"],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.00186012 0.309017 0.294302 [

[.20982 .29652 -9 -9 ]

[.20982 .29652 9 0 ]

[.39583 .29652 -9 -9 ]

[.39583 .29652 9 0 ]

[.58185 .29652 -9 -9 ]

[.58185 .29652 9 0 ]

[.76786 .29652 -9 -9 ]

[.76786 .29652 9 0 ]

[.95387 .29652 -9 -9 ]

[.95387 .29652 9 0 ]

[.01131 .01472 -12 -4.5 ]

[.01131 .01472 0 4.5 ]

[.01131 .16187 -24 -4.5 ]

[.01131 .16187 0 4.5 ]

[.01131 .45617 -18 -4.5 ]

[.01131 .45617 0 4.5 ]

[.01131 .60332 -6 -4.5 ]

[.01131 .60332 0 4.5 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.20982 .30902 m

.20982 .31527 L

s

[(100)] .20982 .29652 0 1 Mshowa

.39583 .30902 m

.39583 .31527 L

s

[(200)] .39583 .29652 0 1 Mshowa

.58185 .30902 m

.58185 .31527 L

s

[(300)] .58185 .29652 0 1 Mshowa

.76786 .30902 m

.76786 .31527 L

s

[(400)] .76786 .29652 0 1 Mshowa

.95387 .30902 m

.95387 .31527 L

s

[(500)] .95387 .29652 0 1 Mshowa

.125 Mabswid

.06101 .30902 m

.06101 .31277 L

s

.09821 .30902 m

.09821 .31277 L

s

.13542 .30902 m

.13542 .31277 L

s

.17262 .30902 m

.17262 .31277 L

s

.24702 .30902 m

.24702 .31277 L

s

.28423 .30902 m

.28423 .31277 L

s

.32143 .30902 m

.32143 .31277 L

s

.35863 .30902 m

.35863 .31277 L

s

.43304 .30902 m

.43304 .31277 L

s

.47024 .30902 m

.47024 .31277 L

s

.50744 .30902 m

.50744 .31277 L

s

.54464 .30902 m

.54464 .31277 L

s

.61905 .30902 m

.61905 .31277 L

s

.65625 .30902 m

.65625 .31277 L

s

.69345 .30902 m

.69345 .31277 L

s

.73065 .30902 m

.73065 .31277 L

s

.80506 .30902 m

.80506 .31277 L

s

.84226 .30902 m

.84226 .31277 L

s

.87946 .30902 m

.87946 .31277 L

s

.91667 .30902 m

.91667 .31277 L

s

.99107 .30902 m

.99107 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

.02381 .01472 m

.03006 .01472 L

s

[(-1)] .01131 .01472 1 0 Mshowa

.02381 .16187 m

.03006 .16187 L

s

[(-0.5)] .01131 .16187 1 0 Mshowa

.02381 .45617 m

.03006 .45617 L

s

[(0.5)] .01131 .45617 1 0 Mshowa

.02381 .60332 m

.03006 .60332 L

s

[(1)] .01131 .60332 1 0 Mshowa

.125 Mabswid

.02381 .04415 m

.02756 .04415 L

s

.02381 .07358 m

.02756 .07358 L

s

.02381 .10301 m

.02756 .10301 L

s

.02381 .13244 m

.02756 .13244 L

s

.02381 .1913 m

.02756 .1913 L

s

.02381 .22073 m

.02756 .22073 L

s

.02381 .25016 m

.02756 .25016 L

s

.02381 .27959 m

.02756 .27959 L

s

.02381 .33845 m

.02756 .33845 L

s

.02381 .36788 m

.02756 .36788 L

s

.02381 .39731 m

.02756 .39731 L

s

.02381 .42674 m

.02756 .42674 L

s

.02381 .4856 m

.02756 .4856 L

s

.02381 .51503 m

.02756 .51503 L

s

.02381 .54446 m

.02756 .54446 L

s

.02381 .57389 m

.02756 .57389 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02567 .36856 m

.02753 .36856 L

.02939 .36856 L

.03125 .36856 L

.03311 .36856 L

.03497 .36856 L

.03683 .36856 L

.03869 .36856 L

.04055 .36856 L

.04241 .36856 L

.04427 .36856 L

.04613 .36856 L

.04799 .36856 L

.04985 .36856 L

.05171 .36856 L

.05357 .36856 L

.05543 .36856 L

.05729 .36856 L

.05915 .36856 L

.06101 .36856 L

.06287 .36856 L

.06473 .36856 L

.06659 .36856 L

.06845 .36856 L

.07031 .36856 L

.07217 .36856 L

.07403 .36856 L

.07589 .36856 L

.07775 .36856 L

.07961 .36856 L

.08147 .36856 L

.08333 .36856 L

.08519 .46413 L

.08705 .46413 L

.08891 .46413 L

.09077 .46413 L

.09263 .46413 L

.09449 .46413 L

.09635 .46413 L

.09821 .46413 L

.10007 .46413 L

.10193 .46413 L

.10379 .46413 L

.10565 .46413 L

.10751 .46413 L

.10937 .46413 L

.11124 .46413 L

.1131 .46413 L

.11496 .46413 L

.11682 .46413 L

Mistroke

.11868 .46413 L

.12054 .46413 L

.1224 .46413 L

.12426 .46413 L

.12612 .46413 L

.12798 .46413 L

.12984 .46413 L

.1317 .46413 L

.13356 .46413 L

.13542 .46413 L

.13728 .46413 L

.13914 .46413 L

.141 .46413 L

.14286 .46413 L

.14472 .56927 L

.14658 .56927 L

.14844 .56927 L

.1503 .56927 L

.15216 .56927 L

.15402 .56927 L

.15588 .56927 L

.15774 .56927 L

.1596 .56927 L

.16146 .56927 L

.16332 .56927 L

.16518 .56927 L

.16704 .56927 L

.1689 .56927 L

.17076 .56927 L

.17262 .56927 L

.17448 .56927 L

.17634 .56927 L

.1782 .56927 L

.18006 .56927 L

.18192 .56927 L

.18378 .56927 L

.18564 .56927 L

.1875 .56927 L

.18936 .56927 L

.19122 .56927 L

.19308 .56927 L

.19494 .56927 L

.1968 .56927 L

.19866 .56927 L

.20052 .56927 L

.20238 .56927 L

.20424 .56927 L

.2061 .56927 L

.20796 .56927 L

.20982 .56927 L

Mistroke

.21168 .56927 L

.21354 .56927 L

.2154 .56927 L

.21726 .56927 L

.21912 .56927 L

.22098 .56927 L

.22284 .56927 L

.2247 .56927 L

.22656 .56927 L

.22842 .56927 L

.23028 .56927 L

.23214 .56927 L

.234 .56927 L

.23586 .56927 L

.23772 .56927 L

.23958 .56927 L

.24144 .56927 L

.2433 .56927 L

.24516 .56927 L

.24702 .56927 L

.24888 .56927 L

.25074 .56927 L

.2526 .56927 L

.25446 .56927 L

.25632 .56927 L

.25818 .56927 L

.26004 .56927 L

.2619 .56927 L

.26376 .56884 L

.26563 .56884 L

.26749 .56884 L

.26935 .56884 L

.27121 .56884 L

.27307 .56884 L

.27493 .56884 L

.27679 .56884 L

.27865 .56884 L

.28051 .56884 L

.28237 .56884 L

.28423 .56884 L

.28609 .56884 L

.28795 .56884 L

.28981 .56884 L

.29167 .56884 L

.29353 .56884 L

.29539 .56884 L

.29725 .56884 L

.29911 .56884 L

.30097 .56884 L

.30283 .56884 L

Mistroke

.30469 .56884 L

.30655 .56884 L

.30841 .56884 L

.31027 .56884 L

.31213 .56884 L

.31399 .56884 L

.31585 .56884 L

.31771 .56884 L

.31957 .56884 L

.32143 .56884 L

.32329 .56884 L

.32515 .56884 L

.32701 .56884 L

.32887 .56884 L

.33073 .56884 L

.33259 .56884 L

.33445 .56884 L

.33631 .56884 L

.33817 .56884 L

.34003 .56884 L

.34189 .56884 L

.34375 .56884 L

.34561 .56884 L

.34747 .56884 L

.34933 .56884 L

.35119 .56884 L

.35305 .56884 L

.35491 .56884 L

.35677 .56884 L

.35863 .56884 L

.36049 .56884 L

.36235 .56884 L

.36421 .56884 L

.36607 .56884 L

.36793 .56884 L

.36979 .56884 L

.37165 .56884 L

.37351 .56884 L

.37537 .56884 L

.37723 .56884 L

.37909 .56884 L

.38095 .56884 L

.38281 .46614 L

.38467 .46614 L

.38653 .46614 L

.38839 .46614 L

.39025 .46614 L

.39211 .46614 L

.39397 .46614 L

.39583 .46614 L

Mistroke

.39769 .46614 L

.39955 .46614 L

.40141 .46614 L

.40327 .46614 L

.40513 .46614 L

.40699 .46614 L

.40885 .46614 L

.41071 .46614 L

.41257 .46614 L

.41443 .46614 L

.41629 .46614 L

.41815 .46614 L

.42001 .46614 L

.42188 .46614 L

.42374 .46614 L

.4256 .46614 L

.42746 .46614 L

.42932 .46614 L

.43118 .46614 L

.43304 .46614 L

.4349 .46614 L

.43676 .46614 L

.43862 .46614 L

.44048 .46614 L

.44234 .36741 L

.4442 .36741 L

.44606 .36741 L

.44792 .36741 L

.44978 .36741 L

.45164 .36741 L

.4535 .36741 L

.45536 .36741 L

.45722 .36741 L

.45908 .36741 L

.46094 .36741 L

.4628 .36741 L

.46466 .36741 L

.46652 .36741 L

.46838 .36741 L

.47024 .36741 L

.4721 .36741 L

.47396 .36741 L

.47582 .36741 L

.47768 .36741 L

.47954 .36741 L

.4814 .36741 L

.48326 .36741 L

.48512 .36741 L

.48698 .36741 L

.48884 .36741 L

Mistroke

.4907 .36741 L

.49256 .36741 L

.49442 .36741 L

.49628 .36741 L

.49814 .36741 L

.5 .36741 L

.50186 .25506 L

.50372 .25506 L

.50558 .25506 L

.50744 .25506 L

.5093 .25506 L

.51116 .25506 L

.51302 .25506 L

.51488 .25506 L

.51674 .25506 L

.5186 .25506 L

.52046 .25506 L

.52232 .25506 L

.52418 .25506 L

.52604 .25506 L

.5279 .25506 L

.52976 .25506 L

.53162 .25506 L

.53348 .25506 L

.53534 .25506 L

.5372 .25506 L

.53906 .25506 L

.54092 .25506 L

.54278 .25506 L

.54464 .25506 L

.5465 .25506 L

.54836 .25506 L

.55022 .25506 L

.55208 .25506 L

.55394 .25506 L

.5558 .25506 L

.55766 .25506 L

.55952 .25506 L

.56138 .14461 L

.56324 .14461 L

.5651 .14461 L

.56696 .14461 L

.56882 .14461 L

.57068 .14461 L

.57254 .14461 L

.5744 .14461 L

.57626 .14461 L

.57813 .14461 L

.57999 .14461 L

.58185 .14461 L

Mistroke

.58371 .14461 L

.58557 .14461 L

.58743 .14461 L

.58929 .14461 L

.59115 .14461 L

.59301 .14461 L

.59487 .14461 L

.59673 .14461 L

.59859 .14461 L

.60045 .14461 L

.60231 .14461 L

.60417 .14461 L

.60603 .14461 L

.60789 .14461 L

.60975 .14461 L

.61161 .14461 L

.61347 .14461 L

.61533 .14461 L

.61719 .14461 L

.61905 .14461 L

.62091 .05062 L

.62277 .05062 L

.62463 .05062 L

.62649 .05062 L

.62835 .05062 L

.63021 .05062 L

.63207 .05062 L

.63393 .05062 L

.63579 .05062 L

.63765 .05062 L

.63951 .05062 L

.64137 .05062 L

.64323 .05062 L

.64509 .05062 L

.64695 .05062 L

.64881 .05062 L

.65067 .05062 L

.65253 .05062 L

.65439 .05062 L

.65625 .05062 L

.65811 .05062 L

.65997 .05062 L

.66183 .05062 L

.66369 .05062 L

.66555 .05062 L

.66741 .05062 L

.66927 .05062 L

.67113 .05062 L

.67299 .05062 L

.67485 .05062 L

Mistroke

.67671 .05062 L

.67857 .05062 L

.68043 .05062 L

.68229 .05062 L

.68415 .05062 L

.68601 .05062 L

.68787 .05062 L

.68973 .05062 L

.69159 .05062 L

.69345 .05062 L

.69531 .05062 L

.69717 .05062 L

.69903 .05062 L

.70089 .05062 L

.70275 .05062 L

.70461 .05062 L

.70647 .05062 L

.70833 .05062 L

.71019 .05062 L

.71205 .05062 L

.71391 .05062 L

.71577 .05062 L

.71763 .05062 L

.71949 .05062 L

.72135 .05062 L

.72321 .05062 L

.72507 .05062 L

.72693 .05062 L

.72879 .05062 L

.73065 .05062 L

.73251 .05062 L

.73438 .05062 L

.73624 .05062 L

.7381 .05062 L

.73996 .04181 L

.74182 .04181 L

.74368 .04181 L

.74554 .04181 L

.7474 .04181 L

.74926 .04181 L

.75112 .04181 L

.75298 .04181 L

.75484 .04181 L

.7567 .04181 L

.75856 .04181 L

.76042 .04181 L

.76228 .04181 L

.76414 .04181 L

.766 .04181 L

.76786 .04181 L

Mistroke

.76972 .04181 L

.77158 .04181 L

.77344 .04181 L

.7753 .04181 L

.77716 .04181 L

.77902 .04181 L

.78088 .04181 L

.78274 .04181 L

.7846 .04181 L

.78646 .04181 L

.78832 .04181 L

.79018 .04181 L

.79204 .04181 L

.7939 .04181 L

.79576 .04181 L

.79762 .04181 L

.79948 .04181 L

.80134 .04181 L

.8032 .04181 L

.80506 .04181 L

.80692 .04181 L

.80878 .04181 L

.81064 .04181 L

.8125 .04181 L

.81436 .04181 L

.81622 .04181 L

.81808 .04181 L

.81994 .04181 L

.8218 .04181 L

.82366 .04181 L

.82552 .04181 L

.82738 .04181 L

.82924 .04181 L

.8311 .04181 L

.83296 .04181 L

.83482 .04181 L

.83668 .04181 L

.83854 .04181 L

.8404 .04181 L

.84226 .04181 L

.84412 .04181 L

.84598 .04181 L

.84784 .04181 L

.8497 .04181 L

.85156 .04181 L

.85342 .04181 L

.85528 .04181 L

.85714 .04181 L

.859 .14347 L

.86086 .14347 L

Mistroke

.86272 .14347 L

.86458 .14347 L

.86644 .14347 L

.8683 .14347 L

.87016 .14347 L

.87202 .14347 L

.87388 .14347 L

.87574 .14347 L

.8776 .14347 L

.87946 .14347 L

.88132 .14347 L

.88318 .14347 L

.88504 .14347 L

.8869 .14347 L

.88876 .14347 L

.89063 .14347 L

.89249 .14347 L

.89435 .14347 L

.89621 .14347 L

.89807 .14347 L

.89993 .14347 L

.90179 .14347 L

.90365 .14347 L

.90551 .14347 L

.90737 .14347 L

.90923 .14347 L

.91109 .14347 L

.91295 .14347 L

.91481 .14347 L

.91667 .14347 L

.91853 .27382 L

.92039 .27382 L

.92225 .27382 L

.92411 .27382 L

.92597 .27382 L

.92783 .27382 L

.92969 .27382 L

.93155 .27382 L

.93341 .27382 L

.93527 .27382 L

.93713 .27382 L

.93899 .27382 L

.94085 .27382 L

.94271 .27382 L

.94457 .27382 L

.94643 .27382 L

.94829 .27382 L

.95015 .27382 L

.95201 .27382 L

.95387 .27382 L

Mistroke

.95573 .27382 L

.95759 .27382 L

.95945 .27382 L

.96131 .27382 L

.96317 .27382 L

.96503 .27382 L

.96689 .27382 L

.96875 .27382 L

.97061 .27382 L

.97247 .27382 L

.97433 .27382 L

.97619 .27382 L

Mfstroke

0 0 1 r

.02567 .30902 m

.02753 .31263 L

.02939 .31624 L

.03125 .31985 L

.03311 .32346 L

.03497 .32706 L

.03683 .33067 L

.03869 .33427 L

.04055 .33786 L

.04241 .34146 L

.04427 .34504 L

.04613 .34862 L

.04799 .3522 L

.04985 .35577 L

.05171 .35933 L

.05357 .36289 L

.05543 .36643 L

.05729 .36997 L

.05915 .3735 L

.06101 .37702 L

.06287 .38053 L

.06473 .38402 L

.06659 .38751 L

.06845 .39099 L

.07031 .39445 L

.07217 .3979 L

.07403 .40133 L

.07589 .40476 L

.07775 .40816 L

.07961 .41156 L

.08147 .41493 L

.08333 .4183 L

.08519 .42164 L

.08705 .42497 L

.08891 .42828 L

.09077 .43157 L

.09263 .43485 L

.09449 .4381 L

.09635 .44134 L

.09821 .44455 L

.10007 .44775 L

.10193 .45092 L

.10379 .45408 L

.10565 .45721 L

.10751 .46032 L

.10937 .4634 L

.11124 .46647 L

.1131 .46951 L

.11496 .47252 L

.11682 .47551 L

Mistroke

.11868 .47848 L

.12054 .48142 L

.1224 .48433 L

.12426 .48722 L

.12612 .49008 L

.12798 .49291 L

.12984 .49572 L

.1317 .4985 L

.13356 .50125 L

.13542 .50397 L

.13728 .50666 L

.13914 .50932 L

.141 .51195 L

.14286 .51455 L

.14472 .51712 L

.14658 .51966 L

.14844 .52216 L

.1503 .52464 L

.15216 .52708 L

.15402 .52949 L

.15588 .53186 L

.15774 .53421 L

.1596 .53652 L

.16146 .53879 L

.16332 .54103 L

.16518 .54323 L

.16704 .5454 L

.1689 .54754 L

.17076 .54963 L

.17262 .5517 L

.17448 .55372 L

.17634 .55571 L

.1782 .55766 L

.18006 .55957 L

.18192 .56145 L

.18378 .56329 L

.18564 .56509 L

.1875 .56685 L

.18936 .56857 L

.19122 .57025 L

.19308 .57189 L

.19494 .5735 L

.1968 .57506 L

.19866 .57659 L

.20052 .57807 L

.20238 .57951 L

.20424 .58092 L

.2061 .58228 L

.20796 .5836 L

.20982 .58488 L

Mistroke

.21168 .58612 L

.21354 .58731 L

.2154 .58846 L

.21726 .58958 L

.21912 .59065 L

.22098 .59167 L

.22284 .59266 L

.2247 .5936 L

.22656 .5945 L

.22842 .59536 L

.23028 .59617 L

.23214 .59694 L

.234 .59766 L

.23586 .59835 L

.23772 .59899 L

.23958 .59958 L

.24144 .60013 L

.2433 .60064 L

.24516 .60111 L

.24702 .60153 L

.24888 .6019 L

.25074 .60223 L

.2526 .60252 L

.25446 .60277 L

.25632 .60296 L

.25818 .60312 L

.26004 .60323 L

.2619 .6033 L

.26376 .60332 L

.26563 .6033 L

.26749 .60323 L

.26935 .60312 L

.27121 .60296 L

.27307 .60277 L

.27493 .60252 L

.27679 .60223 L

.27865 .6019 L

.28051 .60153 L

.28237 .60111 L

.28423 .60064 L

.28609 .60013 L

.28795 .59958 L

.28981 .59899 L

.29167 .59835 L

.29353 .59766 L

.29539 .59694 L

.29725 .59617 L

.29911 .59536 L

.30097 .5945 L

.30283 .5936 L

Mistroke

.30469 .59266 L

.30655 .59167 L

.30841 .59065 L

.31027 .58958 L

.31213 .58846 L

.31399 .58731 L

.31585 .58612 L

.31771 .58488 L

.31957 .5836 L

.32143 .58228 L

.32329 .58092 L

.32515 .57951 L

.32701 .57807 L

.32887 .57659 L

.33073 .57506 L

.33259 .5735 L

.33445 .57189 L

.33631 .57025 L

.33817 .56857 L

.34003 .56685 L

.34189 .56509 L

.34375 .56329 L

.34561 .56145 L

.34747 .55957 L

.34933 .55766 L

.35119 .55571 L

.35305 .55372 L

.35491 .5517 L

.35677 .54963 L

.35863 .54754 L

.36049 .5454 L

.36235 .54323 L

.36421 .54103 L

.36607 .53879 L

.36793 .53652 L

.36979 .53421 L

.37165 .53186 L

.37351 .52949 L

.37537 .52708 L

.37723 .52464 L

.37909 .52216 L

.38095 .51966 L

.38281 .51712 L

.38467 .51455 L

.38653 .51195 L

.38839 .50932 L

.39025 .50666 L

.39211 .50397 L

.39397 .50125 L

.39583 .4985 L

Mistroke

.39769 .49572 L

.39955 .49291 L

.40141 .49008 L

.40327 .48722 L

.40513 .48433 L

.40699 .48142 L

.40885 .47848 L

.41071 .47551 L

.41257 .47252 L

.41443 .46951 L

.41629 .46647 L

.41815 .4634 L

.42001 .46032 L

.42188 .45721 L

.42374 .45408 L

.4256 .45092 L

.42746 .44775 L

.42932 .44455 L

.43118 .44134 L

.43304 .4381 L

.4349 .43485 L

.43676 .43157 L

.43862 .42828 L

.44048 .42497 L

.44234 .42164 L

.4442 .4183 L

.44606 .41493 L

.44792 .41156 L

.44978 .40816 L

.45164 .40476 L

.4535 .40133 L

.45536 .3979 L

.45722 .39445 L

.45908 .39099 L

.46094 .38751 L

.4628 .38402 L

.46466 .38053 L

.46652 .37702 L

.46838 .3735 L

.47024 .36997 L

.4721 .36643 L

.47396 .36289 L

.47582 .35933 L

.47768 .35577 L

.47954 .3522 L

.4814 .34862 L

.48326 .34504 L

.48512 .34146 L

.48698 .33786 L

.48884 .33427 L

Mistroke

.4907 .33067 L

.49256 .32706 L

.49442 .32346 L

.49628 .31985 L

.49814 .31624 L

.5 .31263 L

.50186 .30902 L

.50372 .30541 L

.50558 .30179 L

.50744 .29818 L

.5093 .29458 L

.51116 .29097 L

.51302 .28737 L

.51488 .28377 L

.51674 .28017 L

.5186 .27658 L

.52046 .27299 L

.52232 .26941 L

.52418 .26583 L

.52604 .26226 L

.5279 .2587 L

.52976 .25515 L

.53162 .2516 L

.53348 .24806 L

.53534 .24454 L

.5372 .24102 L

.53906 .23751 L

.54092 .23401 L

.54278 .23052 L

.54464 .22705 L

.5465 .22359 L

.54836 .22014 L

.55022 .2167 L

.55208 .21328 L

.55394 .20987 L

.5558 .20648 L

.55766 .2031 L

.55952 .19974 L

.56138 .19639 L

.56324 .19306 L

.5651 .18975 L

.56696 .18646 L

.56882 .18319 L

.57068 .17993 L

.57254 .1767 L

.5744 .17348 L

.57626 .17028 L

.57813 .16711 L

.57999 .16396 L

.58185 .16082 L

Mistroke

.58371 .15772 L

.58557 .15463 L

.58743 .15157 L

.58929 .14853 L

.59115 .14551 L

.59301 .14252 L

.59487 .13956 L

.59673 .13662 L

.59859 .1337 L

.60045 .13081 L

.60231 .12795 L

.60417 .12512 L

.60603 .12231 L

.60789 .11954 L

.60975 .11679 L

.61161 .11407 L

.61347 .11138 L

.61533 .10871 L

.61719 .10608 L

.61905 .10348 L

.62091 .10091 L

.62277 .09838 L

.62463 .09587 L

.62649 .0934 L

.62835 .09095 L

.63021 .08854 L

.63207 .08617 L

.63393 .08383 L

.63579 .08152 L

.63765 .07924 L

.63951 .07701 L

.64137 .0748 L

.64323 .07263 L

.64509 .0705 L

.64695 .0684 L

.64881 .06634 L

.65067 .06431 L

.65253 .06233 L

.65439 .06037 L

.65625 .05846 L

.65811 .05659 L

.65997 .05475 L

.66183 .05295 L

.66369 .05119 L

.66555 .04947 L

.66741 .04778 L

.66927 .04614 L

.67113 .04454 L

.67299 .04297 L

.67485 .04145 L

Mistroke

.67671 .03996 L

.67857 .03852 L

.68043 .03712 L

.68229 .03576 L

.68415 .03444 L

.68601 .03316 L

.68787 .03192 L

.68973 .03072 L

.69159 .02957 L

.69345 .02846 L

.69531 .02739 L

.69717 .02636 L

.69903 .02538 L

.70089 .02443 L

.70275 .02353 L

.70461 .02268 L

.70647 .02187 L

.70833 .0211 L

.71019 .02037 L

.71205 .01969 L

.71391 .01905 L

.71577 .01845 L

.71763 .0179 L

.71949 .01739 L

.72135 .01693 L

.72321 .01651 L

.72507 .01613 L

.72693 .0158 L

.72879 .01551 L

.73065 .01527 L

.73251 .01507 L

.73438 .01491 L

.73624 .0148 L

.7381 .01474 L

.73996 .01472 L

.74182 .01474 L

.74368 .0148 L

.74554 .01491 L

.7474 .01507 L

.74926 .01527 L

.75112 .01551 L

.75298 .0158 L

.75484 .01613 L

.7567 .01651 L

.75856 .01693 L

.76042 .01739 L

.76228 .0179 L

.76414 .01845 L

.766 .01905 L

.76786 .01969 L

Mistroke

.76972 .02037 L

.77158 .0211 L

.77344 .02187 L

.7753 .02268 L

.77716 .02353 L

.77902 .02443 L

.78088 .02538 L

.78274 .02636 L

.7846 .02739 L

.78646 .02846 L

.78832 .02957 L

.79018 .03072 L

.79204 .03192 L

.7939 .03316 L

.79576 .03444 L

.79762 .03576 L

.79948 .03712 L

.80134 .03852 L

.8032 .03996 L

.80506 .04145 L

.80692 .04297 L

.80878 .04454 L

.81064 .04614 L

.8125 .04778 L

.81436 .04947 L

.81622 .05119 L

.81808 .05295 L

.81994 .05475 L

.8218 .05659 L

.82366 .05846 L

.82552 .06037 L

.82738 .06233 L

.82924 .06431 L

.8311 .06634 L

.83296 .0684 L

.83482 .0705 L

.83668 .07263 L

.83854 .0748 L

.8404 .07701 L

.84226 .07924 L

.84412 .08152 L

.84598 .08383 L

.84784 .08617 L

.8497 .08854 L

.85156 .09095 L

.85342 .0934 L

.85528 .09587 L

.85714 .09838 L

.859 .10091 L

.86086 .10348 L

Mistroke

.86272 .10608 L

.86458 .10871 L

.86644 .11138 L

.8683 .11407 L

.87016 .11679 L

.87202 .11954 L

.87388 .12231 L

.87574 .12512 L

.8776 .12795 L

.87946 .13081 L

.88132 .1337 L

.88318 .13662 L

.88504 .13956 L

.8869 .14252 L

.88876 .14551 L

.89063 .14853 L

.89249 .15157 L

.89435 .15463 L

.89621 .15772 L

.89807 .16082 L

.89993 .16396 L

.90179 .16711 L

.90365 .17028 L

.90551 .17348 L

.90737 .1767 L

.90923 .17993 L

.91109 .18319 L

.91295 .18646 L

.91481 .18975 L

.91667 .19306 L

.91853 .19639 L

.92039 .19974 L

.92225 .2031 L

.92411 .20648 L

.92597 .20987 L

.92783 .21328 L

.92969 .2167 L

.93155 .22014 L

.93341 .22359 L

.93527 .22705 L

.93713 .23052 L

.93899 .23401 L

.94085 .23751 L

.94271 .24102 L

.94457 .24454 L

.94643 .24806 L

.94829 .2516 L

.95015 .25515 L

.95201 .2587 L

.95387 .26226 L

Mistroke

.95573 .26583 L

.95759 .26941 L

.95945 .27299 L

.96131 .27658 L

.96317 .28017 L

.96503 .28377 L

.96689 .28737 L

.96875 .29097 L

.97061 .29458 L

.97247 .29818 L

.97433 .30179 L

.97619 .30541 L

Mfstroke

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{413, 255.063},

  ImageMargins->{{27, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006M0000oa000`40O003h00OogooWWoo003oOonN

Ool00?mooiioo`00ogooWWoo003oOonNOol00?mooiioo`0077oo00<007ooOol0ogooOgoo000LOol0

0`00Oomoo`3oOomoOol001aoo`03001oogoo0?moogmoo`0077oo00<007ooOol0ogooOgoo000COol5

0004Ool00`00Oomoo`3oOomoOol001Eoo`03001oogoo00Aoo`03001oogoo0?moogmoo`003goo0`00

0goo00<007ooOol017oo1000ogoo4Goo300OHGoo000EOol00`00Oomoo`04Ool00`00Oomoo`3oOol>

Ool501l:Ool501mMOol001Eoo`03001oogoo00Aoo`03001oogoo0?moo`]oo`<07aAoo`<07eYoo`00

57oo0P001Woo00<007ooOol0ogoo2Goo0P0O6Woo0P0OF7oo000LOol00`00Oomoo`3oOol7Ool201lN

Ool201mFOol001aoo`03001oogoo0?moo`Eoo`<07b1oo`<07eAoo`0077oo00<007ooOol0ogoo17oo

00<07gooOol08goo0P0ODgoo000LOol00`00Oomoo`3oOol2Ool201lXOol201mAOol001aoo`03001o

ogoo0?moo`5oo`807bYoo`807e1oo`0077oo00<007ooOol0oWoo0P0O;Woo0P0OCWoo000LOol00`00

Oomoo`3mOol201l`Ool201m=Ool001aoo`03001oogoo0?aoo`0301moogoo01Mooa]l000301ml07`0

015l03Uoo`0077oo0`00ngoo00<07gooOol067oo00=l07ooOol067oo0P0O4Goo00=l07ooOol0=goo

000LOol00`00Oomoo`3jOol00`0OOomoo`0IOol00g`0Oomoo`0JOol00`0OOomoo`0>Ool00g`0Oomo

o`0gOol001aoo`03001oogoo0>Qooa5l000301ml07`001]l01eoo`0301moogoo00eoo`03O01oogoo

03Moo`0077oo00<007ooOol0j7oo00=l07ooOol03Goo00<07gooOol0>Woo00<07gooOol037oo00=l

07ooOol0=goo000LOol00`00Oomoo`3XOol00g`0Oomoo`0;Ool201lnOol201l<Ool00g`0Oomoo`0g

Ool001aoo`03001oogoo0>Qoo`03O01oogoo00]oo`0301moogoo03ioo`0301moogoo00Yoo`03O01o

ogoo03Moo`0077oo00<007ooOol0j7oo00=l07ooOol02Woo00<07gooOol0@7oo00<07gooOol02Goo

00=l07ooOol0=goo000LOol00`00Oomoo`3XOol00g`0Oomoo`08Ool201m4Ool00`0OOomoo`08Ool0

0g`0Oomoo`0gOol001aoo`03001oogoo0>Qoo`03O01oogoo00Qoo`0301moogoo04Aoo`0301moogoo

00Moo`03O01oogoo03Moo`0077oo00<007ooOol0j7oo00=l07ooOol01goo00<07gooOol0AWoo00<0

7gooOol01Woo00=l07ooOol0=goo000LOol00`00Oomoo`3XOol00g`0Oomoo`06Ool00`0OOomoo`18

Ool00`0OOomoo`05Ool00g`0Oomoo`0gOol001aoo`<00>Qoo`03O01oogoo00Eoo`0301moogoo04Uo

o`0301moogoo00Eoo`03O01oogoo03Moo`0077oo00<007ooOol0j7oo00=l07ooOol017oo0P0OC7oo

0P0O1Goo00=l07ooOol0=goo000LOol00`00Oomoo`3XOol00g`0Oomoo`03Ool00`0OOomoo`1>Ool0

0`0OOomoo`02Ool00g`0Oomoo`0gOol001aoo`03001oogoo0>Qoo`03O01oogoo00=oo`0301moogoo

04ioo`0301moogoo009oo`03O01oogoo03Moo`0077oo00<007ooOol0j7oo00=l07ooOol00Woo00<0

7gooOol0D7oo00D07gooOomoog`003Uoo`0077oo00<007ooOol0j7oo00El07ooOomoo`0O05Aoo`04

01moogooO00iOol001aoo`03001oogoo0>Qoo`04O01oogoo01mFOol00`0OOoml000iOol001aoo`03

001oogoo0>Qoo`04O01oogoo01mFOol00`0OOoml000iOol001aoo`03001oogoo0>Qoo`03O01oo`0O

05Qoo`0301ml07oo03Qoo`0077oo00<007ooOol0j7oo00=l000OOol0FGoo00<07g`0Ool0=goo000L

Ool00`00Oomoo`3WOol00g`001moo`1JOol00`0OO01oo`0gOol001aoo`03001oogoo0>Moo`03O000

7goo05]oo`0301moogoo03Ioo`0077oo0`00igoo00<07gooOol0Fgoo00=l000OOol0=Woo000LOol0

0`00Oomoo`3VOol00`0OO01oo`1LOol00g`0Ool07`0fOol001aoo`03001oogoo0>Ioo`0301ml07oo

05aoo`03O01oo`0O03Ioo`0077oo00<007ooOol0iGoo00<07gooO000GGoo00Al07ooOol07cEoo`00

77oo00<007ooOol0i7oo00@07gooOoml05eoo`05O01oogooOol07`0dOol001aoo`03001oogoo0>=o

o`0501moogooOoml001MOol00g`0Oomoo`02Ool00`0OOomoo`0aOol001aoo`03001oogoo0>=oo`05

01moogooOoml001MOol00g`0Oomoo`02Ool00`0OOomoo`0aOol001aoo`03001oogoo0>9oo`0301mo

ogoo009oo`03O01oogoo05]oo`03O01oogoo00=oo`0301moogoo031oo`0077oo00<007ooOol0hGoo

00<07gooOol00goo00=l07ooOol0Fgoo00=l07ooOol017oo00<07gooOol0;goo000LOol00`00Oomo

o`3POol00`0OOomoo`04Ool00g`0Oomoo`1KOol00g`0Oomoo`04Ool00`0OOomoo`0_Ool001aoo`03

001oogoo0>1oo`0301moogoo00Aoo`03O01oogoo05]oo`03O01oogoo00Aoo`0301moogoo02moo`00

77oo0`00h7oo00<07gooOol017oo00=l07ooOol0Fgoo00=l07ooOol01Goo00<07gooOol0;Woo000L

Ool00`00Oomoo`3OOol00`0OOomoo`05Ool00g`0Oomoo`1KOol00g`0Oomoo`06Ool00`0OOomoo`0]

Ool001aoo`03001oogoo0=ioo`0301moogoo00Ioo`03O01oogoo05]oo`03O01oogoo00Moo`0301mo

ogoo02aoo`0077oo00<007ooOol0gWoo00<07gooOol01Woo00=l07ooOol0Fgoo00=l07ooOol01goo

00<07gooOol0;7oo000LOol00`00Oomoo`3MOol00`0OOomoo`07Ool00g`0Oomoo`1KOol00g`0Oomo

o`08Ool00`0OOomoo`0[Ool001aoo`03001oogoo0=1oo`al000301ml07`000Ul05eoo`al000301ml

07`000Ul025oo`0077oo00<007ooOol0d7oo00=l07ooOol027oo00<07gooOol0M7oo00<07gooOol0

1goo00=l07ooOol07goo000LOol00`00Oomoo`3@Ool00g`0Oomoo`08Ool00`0OOomoo`1dOol00`0O

Oomoo`07Ool00g`0Oomoo`0OOol001aoo`03001oogoo0=1oo`03O01oogoo00Qoo`0301moogoo07Ao

o`0301moogoo00Moo`03O01oogoo01moo`0077oo00<007ooOol0d7oo00=l07ooOol01goo00<07goo

Ool0MWoo00<07gooOol01Woo00=l07ooOol07goo000;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0

0`00Oomoo`04Ool00`00Oomoo`3@Ool00g`0Oomoo`06Ool00`0OOomoo`1hOol00`0OOomoo`05Ool0

0g`0Oomoo`0OOol000Yoo`03001oo`0000Moo`03001oo`0000Eoo`03001oogoo0=1oo`03O01oogoo

00Eoo`0301moogoo07Uoo`0301moogoo00Eoo`03O01oogoo01moo`001Goo0`000Woo00<007oo0000

2Goo00<007ooOol00goo1000cgoo00=l07ooOol01Goo00<07gooOol0NGoo00<07gooOol01Goo00=l

07ooOol07goo000:Ool00`00Ool00007Ool20006Ool00`00Oomoo`3@Ool00g`0Oomoo`05Ool00`0O

Oomoo`1jOol00`0OOomoo`04Ool00g`0Oomoo`0OOol000Yoo`03001oo`0000Moo`03001oogoo00Eo

o`03001oogoo0=1oo`03O01oogoo00Aoo`0301moogoo07aoo`0301moogoo00=oo`03O01oogoo01mo

o`002goo00<007ooOol01Woo0`001Goo00<007ooOol0d7oo00=l07ooOol00goo00<07gooOol0OWoo

00<07gooOol00Woo00=l07ooOol07goo000LOol00`00Oomoo`3@Ool00g`0Oomoo`02Ool00`0OOomo

o`1oOol00`0OOomoo`02Ool00g`0Oomoo`0OOol001aoo`03001oogoo0=1oo`03O01oogoo009oo`03

01moogoo07moo`0301moogoo009oo`03O01oogoo01moo`0077oo00<007ooOol0d7oo00=l07ooOol0

0Woo00<07gooOol0P7oo00D07gooOomoog`0025oo`0077oo00<007ooOol0d7oo00El07ooOomoo`0O

08Aoo`0401moogooO00QOol001aoo`03001oogoo0=1oo`04O01oogoo01n6Ool00`0OOoml000QOol0

01aoo`03001oogoo0=1oo`04O01oogoo01n6Ool00`0OOoml000QOol001aoo`03001oogoo0=1oo`03

O01oo`0O08Moo`0301moog`0025oo`0077oo0`00d7oo00=l07oo01l0R7oo00<07g`0Ool087oo000L

Ool00`00Oomoo`3@Ool00g`001moo`29Ool00`0OOomoo`0OOol001aoo`03001oogoo0=1oo`0301mo

ogoo08Uoo`03O0007goo01moo`0077oo00<007ooOol0d7oo00<07gooOol0RGoo00=l000OOol07goo

000LOol00`00Oomoo`3@Ool00`0OOomoo`29Ool00g`001moo`0OOol001aoo`03001oogoo0<moo`03

01ml07oo08Yoo`03O01oo`0O01moo`0077oo00<007ooOol0cWoo00<07gooO000Rgoo00Al07ooOol0

7aioo`0077oo00<007ooOol0cGoo00@07gooOoml08]oo`04O01oogoo01lNOol001aoo`03001oogoo

0<eoo`0401moogooO02<Ool00g`0Ool07`0NOol001aoo`03001oogoo0<eoo`0401moogooO02<Ool0

17`0Oomoo`0O7Goo000LOol00`00Oomoo`3<Ool01@0OOomoogooO000S7oo00El07ooOomoo`0O01ao

o`0077oo00<007ooOol0bgoo00<07gooOol00Woo00=l07ooOol0RWoo00El07ooOomoo`0O01aoo`00

77oo0`00bgoo00<07gooOol00Woo00=l07ooOol0RWoo00=l07ooOol00Woo00<07gooOol06Goo000L

Ool00`00Oomoo`3;Ool00`0OOomoo`02Ool00g`0Oomoo`2:Ool00g`0Oomoo`02Ool00`0OOomoo`0I

Ool001aoo`03001oogoo0<Yoo`0301moogoo00=oo`03O01oogoo08Yoo`03O01oogoo00=oo`0301mo

ogoo01Qoo`0077oo00<007ooOol0bGoo00<07gooOol017oo00=l07ooOol0RWoo00=l07ooOol00goo

00<07gooOol067oo000LOol00`00Oomoo`39Ool00`0OOomoo`04Ool00g`0Oomoo`2:Ool00g`0Oomo

o`04Ool00`0OOomoo`0GOol001aoo`03001oogoo0<Qoo`0301moogoo00Eoo`03O01oogoo08Yoo`03

O01oogoo00Eoo`0301moogoo01Ioo`0077oo00<007ooOol0b7oo00<07gooOol01Goo00=l07ooOol0

RWoo00=l07ooOol01Goo00<07gooOol05Woo000LOol00`00Oomoo`37Ool00`0OOomoo`06Ool00g`0

Oomoo`2:Ool00g`0Oomoo`05Ool00`0OOomoo`0FOol001aoo`03001oogoo0<Moo`0301moogoo00Io

o`03O01oogoo08Yoo`03O01oogoo00Ioo`0301moogoo01Eoo`0077oo00<007ooOol0aWoo00<07goo

Ool01goo00=l07ooOol0RWoo00=l07ooOol01goo00<07gooOol057oo000LOol00`00Oomoo`35Ool0

0`0OOomoo`08Ool00g`0Oomoo`2:Ool00g`0Oomoo`07Ool00`0OOomoo`0DOol001aoo`<00<Eoo`03

01moogoo00Qoo`03O01oogoo08Yoo`03O01oogoo00Moo`0301moogoo01Aoo`0077oo00<007ooOol0

aGoo00<07gooOol027oo00=l07ooOol0RWoo00=l07ooOol027oo00<07gooOol04goo000LOol00`00

Oomoo`2iOol;O0000`0OO01l000:O02<Ool00g`0Oomoo`09Ool00`0OOomoo`0BOol001aoo`03001o

ogoo0;Uoo`03O01oogoo00Moo`0301moogoo09Moo`03O01oogoo00Uoo`0301moogoo019oo`0077oo

00<007ooOol0^Goo00=l07ooOol01goo00<07gooOol0Ugoo00=l07ooOol02Woo00<07gooOol04Goo

000LOol00`00Oomoo`2iOol00g`0Oomoo`07Ool00`0OOomoo`2GOol00g`0Oomoo`0:Ool00`0OOomo

o`0AOol001aoo`03001oogoo0;Uoo`03O01oogoo00Ioo`0301moogoo09Qoo`03O01oogoo00Yoo`03

01moogoo015oo`0077oo00<007ooOol0^Goo00=l07ooOol01Woo00<07gooOol0V7oo00=l07ooOol0

2goo00<07gooOol047oo000LOol00`00Oomoo`2iOol00g`0Oomoo`05Ool00`0OOomoo`2IOol00g`0

Oomoo`0<Ool00`0OOomoo`0?Ool001aoo`03001oogoo0;Uoo`03O01oogoo00Aoo`0301moogoo09Yo

o`03O01oogoo00eoo`0301moogoo00ioo`0077oo00<007ooOol0^Goo00=l07ooOol017oo00<07goo

Ool0VWoo47`000<07g`0O00017`02Woo000LOol00`00Oomoo`0oOol50002Ool00`00Oomoo`02Ool0

0`00Oomoo`0kOol30003Ool00`00Oomoo`02Ool00`00Oomoo`0ROol00g`0Oomoo`04Ool00`0OOomo

o`0?Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0lOol30002Ool00`00Oomoo`02Ool00`00Oomo

o`0lOol00`00Oomoo`02Ool01P00Oomoo`0OOol000ioo`0077oo0`00@Goo00L007ooOomoo`00Ool0

0002Ool00`00Ool0000lOol00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool0000SOol00g`0Oomo

o`03Ool00`0OOomoo`0BOol01P00Oomoo`00Ool0009oo`03001oo`0003ioo`06001oogoo001oo`00

0Woo00<007oo0000?7oo00<007oo00000Woo00<007oo00000Woo00<07goo00003Goo000LOol00`00

Oomoo`11Ool01`00Oomoogoo001oo`00009oo`03001oo`0003eoo`07001oogooOol007oo00000Woo

00<007oo00008goo00=l07ooOol00Woo00<07gooOol04Woo00L007ooOomoo`00Ool00002Ool00`00

Ool0000lOol4000017oo001oo`000Woo00<007oo0000?Woo00H007ooOol007oo0002Ool00`0OOol0

000=Ool001aoo`03001oogoo045oo`07001oogooOol007oo00000Woo00<007oo0000?Goo00L007oo

Oomoo`00Ool00002Ool00`00Ool0000SOol00g`0Oomoo`02Ool00`0OOomoo`0COol01P00Oomoo`00

Ool0009oo`03001oo`0003aoo`03001oo`00009oo`03001oo`00009oo`03001oo`0003aoo`8000=o

o`03001oo`00009oo`0300007`0000eoo`0077oo00<007ooOol0@Goo00L007ooOomoo`00Ool00002

Ool00`00Ool0000lOol00`00Ool00002Ool00`00Ool00002Ool00`00Ool0000SOol01G`0Oomoogoo

01l057oo00<007oo00000Woo00<007oo00000Woo00<007oo0000?Goo0P000Woo00<007oo00000Woo

00<007oo0000?7oo00<007ooOol00Woo00<007oo00000Woo00<007oo01l03Goo000LOol00`00Oomo

o`10Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0lOol00`00Oomoo`02Ool00`00Oomoo`02Ool0

0`00Oomoo`0ROol01G`0Oomoogoo01l05Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0

?Goo00D007ooOomoo`0000Aoo`03001oogoo03]oo`<000=oo`03001oogoo009oo`0300007goo00ao

o`0077oo00<007ooOol0^Goo00Al07ooOol07k=oo`0301moogoo00]oo`0077oo00<007ooOol0^Goo

00Al07ooOol07kAoo`0301moogoo00Yoo`0077oo00<007ooOol0^Goo00=l07oo01l0]Woo00<07goo

Ool02Goo000LOol00`00Oomoo`2iOol00g`001moo`2fOol00`0OOomoo`09Ool001aoo`03001oogoo

0;Uoo`03O0007goo0;Ioo`0301moogoo00Uoo`0077oo00<007ooOol0^Goo00=l000OOol0]goo00<0

7gooOol027oo000COol:00000`0O0000002h00000`0O00000032000001aoo`0300007goo00aoo`03

001oogoo00aoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00aoo`03

001oogoo00aoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00aoo`03

001oogoo00aoo`03001oogoo00Qoo`0401moogoo000>Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool0

0`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool0

0`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool0

0`00Oomoo`02Ool001aoo`03001oo`0O00aoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo

00aoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo

00aoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00Qoo`0401moogoo

000>Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomo

o`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomo

o`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool001aoo`04001oogoo01m5Ool0

0`00Oomoo`16Ool00`00Oomoo`0VOol00`0OOomoo`0MOol00`00Oomoo`16Ool00`00Oomoo`16Ool0

0`00Oomoo`0AOol001aoo`04001oogoo01nfOol00`0OO01oo`34Ool001aoo`04001oogoo01nfOol0

0`0OO01oo`34Ool001aoo`05001oogooOol07`2dOol00`0OOoml0035Ool001aoo`05001oogooOol0

7`2cOol0100OOomoog`0aGoo000LOol00`00Oomoo`02Ool00`0OOomoo`2`Ool0100OOomoog`0aGoo

000LOol00`00Oomoo`03Ool00`0OOomoo`2_Ool0100OOomoog`0aGoo000LOol00`00Oomoo`03Ool0

0`0OOomoo`2^Ool01@0OOomoogooO000aGoo000LOol00`00Oomoo`03Ool00`0OOomoo`2]Ool00`0O

Oomoo`02Ool00g`0Oomoo`33Ool001aoo`<000Aoo`0301moogoo0:aoo`0301moogoo009oo`03O01o

ogoo0<=oo`0077oo00<007ooOol01Goo00<07gooOol0ZWoo00<07gooOol00goo00=l07ooOol0`goo

000LOol00`00Oomoo`05Ool00`0OOomoo`2ZOol00`0OOomoo`03Ool00g`0Oomoo`33Ool001aoo`03

001oogoo00Eoo`0301moogoo0:Yoo`0301moogoo00=oo`03O01oogoo0<=oo`0077oo00<007ooOol0

1Woo00<07gooOol0Z7oo00<07gooOol017oo00=l07ooOol0`goo000LOol00`00Oomoo`07Ool00`0O

Oomoo`2VOol00`0OOomoo`05Ool00g`0Oomoo`33Ool001aoo`03001oogoo00Moo`0301moogoo0:Io

o`0301moogoo00Eoo`03O01oogoo0<=oo`0077oo00<007ooOol027oo00<07gooOol0YGoo00<07goo

Ool01Goo00=l07ooOol0`goo000LOol00`00Oomoo`08Ool00`0OOomoo`2TOol00`0OOomoo`06Ool0

0g`0Oomoo`33Ool001aoo`03001oogoo00Qoo`0301moogoo0:=oo`0301moogoo00Moo`03O01oogoo

0<=oo`0077oo00<007ooOol02Goo00<07gooOol0XWoo00<07gooOol01goo00=l07ooOol0`goo000L

Ool00`00Oomoo`0:Ool00`0OOomoo`2EOol;O0000`0OO01l0009O035Ool001aoo`03001l07`000]l

000301ml07`000Ql08aoo`03O01oogoo00Qoo`0301moogoo0<ioo`0077oo00<007ooOol02goo00<0

7gooOol01goo00=l07ooOol0RWoo00=l07ooOol01goo00<07gooOol0cgoo000LOol00`00Oomoo`0;

Ool00`0OOomoo`07Ool00g`0Oomoo`2:Ool00g`0Oomoo`07Ool00`0OOomoo`3?Ool001aoo`03001o

ogoo00aoo`0301moogoo00Ioo`03O01oogoo08Yoo`03O01oogoo00Ioo`0301moogoo0=1oo`0077oo

00<007ooOol037oo00<07gooOol01Woo00=l07ooOol0RWoo00=l07ooOol01Goo00<07gooOol0dGoo

000LOol00`00Oomoo`0=Ool00`0OOomoo`05Ool00g`0Oomoo`2:Ool00g`0Oomoo`05Ool00`0OOomo

o`3AOol001aoo`03001oogoo00eoo`0301moogoo00Eoo`03O01oogoo08Yoo`03O01oogoo00Eoo`03

01moogoo0=5oo`0077oo00<007ooOol03Woo00<07gooOol017oo00=l07ooOol0RWoo00=l07ooOol0

17oo00<07gooOol0dWoo000LOol00`00Oomoo`0>Ool00`0OOomoo`04Ool00g`0Oomoo`2:Ool00g`0

Oomoo`03Ool00`0OOomoo`3COol001aoo`03001oogoo00moo`0301moogoo00=oo`03O01oogoo08Yo

o`03O01oogoo00=oo`0301moogoo0==oo`0077oo00<007ooOol047oo00<07gooOol00Woo00=l07oo

Ool0RWoo00=l07ooOol00Woo00<07gooOol0e7oo000LOol3000@Ool00`0OOomoo`02Ool00g`0Oomo

o`2:Ool00g`0Oomoo`02Ool00`0OOomoo`3DOol001aoo`03001oogoo011oo`0301moogoo009oo`03

O01oogoo08Yoo`05O01oogooOol07`3GOol001aoo`03001oogoo015oo`0501moogooOoml002<Ool0

1G`0Oomoogoo01l0egoo000LOol00`00Oomoo`0BOol0100OOomoog`0S7oo00Al07ooOol07mQoo`00

77oo00<007ooOol04goo00<07gooO000S7oo00Al07ooOol07mQoo`0077oo00<007ooOol04goo00<0

7gooO000S7oo00=l07oo01l0fGoo000LOol00`00Oomoo`0COol00`0OOoml002<Ool00g`0Ool07`3I

Ool001aoo`03001oogoo01Aoo`0301ml07oo08]oo`03O0007goo0=Uoo`0077oo00<007ooOol05Goo

00<07gooOol0RGoo00=l000OOol0fWoo000LOol00`00Oomoo`0EOol00`0OOomoo`29Ool00g`001mo

o`3JOol001aoo`03001oogoo01Eoo`0301moogoo08Uoo`03O0007goo0=Yoo`0077oo00<007ooOol0

5Goo00=l000OOol0RGoo00<07gooOol0fWoo000LOol3000EOol00g`0Ool07`28Ool00`0OO01oo`3K

Ool001aoo`03001oogoo01Eoo`03O01oo`0O08Moo`0301moog`00=aoo`0077oo00<007ooOol05Goo

00Al07ooOol07hIoo`0301moog`00=aoo`0077oo00<007ooOol05Goo00Al07ooOol07hIoo`0301mo

og`00=aoo`0077oo00<007ooOol05Goo00El07ooOomoo`0O08Aoo`0401moogooO03LOol001aoo`03

001oogoo01Eoo`03O01oogoo009oo`0301moogoo081oo`0501moogooOoml003LOol001aoo`03001o

ogoo01Eoo`03O01oogoo009oo`0301moogoo081oo`0501moogooOoml003LOol001aoo`03001oogoo

01Eoo`03O01oogoo00=oo`0301moogoo07moo`0501moogooOoml003LOol001aoo`03001oogoo01Eo

o`03O01oogoo00=oo`0301moogoo07ioo`0301moogoo009oo`03O01oogoo0=Yoo`002goo00<007oo

Ool00Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol05Goo00=l07ooOol017oo00<07goo

Ool0O7oo00<07gooOol00goo00=l07ooOol0fWoo000:Ool00`00Ool00007Ool00`00Ool00005Ool0

0`00Oomoo`0EOol00g`0Oomoo`05Ool00`0OOomoo`1jOol00`0OOomoo`04Ool00g`0Oomoo`3JOol0

00Yoo`03001oo`0000Uoo`03001oogoo00=oo`@001Aoo`03O01oogoo00Eoo`0301moogoo07Yoo`03

01moogoo00Aoo`03O01oogoo0=Yoo`002Woo00<007oo00001goo0P001Woo00<007ooOol05Goo00=l

07ooOol01Woo00<07gooOol0NGoo00<07gooOol017oo00=l07ooOol0fWoo000:Ool00`00Ool00007

Ool00`00Oomoo`05Ool00`00Oomoo`0EOol00g`0Oomoo`06Ool00`0OOomoo`1hOol00`0OOomoo`05

Ool00g`0Oomoo`3JOol000]oo`03001oogoo00Ioo`<000Eoo`03001oogoo01Eoo`Yl000301ml07`0

00]l06]oo`0301moogoo00Ioo`03O01oogoo0=Yoo`0077oo00<007ooOol087oo00<07gooOol02Goo

00=l07ooOol0Fgoo3G`000<07g`0O00027`0g7oo000LOol00`00Oomoo`0POol00`0OOomoo`09Ool0

0g`0Oomoo`1KOol00g`0Oomoo`0:Ool00`0OOomoo`3TOol001aoo`03001oogoo021oo`0301moogoo

00Uoo`03O01oogoo05]oo`03O01oogoo00Uoo`0301moogoo0>Eoo`0077oo00<007ooOol08Goo00<0

7gooOol027oo00=l07ooOol0Fgoo00=l07ooOol02Goo00<07gooOol0iGoo000LOol00`00Oomoo`0R

Ool00`0OOomoo`07Ool00g`0Oomoo`1KOol00g`0Oomoo`08Ool00`0OOomoo`3VOol001aoo`03001o

ogoo02=oo`0301moogoo00Ioo`03O01oogoo05]oo`03O01oogoo00Qoo`0301moogoo0>Ioo`0077oo

00<007ooOol08goo00<07gooOol01Woo00=l07ooOol0Fgoo00=l07ooOol01goo00<07gooOol0igoo

000LOol00`00Oomoo`0TOol00`0OOomoo`05Ool00g`0Oomoo`1KOol00g`0Oomoo`06Ool00`0OOomo

o`3XOol001aoo`<002Eoo`0301moogoo00Aoo`03O01oogoo05]oo`03O01oogoo00Eoo`0301moogoo

0>Uoo`0077oo00<007ooOol09Goo00<07gooOol017oo00=l07ooOol0Fgoo00=l07ooOol01Goo00<0

7gooOol0jGoo000LOol00`00Oomoo`0VOol00`0OOomoo`03Ool00g`0Oomoo`1KOol00g`0Oomoo`05

Ool00`0OOomoo`3YOol001aoo`03001oogoo02Ioo`0301moogoo00=oo`03O01oogoo05]oo`03O01o

ogoo00Aoo`0301moogoo0>Yoo`0077oo00<007ooOol09goo00<07gooOol00Woo00=l07ooOol0Fgoo

00=l07ooOol00goo00<07gooOol0jgoo000LOol00`00Oomoo`0XOol01@0OOomoogooO000GGoo00=l

07ooOol00Woo00<07gooOol0k7oo000LOol00`00Oomoo`0XOol01@0OOomoogooO000GGoo00=l07oo

Ool00Woo00<07gooOol0k7oo000LOol00`00Oomoo`0YOol0100OOomoog`0GGoo00El07ooOomoo`0O

0>moo`0077oo00<007ooOol0:Woo00<07gooO000GGoo00Al07ooOol07o1oo`0077oo00<007ooOol0

:goo00<07g`0Ool0G7oo00=l07oo01l0lGoo000LOol00`00Oomoo`0[Ool00`0OO01oo`1LOol00g`0

Ool07`3aOol001aoo`<002aoo`0301moogoo05]oo`03O0007goo0?5oo`0077oo00<007ooOol0;7oo

00=l000OOol0Fgoo00<07gooOol0lGoo000LOol00`00Oomoo`0]Ool00g`001moo`1JOol00`0OOomo

o`3aOol001aoo`03001oogoo02eoo`03O0007goo05Uoo`0301ml07oo0?9oo`0077oo00<007ooOol0

;Goo00=l07oo01l0F7oo00<07gooO000lgoo000LOol00`00Oomoo`0]Ool017`0Oomoo`0OEWoo00@0

7gooOoml0?=oo`0077oo00<007ooOol0;Goo00El07ooOomoo`0O05Eoo`0401moogooO03cOol001ao

o`03001oogoo02eoo`05O01oogooOol07`1DOol01@0OOomoogooO000lgoo000LOol00`00Oomoo`0]

Ool00g`0Oomoo`02Ool00`0OOomoo`1@Ool00`0OOomoo`02Ool00g`0Oomoo`3aOol001aoo`03001o

ogoo02eoo`03O01oogoo00=oo`0301moogoo04ioo`0301moogoo00=oo`03O01oogoo0?5oo`0077oo

00<007ooOol0;Goo00=l07ooOol00goo00<07gooOol0CWoo00<07gooOol00goo00=l07ooOol0lGoo

000LOol00`00Oomoo`0]Ool00g`0Oomoo`04Ool201m<Ool201l6Ool00g`0Oomoo`3aOol001aoo`<0

02eoo`03O01oogoo00Ioo`0301moogoo04Uoo`0301moogoo00Eoo`03O01oogoo0?5oo`0077oo00<0

07ooOol0;Goo00=l07ooOol01Woo00<07gooOol0B7oo00<07gooOol01Woo00=l07ooOol0lGoo000L

Ool00`00Oomoo`0]Ool00g`0Oomoo`07Ool00`0OOomoo`16Ool00`0OOomoo`07Ool00g`0Oomoo`3a

Ool001aoo`03001oogoo02eoo`03O01oogoo00Qoo`807dEoo`0301moogoo00Qoo`03O01oogoo0?5o

o`0077oo00<007ooOol0;Goo00=l07ooOol02Goo00<07gooOol0@Woo00<07gooOol02Goo00=l07oo

Ool0lGoo000LOol00`00Oomoo`0]Ool00g`0Oomoo`0:Ool00`0OOomoo`10Ool00`0OOomoo`0:Ool0

0g`0Oomoo`3aOol001aoo`03001oogoo02eoo`03O01oogoo00]oo`0301moogoo03ioo`0301moogoo

00]oo`03O01oogoo0?5oo`0077oo00<007ooOol0;Goo00=l07ooOol02goo0P0O?Woo0P0O3Goo00=l

07ooOol0lGoo000LOol00`00Oomoo`0]Ool00g`0Oomoo`0=Ool00`0OOomoo`0jOol00`0OOomoo`0=

Ool00g`0Oomoo`3aOol001aoo`03001oogoo02eoo`03O01oogoo00ioo`0301moogoo01]ooael0080

7a1l0?=oo`0077oo00<007ooOol0;Goo4W`000<07g`0O0006W`077oo00<07gooOol0ogoo17oo000L

Ool30010Ool201leOol00`0OOomoo`3oOol5Ool001aoo`03001oogoo045oo`807c9oo`807omoo`Qo

o`0077oo00<007ooOol0@goo00<07gooOol0;Woo00<07gooOol0ogoo27oo000LOol00`00Oomoo`13

Ool201l^Ool201ooOol:Ool001aoo`03001oogoo04Eoo`807bYoo`807omoo`aoo`0077oo00<007oo

Ool0AWoo0P0O:7oo0P0Oogoo3Goo000LOol00`00Oomoo`18Ool201lUOol00`0OOomoo`3oOol=Ool0

01aoo`03001oogoo04Uoo`<07b1oo`<07omooa1oo`0077oo00<007ooOol0C7oo00<07gooOol077oo

0P0Oogoo4Woo000LOol00`00Oomoo`1=Ool301lHOol301ooOolDOol001=oo`D000Aoo`03001oogoo

051oo`<07a9oo`<07omooaMoo`005Goo00<007ooOol017oo00<007ooOol0Dgoo100O2Woo100Oogoo

6Woo000EOol00`00Oomoo`04Ool4001EOol<01ooOolMOol001Eoo`03001oogoo00Aoo`03001oogoo

0?moogmoo`005Goo00<007ooOol017oo00<007ooOol0ogooOgoo000DOol20006Ool00`00Oomoo`3o

OomoOol001aoo`03001oogoo0?moogmoo`0077oo00<007ooOol0ogooOgoo000LOol00`00Oomoo`3o

OomoOol00?mooiioo`00ogooWWoo003oOonNOol00?mooiioo`00ogooWWoo0000\

\>"],

  ImageRangeCache->{{{0, 412}, {254.063, 0}} -> {-39.6002, -1.0999, 1.36991, 

  0.00865844}}]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{



Cell["A worse (or better) smooth?", "Subsubtitle"],



Cell["\<\

Though we keep more coefficients, the smooth here seems to be worse. However, \

note that it is actually better in the middle. We happened to keep the \

coefficients of those wavelets that are approximating the middle of the plot \

range. Perhaps simple thresholding is not the best way to denoise.\

\>", "Text"],



Cell[CellGroupData[{



Cell[BoxData[

    \(swdata2\  = \ thresh[wdata,  .5]\)], "Input"],



Cell[BoxData[

    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0.549509373939600642`, 0, 0, 

      0.776151873726004204`, 0, 0, 0, 0, 0, 0, 0, 0, 0.651234733463280424`, 

      1.34183460162570122`, 1.50108201979227402`, 0, 0, 0, 0, 

      2.92281199433181981`, 2.86810968799443912`, 0, 0, 0, 

      14.1306966394984261`, 0}\)], "Output"]

}, Open  ]],



Cell[BoxData[

    \(\(sdata2\  = \ IDWT[swdata2]; \)\)], "Input"],



Cell[CellGroupData[{



Cell[BoxData[

    \(Plot2Lists[sdata2, udata]\)], "Input"],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.00186012 0.309017 0.294302 [

[.20982 .29652 -9 -9 ]

[.20982 .29652 9 0 ]

[.39583 .29652 -9 -9 ]

[.39583 .29652 9 0 ]

[.58185 .29652 -9 -9 ]

[.58185 .29652 9 0 ]

[.76786 .29652 -9 -9 ]

[.76786 .29652 9 0 ]

[.95387 .29652 -9 -9 ]

[.95387 .29652 9 0 ]

[.01131 .01472 -12 -4.5 ]

[.01131 .01472 0 4.5 ]

[.01131 .16187 -24 -4.5 ]

[.01131 .16187 0 4.5 ]

[.01131 .45617 -18 -4.5 ]

[.01131 .45617 0 4.5 ]

[.01131 .60332 -6 -4.5 ]

[.01131 .60332 0 4.5 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.20982 .30902 m

.20982 .31527 L

s

[(100)] .20982 .29652 0 1 Mshowa

.39583 .30902 m

.39583 .31527 L

s

[(200)] .39583 .29652 0 1 Mshowa

.58185 .30902 m

.58185 .31527 L

s

[(300)] .58185 .29652 0 1 Mshowa

.76786 .30902 m

.76786 .31527 L

s

[(400)] .76786 .29652 0 1 Mshowa

.95387 .30902 m

.95387 .31527 L

s

[(500)] .95387 .29652 0 1 Mshowa

.125 Mabswid

.06101 .30902 m

.06101 .31277 L

s

.09821 .30902 m

.09821 .31277 L

s

.13542 .30902 m

.13542 .31277 L

s

.17262 .30902 m

.17262 .31277 L

s

.24702 .30902 m

.24702 .31277 L

s

.28423 .30902 m

.28423 .31277 L

s

.32143 .30902 m

.32143 .31277 L

s

.35863 .30902 m

.35863 .31277 L

s

.43304 .30902 m

.43304 .31277 L

s

.47024 .30902 m

.47024 .31277 L

s

.50744 .30902 m

.50744 .31277 L

s

.54464 .30902 m

.54464 .31277 L

s

.61905 .30902 m

.61905 .31277 L

s

.65625 .30902 m

.65625 .31277 L

s

.69345 .30902 m

.69345 .31277 L

s

.73065 .30902 m

.73065 .31277 L

s

.80506 .30902 m

.80506 .31277 L

s

.84226 .30902 m

.84226 .31277 L

s

.87946 .30902 m

.87946 .31277 L

s

.91667 .30902 m

.91667 .31277 L

s

.99107 .30902 m

.99107 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

.02381 .01472 m

.03006 .01472 L

s

[(-1)] .01131 .01472 1 0 Mshowa

.02381 .16187 m

.03006 .16187 L

s

[(-0.5)] .01131 .16187 1 0 Mshowa

.02381 .45617 m

.03006 .45617 L

s

[(0.5)] .01131 .45617 1 0 Mshowa

.02381 .60332 m

.03006 .60332 L

s

[(1)] .01131 .60332 1 0 Mshowa

.125 Mabswid

.02381 .04415 m

.02756 .04415 L

s

.02381 .07358 m

.02756 .07358 L

s

.02381 .10301 m

.02756 .10301 L

s

.02381 .13244 m

.02756 .13244 L

s

.02381 .1913 m

.02756 .1913 L

s

.02381 .22073 m

.02756 .22073 L

s

.02381 .25016 m

.02756 .25016 L

s

.02381 .27959 m

.02756 .27959 L

s

.02381 .33845 m

.02756 .33845 L

s

.02381 .36788 m

.02756 .36788 L

s

.02381 .39731 m

.02756 .39731 L

s

.02381 .42674 m

.02756 .42674 L

s

.02381 .4856 m

.02756 .4856 L

s

.02381 .51503 m

.02756 .51503 L

s

.02381 .54446 m

.02756 .54446 L

s

.02381 .57389 m

.02756 .57389 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02567 .49281 m

.02753 .49281 L

.02939 .49281 L

.03125 .49281 L

.03311 .49281 L

.03497 .49281 L

.03683 .49281 L

.03869 .49281 L

.04055 .49281 L

.04241 .49281 L

.04427 .49281 L

.04613 .49281 L

.04799 .49281 L

.04985 .49281 L

.05171 .49281 L

.05357 .49281 L

.05543 .49281 L

.05729 .49281 L

.05915 .49281 L

.06101 .49281 L

.06287 .49281 L

.06473 .49281 L

.06659 .49281 L

.06845 .49281 L

.07031 .49281 L

.07217 .49281 L

.07403 .49281 L

.07589 .49281 L

.07775 .49281 L

.07961 .49281 L

.08147 .49281 L

.08333 .49281 L

.08519 .49281 L

.08705 .49281 L

.08891 .49281 L

.09077 .49281 L

.09263 .49281 L

.09449 .49281 L

.09635 .49281 L

.09821 .49281 L

.10007 .49281 L

.10193 .49281 L

.10379 .49281 L

.10565 .49281 L

.10751 .49281 L

.10937 .49281 L

.11124 .49281 L

.1131 .49281 L

.11496 .49281 L

.11682 .49281 L

Mistroke

.11868 .49281 L

.12054 .49281 L

.1224 .49281 L

.12426 .49281 L

.12612 .49281 L

.12798 .49281 L

.12984 .49281 L

.1317 .49281 L

.13356 .49281 L

.13542 .49281 L

.13728 .49281 L

.13914 .49281 L

.141 .49281 L

.14286 .49281 L

.14472 .49281 L

.14658 .49281 L

.14844 .49281 L

.1503 .49281 L

.15216 .49281 L

.15402 .49281 L

.15588 .49281 L

.15774 .49281 L

.1596 .49281 L

.16146 .49281 L

.16332 .49281 L

.16518 .49281 L

.16704 .49281 L

.1689 .49281 L

.17076 .49281 L

.17262 .49281 L

.17448 .49281 L

.17634 .49281 L

.1782 .49281 L

.18006 .49281 L

.18192 .49281 L

.18378 .49281 L

.18564 .49281 L

.1875 .49281 L

.18936 .49281 L

.19122 .49281 L

.19308 .49281 L

.19494 .49281 L

.1968 .49281 L

.19866 .49281 L

.20052 .49281 L

.20238 .49281 L

.20424 .49281 L

.2061 .49281 L

.20796 .49281 L

.20982 .49281 L

Mistroke

.21168 .49281 L

.21354 .49281 L

.2154 .49281 L

.21726 .49281 L

.21912 .49281 L

.22098 .49281 L

.22284 .49281 L

.2247 .49281 L

.22656 .49281 L

.22842 .49281 L

.23028 .49281 L

.23214 .49281 L

.234 .49281 L

.23586 .49281 L

.23772 .49281 L

.23958 .49281 L

.24144 .49281 L

.2433 .49281 L

.24516 .49281 L

.24702 .49281 L

.24888 .49281 L

.25074 .49281 L

.2526 .49281 L

.25446 .49281 L

.25632 .49281 L

.25818 .49281 L

.26004 .49281 L

.2619 .49281 L

.26376 .5928 L

.26563 .5928 L

.26749 .5928 L

.26935 .5928 L

.27121 .5928 L

.27307 .5928 L

.27493 .5928 L

.27679 .5928 L

.27865 .5928 L

.28051 .5928 L

.28237 .5928 L

.28423 .5928 L

.28609 .5928 L

.28795 .5928 L

.28981 .5928 L

.29167 .5928 L

.29353 .5928 L

.29539 .5928 L

.29725 .5928 L

.29911 .5928 L

.30097 .5928 L

.30283 .5928 L

Mistroke

.30469 .5928 L

.30655 .5928 L

.30841 .5928 L

.31027 .5928 L

.31213 .5928 L

.31399 .5928 L

.31585 .5928 L

.31771 .5928 L

.31957 .5928 L

.32143 .5928 L

.32329 .54488 L

.32515 .54488 L

.32701 .54488 L

.32887 .54488 L

.33073 .54488 L

.33259 .54488 L

.33445 .54488 L

.33631 .54488 L

.33817 .54488 L

.34003 .54488 L

.34189 .54488 L

.34375 .54488 L

.34561 .54488 L

.34747 .54488 L

.34933 .54488 L

.35119 .54488 L

.35305 .54488 L

.35491 .54488 L

.35677 .54488 L

.35863 .54488 L

.36049 .54488 L

.36235 .54488 L

.36421 .54488 L

.36607 .54488 L

.36793 .54488 L

.36979 .54488 L

.37165 .54488 L

.37351 .54488 L

.37537 .54488 L

.37723 .54488 L

.37909 .54488 L

.38095 .54488 L

.38281 .49473 L

.38467 .49473 L

.38653 .49473 L

.38839 .49473 L

.39025 .49473 L

.39211 .49473 L

.39397 .49473 L

.39583 .49473 L

Mistroke

.39769 .49473 L

.39955 .49473 L

.40141 .49473 L

.40327 .49473 L

.40513 .49473 L

.40699 .49473 L

.40885 .49473 L

.41071 .49473 L

.41257 .43755 L

.41443 .43755 L

.41629 .43755 L

.41815 .43755 L

.42001 .43755 L

.42188 .43755 L

.42374 .43755 L

.4256 .43755 L

.42746 .43755 L

.42932 .43755 L

.43118 .43755 L

.43304 .43755 L

.4349 .43755 L

.43676 .43755 L

.43862 .43755 L

.44048 .43755 L

.44234 .36741 L

.4442 .36741 L

.44606 .36741 L

.44792 .36741 L

.44978 .36741 L

.45164 .36741 L

.4535 .36741 L

.45536 .36741 L

.45722 .36741 L

.45908 .36741 L

.46094 .36741 L

.4628 .36741 L

.46466 .36741 L

.46652 .36741 L

.46838 .36741 L

.47024 .36741 L

.4721 .36741 L

.47396 .36741 L

.47582 .36741 L

.47768 .36741 L

.47954 .36741 L

.4814 .36741 L

.48326 .36741 L

.48512 .36741 L

.48698 .36741 L

.48884 .36741 L

Mistroke

.4907 .36741 L

.49256 .36741 L

.49442 .36741 L

.49628 .36741 L

.49814 .36741 L

.5 .36741 L

.50186 .25506 L

.50372 .25506 L

.50558 .25506 L

.50744 .25506 L

.5093 .25506 L

.51116 .25506 L

.51302 .25506 L

.51488 .25506 L

.51674 .25506 L

.5186 .25506 L

.52046 .25506 L

.52232 .25506 L

.52418 .25506 L

.52604 .25506 L

.5279 .25506 L

.52976 .25506 L

.53162 .25506 L

.53348 .25506 L

.53534 .25506 L

.5372 .25506 L

.53906 .25506 L

.54092 .25506 L

.54278 .25506 L

.54464 .25506 L

.5465 .25506 L

.54836 .25506 L

.55022 .25506 L

.55208 .25506 L

.55394 .25506 L

.5558 .25506 L

.55766 .25506 L

.55952 .25506 L

.56138 .18499 L

.56324 .18499 L

.5651 .18499 L

.56696 .18499 L

.56882 .18499 L

.57068 .18499 L

.57254 .18499 L

.5744 .18499 L

.57626 .18499 L

.57813 .18499 L

.57999 .18499 L

.58185 .18499 L

Mistroke

.58371 .18499 L

.58557 .18499 L

.58743 .18499 L

.58929 .18499 L

.59115 .10423 L

.59301 .10423 L

.59487 .10423 L

.59673 .10423 L

.59859 .10423 L

.60045 .10423 L

.60231 .10423 L

.60417 .10423 L

.60603 .10423 L

.60789 .10423 L

.60975 .10423 L

.61161 .10423 L

.61347 .10423 L

.61533 .10423 L

.61719 .10423 L

.61905 .10423 L

.62091 .05062 L

.62277 .05062 L

.62463 .05062 L

.62649 .05062 L

.62835 .05062 L

.63021 .05062 L

.63207 .05062 L

.63393 .05062 L

.63579 .05062 L

.63765 .05062 L

.63951 .05062 L

.64137 .05062 L

.64323 .05062 L

.64509 .05062 L

.64695 .05062 L

.64881 .05062 L

.65067 .05062 L

.65253 .05062 L

.65439 .05062 L

.65625 .05062 L

.65811 .05062 L

.65997 .05062 L

.66183 .05062 L

.66369 .05062 L

.66555 .05062 L

.66741 .05062 L

.66927 .05062 L

.67113 .05062 L

.67299 .05062 L

.67485 .05062 L

Mistroke

.67671 .05062 L

.67857 .05062 L

.68043 .05062 L

.68229 .05062 L

.68415 .05062 L

.68601 .05062 L

.68787 .05062 L

.68973 .05062 L

.69159 .05062 L

.69345 .05062 L

.69531 .05062 L

.69717 .05062 L

.69903 .05062 L

.70089 .05062 L

.70275 .05062 L

.70461 .05062 L

.70647 .05062 L

.70833 .05062 L

.71019 .05062 L

.71205 .05062 L

.71391 .05062 L

.71577 .05062 L

.71763 .05062 L

.71949 .05062 L

.72135 .05062 L

.72321 .05062 L

.72507 .05062 L

.72693 .05062 L

.72879 .05062 L

.73065 .05062 L

.73251 .05062 L

.73438 .05062 L

.73624 .05062 L

.7381 .05062 L

.73996 .12523 L

.74182 .12523 L

.74368 .12523 L

.74554 .12523 L

.7474 .12523 L

.74926 .12523 L

.75112 .12523 L

.75298 .12523 L

.75484 .12523 L

.7567 .12523 L

.75856 .12523 L

.76042 .12523 L

.76228 .12523 L

.76414 .12523 L

.766 .12523 L

.76786 .12523 L

Mistroke

.76972 .12523 L

.77158 .12523 L

.77344 .12523 L

.7753 .12523 L

.77716 .12523 L

.77902 .12523 L

.78088 .12523 L

.78274 .12523 L

.7846 .12523 L

.78646 .12523 L

.78832 .12523 L

.79018 .12523 L

.79204 .12523 L

.7939 .12523 L

.79576 .12523 L

.79762 .12523 L

.79948 .12523 L

.80134 .12523 L

.8032 .12523 L

.80506 .12523 L

.80692 .12523 L

.80878 .12523 L

.81064 .12523 L

.8125 .12523 L

.81436 .12523 L

.81622 .12523 L

.81808 .12523 L

.81994 .12523 L

.8218 .12523 L

.82366 .12523 L

.82552 .12523 L

.82738 .12523 L

.82924 .12523 L

.8311 .12523 L

.83296 .12523 L

.83482 .12523 L

.83668 .12523 L

.83854 .12523 L

.8404 .12523 L

.84226 .12523 L

.84412 .12523 L

.84598 .12523 L

.84784 .12523 L

.8497 .12523 L

.85156 .12523 L

.85342 .12523 L

.85528 .12523 L

.85714 .12523 L

.859 .12523 L

.86086 .12523 L

Mistroke

.86272 .12523 L

.86458 .12523 L

.86644 .12523 L

.8683 .12523 L

.87016 .12523 L

.87202 .12523 L

.87388 .12523 L

.87574 .12523 L

.8776 .12523 L

.87946 .12523 L

.88132 .12523 L

.88318 .12523 L

.88504 .12523 L

.8869 .12523 L

.88876 .12523 L

.89063 .12523 L

.89249 .12523 L

.89435 .12523 L

.89621 .12523 L

.89807 .12523 L

.89993 .12523 L

.90179 .12523 L

.90365 .12523 L

.90551 .12523 L

.90737 .12523 L

.90923 .12523 L

.91109 .12523 L

.91295 .12523 L

.91481 .12523 L

.91667 .12523 L

.91853 .12523 L

.92039 .12523 L

.92225 .12523 L

.92411 .12523 L

.92597 .12523 L

.92783 .12523 L

.92969 .12523 L

.93155 .12523 L

.93341 .12523 L

.93527 .12523 L

.93713 .12523 L

.93899 .12523 L

.94085 .12523 L

.94271 .12523 L

.94457 .12523 L

.94643 .12523 L

.94829 .12523 L

.95015 .12523 L

.95201 .12523 L

.95387 .12523 L

Mistroke

.95573 .12523 L

.95759 .12523 L

.95945 .12523 L

.96131 .12523 L

.96317 .12523 L

.96503 .12523 L

.96689 .12523 L

.96875 .12523 L

.97061 .12523 L

.97247 .12523 L

.97433 .12523 L

.97619 .12523 L

Mfstroke

0 0 1 r

.02567 .30902 m

.02753 .31263 L

.02939 .31624 L

.03125 .31985 L

.03311 .32346 L

.03497 .32706 L

.03683 .33067 L

.03869 .33427 L

.04055 .33786 L

.04241 .34146 L

.04427 .34504 L

.04613 .34862 L

.04799 .3522 L

.04985 .35577 L

.05171 .35933 L

.05357 .36289 L

.05543 .36643 L

.05729 .36997 L

.05915 .3735 L

.06101 .37702 L

.06287 .38053 L

.06473 .38402 L

.06659 .38751 L

.06845 .39099 L

.07031 .39445 L

.07217 .3979 L

.07403 .40133 L

.07589 .40476 L

.07775 .40816 L

.07961 .41156 L

.08147 .41493 L

.08333 .4183 L

.08519 .42164 L

.08705 .42497 L

.08891 .42828 L

.09077 .43157 L

.09263 .43485 L

.09449 .4381 L

.09635 .44134 L

.09821 .44455 L

.10007 .44775 L

.10193 .45092 L

.10379 .45408 L

.10565 .45721 L

.10751 .46032 L

.10937 .4634 L

.11124 .46647 L

.1131 .46951 L

.11496 .47252 L

.11682 .47551 L

Mistroke

.11868 .47848 L

.12054 .48142 L

.1224 .48433 L

.12426 .48722 L

.12612 .49008 L

.12798 .49291 L

.12984 .49572 L

.1317 .4985 L

.13356 .50125 L

.13542 .50397 L

.13728 .50666 L

.13914 .50932 L

.141 .51195 L

.14286 .51455 L

.14472 .51712 L

.14658 .51966 L

.14844 .52216 L

.1503 .52464 L

.15216 .52708 L

.15402 .52949 L

.15588 .53186 L

.15774 .53421 L

.1596 .53652 L

.16146 .53879 L

.16332 .54103 L

.16518 .54323 L

.16704 .5454 L

.1689 .54754 L

.17076 .54963 L

.17262 .5517 L

.17448 .55372 L

.17634 .55571 L

.1782 .55766 L

.18006 .55957 L

.18192 .56145 L

.18378 .56329 L

.18564 .56509 L

.1875 .56685 L

.18936 .56857 L

.19122 .57025 L

.19308 .57189 L

.19494 .5735 L

.1968 .57506 L

.19866 .57659 L

.20052 .57807 L

.20238 .57951 L

.20424 .58092 L

.2061 .58228 L

.20796 .5836 L

.20982 .58488 L

Mistroke

.21168 .58612 L

.21354 .58731 L

.2154 .58846 L

.21726 .58958 L

.21912 .59065 L

.22098 .59167 L

.22284 .59266 L

.2247 .5936 L

.22656 .5945 L

.22842 .59536 L

.23028 .59617 L

.23214 .59694 L

.234 .59766 L

.23586 .59835 L

.23772 .59899 L

.23958 .59958 L

.24144 .60013 L

.2433 .60064 L

.24516 .60111 L

.24702 .60153 L

.24888 .6019 L

.25074 .60223 L

.2526 .60252 L

.25446 .60277 L

.25632 .60296 L

.25818 .60312 L

.26004 .60323 L

.2619 .6033 L

.26376 .60332 L

.26563 .6033 L

.26749 .60323 L

.26935 .60312 L

.27121 .60296 L

.27307 .60277 L

.27493 .60252 L

.27679 .60223 L

.27865 .6019 L

.28051 .60153 L

.28237 .60111 L

.28423 .60064 L

.28609 .60013 L

.28795 .59958 L

.28981 .59899 L

.29167 .59835 L

.29353 .59766 L

.29539 .59694 L

.29725 .59617 L

.29911 .59536 L

.30097 .5945 L

.30283 .5936 L

Mistroke

.30469 .59266 L

.30655 .59167 L

.30841 .59065 L

.31027 .58958 L

.31213 .58846 L

.31399 .58731 L

.31585 .58612 L

.31771 .58488 L

.31957 .5836 L

.32143 .58228 L

.32329 .58092 L

.32515 .57951 L

.32701 .57807 L

.32887 .57659 L

.33073 .57506 L

.33259 .5735 L

.33445 .57189 L

.33631 .57025 L

.33817 .56857 L

.34003 .56685 L

.34189 .56509 L

.34375 .56329 L

.34561 .56145 L

.34747 .55957 L

.34933 .55766 L

.35119 .55571 L

.35305 .55372 L

.35491 .5517 L

.35677 .54963 L

.35863 .54754 L

.36049 .5454 L

.36235 .54323 L

.36421 .54103 L

.36607 .53879 L

.36793 .53652 L

.36979 .53421 L

.37165 .53186 L

.37351 .52949 L

.37537 .52708 L

.37723 .52464 L

.37909 .52216 L

.38095 .51966 L

.38281 .51712 L

.38467 .51455 L

.38653 .51195 L

.38839 .50932 L

.39025 .50666 L

.39211 .50397 L

.39397 .50125 L

.39583 .4985 L

Mistroke

.39769 .49572 L

.39955 .49291 L

.40141 .49008 L

.40327 .48722 L

.40513 .48433 L

.40699 .48142 L

.40885 .47848 L

.41071 .47551 L

.41257 .47252 L

.41443 .46951 L

.41629 .46647 L

.41815 .4634 L

.42001 .46032 L

.42188 .45721 L

.42374 .45408 L

.4256 .45092 L

.42746 .44775 L

.42932 .44455 L

.43118 .44134 L

.43304 .4381 L

.4349 .43485 L

.43676 .43157 L

.43862 .42828 L

.44048 .42497 L

.44234 .42164 L

.4442 .4183 L

.44606 .41493 L

.44792 .41156 L

.44978 .40816 L

.45164 .40476 L

.4535 .40133 L

.45536 .3979 L

.45722 .39445 L

.45908 .39099 L

.46094 .38751 L

.4628 .38402 L

.46466 .38053 L

.46652 .37702 L

.46838 .3735 L

.47024 .36997 L

.4721 .36643 L

.47396 .36289 L

.47582 .35933 L

.47768 .35577 L

.47954 .3522 L

.4814 .34862 L

.48326 .34504 L

.48512 .34146 L

.48698 .33786 L

.48884 .33427 L

Mistroke

.4907 .33067 L

.49256 .32706 L

.49442 .32346 L

.49628 .31985 L

.49814 .31624 L

.5 .31263 L

.50186 .30902 L

.50372 .30541 L

.50558 .30179 L

.50744 .29818 L

.5093 .29458 L

.51116 .29097 L

.51302 .28737 L

.51488 .28377 L

.51674 .28017 L

.5186 .27658 L

.52046 .27299 L

.52232 .26941 L

.52418 .26583 L

.52604 .26226 L

.5279 .2587 L

.52976 .25515 L

.53162 .2516 L

.53348 .24806 L

.53534 .24454 L

.5372 .24102 L

.53906 .23751 L

.54092 .23401 L

.54278 .23052 L

.54464 .22705 L

.5465 .22359 L

.54836 .22014 L

.55022 .2167 L

.55208 .21328 L

.55394 .20987 L

.5558 .20648 L

.55766 .2031 L

.55952 .19974 L

.56138 .19639 L

.56324 .19306 L

.5651 .18975 L

.56696 .18646 L

.56882 .18319 L

.57068 .17993 L

.57254 .1767 L

.5744 .17348 L

.57626 .17028 L

.57813 .16711 L

.57999 .16396 L

.58185 .16082 L

Mistroke

.58371 .15772 L

.58557 .15463 L

.58743 .15157 L

.58929 .14853 L

.59115 .14551 L

.59301 .14252 L

.59487 .13956 L

.59673 .13662 L

.59859 .1337 L

.60045 .13081 L

.60231 .12795 L

.60417 .12512 L

.60603 .12231 L

.60789 .11954 L

.60975 .11679 L

.61161 .11407 L

.61347 .11138 L

.61533 .10871 L

.61719 .10608 L

.61905 .10348 L

.62091 .10091 L

.62277 .09838 L

.62463 .09587 L

.62649 .0934 L

.62835 .09095 L

.63021 .08854 L

.63207 .08617 L

.63393 .08383 L

.63579 .08152 L

.63765 .07924 L

.63951 .07701 L

.64137 .0748 L

.64323 .07263 L

.64509 .0705 L

.64695 .0684 L

.64881 .06634 L

.65067 .06431 L

.65253 .06233 L

.65439 .06037 L

.65625 .05846 L

.65811 .05659 L

.65997 .05475 L

.66183 .05295 L

.66369 .05119 L

.66555 .04947 L

.66741 .04778 L

.66927 .04614 L

.67113 .04454 L

.67299 .04297 L

.67485 .04145 L

Mistroke

.67671 .03996 L

.67857 .03852 L

.68043 .03712 L

.68229 .03576 L

.68415 .03444 L

.68601 .03316 L

.68787 .03192 L

.68973 .03072 L

.69159 .02957 L

.69345 .02846 L

.69531 .02739 L

.69717 .02636 L

.69903 .02538 L

.70089 .02443 L

.70275 .02353 L

.70461 .02268 L

.70647 .02187 L

.70833 .0211 L

.71019 .02037 L

.71205 .01969 L

.71391 .01905 L

.71577 .01845 L

.71763 .0179 L

.71949 .01739 L

.72135 .01693 L

.72321 .01651 L

.72507 .01613 L

.72693 .0158 L

.72879 .01551 L

.73065 .01527 L

.73251 .01507 L

.73438 .01491 L

.73624 .0148 L

.7381 .01474 L

.73996 .01472 L

.74182 .01474 L

.74368 .0148 L

.74554 .01491 L

.7474 .01507 L

.74926 .01527 L

.75112 .01551 L

.75298 .0158 L

.75484 .01613 L

.7567 .01651 L

.75856 .01693 L

.76042 .01739 L

.76228 .0179 L

.76414 .01845 L

.766 .01905 L

.76786 .01969 L

Mistroke

.76972 .02037 L

.77158 .0211 L

.77344 .02187 L

.7753 .02268 L

.77716 .02353 L

.77902 .02443 L

.78088 .02538 L

.78274 .02636 L

.7846 .02739 L

.78646 .02846 L

.78832 .02957 L

.79018 .03072 L

.79204 .03192 L

.7939 .03316 L

.79576 .03444 L

.79762 .03576 L

.79948 .03712 L

.80134 .03852 L

.8032 .03996 L

.80506 .04145 L

.80692 .04297 L

.80878 .04454 L

.81064 .04614 L

.8125 .04778 L

.81436 .04947 L

.81622 .05119 L

.81808 .05295 L

.81994 .05475 L

.8218 .05659 L

.82366 .05846 L

.82552 .06037 L

.82738 .06233 L

.82924 .06431 L

.8311 .06634 L

.83296 .0684 L

.83482 .0705 L

.83668 .07263 L

.83854 .0748 L

.8404 .07701 L

.84226 .07924 L

.84412 .08152 L

.84598 .08383 L

.84784 .08617 L

.8497 .08854 L

.85156 .09095 L

.85342 .0934 L

.85528 .09587 L

.85714 .09838 L

.859 .10091 L

.86086 .10348 L

Mistroke

.86272 .10608 L

.86458 .10871 L

.86644 .11138 L

.8683 .11407 L

.87016 .11679 L

.87202 .11954 L

.87388 .12231 L

.87574 .12512 L

.8776 .12795 L

.87946 .13081 L

.88132 .1337 L

.88318 .13662 L

.88504 .13956 L

.8869 .14252 L

.88876 .14551 L

.89063 .14853 L

.89249 .15157 L

.89435 .15463 L

.89621 .15772 L

.89807 .16082 L

.89993 .16396 L

.90179 .16711 L

.90365 .17028 L

.90551 .17348 L

.90737 .1767 L

.90923 .17993 L

.91109 .18319 L

.91295 .18646 L

.91481 .18975 L

.91667 .19306 L

.91853 .19639 L

.92039 .19974 L

.92225 .2031 L

.92411 .20648 L

.92597 .20987 L

.92783 .21328 L

.92969 .2167 L

.93155 .22014 L

.93341 .22359 L

.93527 .22705 L

.93713 .23052 L

.93899 .23401 L

.94085 .23751 L

.94271 .24102 L

.94457 .24454 L

.94643 .24806 L

.94829 .2516 L

.95015 .25515 L

.95201 .2587 L

.95387 .26226 L

Mistroke

.95573 .26583 L

.95759 .26941 L

.95945 .27299 L

.96131 .27658 L

.96317 .28017 L

.96503 .28377 L

.96689 .28737 L

.96875 .29097 L

.97061 .29458 L

.97247 .29818 L

.97433 .30179 L

.97619 .30541 L

Mfstroke

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{288, 177.938},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ

Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`006goo00<007ooOol0ogoo0goo000KOol0

0`00Oomoo`3oOol3Ool001=oo`D000=oo`03001oogoo0?moo`=oo`005Goo00<007ooOol00goo00<0

07ooOol0ogoo0goo000?Ool30003Ool00`00Oomoo`03Ool2002gOol<01m0Ool001Eoo`03001oogoo

00=oo`03001oogoo0;=oo`<07`]oo`@07ceoo`005Goo00<007ooOol00goo00<007ooOol0/Goo0P0O

4Goo0`0O>goo000DOol20005Ool00`00Oomoo`2_Ool201lEOol301liOol001]oo`03001oogoo0:eo

o`807aUoo`807cQoo`006goo00<007ooOol0[7oo0P0O77oo0P0O=Woo000KOol00`00Oomoo`2[Ool0

0`0OOomoo`0MOol201leOol001]oo`03001oogoo0:Yoo`0301moogoo021oo`0301moogoo039oo`00

6goo0P00ZWoo00<07gooOol08Woo00<07gooOol0<Goo000KOol00`00Oomoo`2LOol;O00201lCO00C

Ool201laOol001]oo`03001oogoo09aoo`03O01oogoo00Moo`807a=oo`03O01oogoo019oo`807c1o

o`006goo00<007ooOol0W7oo00=l07ooOol01Woo0P0O57oo00=l07ooOol04goo0P0O;goo000KOol0

0`00Oomoo`2LOol00g`0Oomoo`05Ool201lEOol00g`0Oomoo`0DOol201l^Ool001]oo`03001oogoo

09aoo`03O01oogoo00Aoo`807aIoo`03O01oogoo01Eoo`807beoo`006goo00<007ooOol0W7oo00=l

07ooOol017oo00<07gooOol05Goo00=l07ooOol05Woo00<07gooOol0:goo000KOol2002MOol00g`0

Oomoo`03Ool00`0OOomoo`0FOol00g`0Oomoo`0GOol00`0OOomoo`0ZOol001]oo`03001oogoo09ao

o`03O01oogoo009oo`0301moogoo01Moo`03O01oogoo01Qoo`0301moogoo02Uoo`006goo00<007oo

Ool0Vgoo00=l07ooOol00Woo00<07gooOol067oo00=l07ooOol06Goo00<07gooOol0:7oo000KOol0

0`00Oomoo`2KOol017`0Oomoogoo0P0O6Woo00=l07ooOol06Goo0P0O:Goo000KOol00`00Oomoo`2K

Ool00g`0Oomoo`0201lKOol00g`0Oomoo`0JOol201lXOol001]oo`03001oogoo09]oo`04O01oogoo

01lLOol00g`0Oomoo`0KOol00`0OOomoo`0VOol001]oo`03001oogoo09]oo`03O01oo`0O01eoo`03

O01oogoo01aoo`0301moogoo02Eoo`006goo00<007ooOol0Vgoo00=l000OOol07Goo00=l07ooOol0

77oo00<07gooOol09Goo000KOol2002LOol201lNOol00g`0Oomoo`0MOol00`0OOomoo`0TOol001]o

o`03001oogoo09Aoo`Ml000301moogoo01eoo`03O01oogoo01ioo`0301moogoo02=oo`006goo00<0

07ooOol0U7oo00=l07ooOol00goo00<07gooOol07Woo00=l07ooOol07Woo0P0O97oo000KOol00`00

Oomoo`2DOol00g`0Oomoo`02Ool00`0OOomoo`0OOol00g`0Oomoo`0OOol00`0OOomoo`0ROol001]o

o`03001oogoo09Aoo`03O01oogoo009oo`0301moogoo01moo`03O01oogoo021oo`0301moogoo025o

o`006goo00<007ooOol0U7oo00El07ooOomoo`0O029oo`03O01oogoo021oo`807b9oo`006goo00<0

07ooOol0U7oo00Al07ooOol07b=oobAl000301ml07`001Ul00Moo`006goo00<007ooOol0U7oo00Al

07ooOol07dQoo`0301moogoo01moo`006goo0P00UGoo00=l07oo01l0BGoo0P0O87oo000KOol00`00

Oomoo`2DOol00g`001moo`1:Ool00`0OOomoo`0NOol001]oo`03001oogoo09Aoo`03O0007goo04]o

o`0301moogoo01eoo`006goo00<007ooOol0U7oo00<07gooOol0Bgoo00<07gooOol07Goo000KOol0

0`00Oomoo`2COol201m>Ool00`0OOomoo`0LOol001]oo`03001oogoo09=oo`0301moogoo04ioo`03

01moogoo01]oo`002goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0

TWoo00<07g`0Ool0Cgoo00<07gooOol06goo000:Ool00`00Ool00007Ool00`00Ool00004Ool00`00

Oomoo`2BOol00`0OO01oo`1@Ool00`0OOomoo`0JOol000Eoo`<0009oo`03001oo`0000Uoo`03001o

ogoo009oo`80099oo`0301moog`0055oo`807a]oo`002Woo00<007oo00001goo0P001Goo00<007oo

Ool0T7oo00@07gooOoml059oo`0301moogoo01Uoo`002Woo00<007oo00001goo00<007ooOol017oo

00<007ooOol0T7oo00@07gooOoml05=oo`0301moogoo01Qoo`002goo00<007ooOol01Woo0`0017oo

00<007ooOol0Sgoo00D07gooOomoog`005=oo`0301moogoo01Qoo`006goo00<007ooOol0Sgoo00D0

7gooOomoog`005Aoo`0301moogoo01Moo`006goo00<007ooOol0SWoo00<07gooOol00Woo00=l07oo

Ool0DWoo00<07gooOol05goo000KOol00`00Oomoo`2<Ool00g`001l07`05O01EOol00`0OOomoo`0F

Ool001]oo`03001oogoo08aoo`03O0007goo05]oo`0301moogoo01Eoo`006goo0P00SGoo00<07goo

Ool0Fgoo00<07gooOol05Goo000KOol00`00Oomoo`2<Ool00`0OOomoo`1LOol00`0OOomoo`0DOol0

01]oo`03001oogoo08]oo`0301ml07oo05eoo`0301moogoo01Aoo`006goo00<007ooOol0Rgoo00<0

7g`0Ool0GWoo00<07gooOol04goo000KOol00`00Oomoo`2:Ool00`0OOoml001OOol00`0OOomoo`0C

Ool001]oo`03001oogoo08Yoo`0301moog`0061oo`0301moogoo019oo`006goo00<007ooOol0RGoo

00@07gooOoml061oo`807a=oo`006goo00<007ooOol0R7oo00D07gooOomoog`0065oo`0301moogoo

015oo`006goo0P00RGoo00@07gooOoml06=oo`0301moogoo011oo`006goo00<007ooOol0Qgoo00D0

7gooOomoog`006=oo`0301moogoo011oo`006goo00<007ooOol0Qgoo00D07gooOomoog`006Aoo`03

01moogoo00moo`006goo00<007ooOol0QWoo00<07gooOol00Woo00=l07ooOol0HWoo00<07gooOol0

3goo000KOol00`00Oomoo`26Ool00`0OOomoo`02Ool00g`0Oomoo`1SOol00`0OOomoo`0>Ool001]o

o`03001oogoo08Eoo`0301moogoo00=oo`03O01oogoo06=oo`0301moogoo00ioo`006goo00<007oo

Ool0QGoo00<07gooOol00goo00=l07ooOol0I7oo00<07gooOol03Goo000KOol20025Ool00`0OOomo

o`04Ool00g`0Oomoo`1TOol00`0OOomoo`0=Ool001]oo`03001oogoo08Aoo`0301moogoo00Aoo`03

O01oogoo06Eoo`0301moogoo00aoo`006goo00<007ooOol0O7oo1g`000<07g`0O0001W`0Igoo00<0

7gooOol037oo000KOol00`00Oomoo`1lOol00g`0Oomoo`04Ool00`0OOomoo`1^Ool00`0OOomoo`0;

Ool001]oo`03001oogoo07aoo`03O01oogoo00=oo`0301moogoo06moo`0301moogoo00]oo`006goo

00<007ooOol09goo1@000Woo00<007ooOol00Woo00<007ooOol08goo0`000goo00<007ooOol00Woo

00<007ooOol05Goo00=l07ooOol00Woo0P0O27oo0P0017oo00<007ooOol00Woo00<007ooOol097oo

0`000Woo00<007ooOol00Woo00<007ooOol09Goo00<007ooOol00Woo00<0000OOol00Woo00<007oo

Ool01Woo000KOol00`00Oomoo`0YOol01`00Oomoogoo001oo`00009oo`03001oo`0002Aoo`03001o

ogoo009oo`03001oo`00009oo`03001oo`0001Ioo`03O01oogoo009oo`0301moogoo00Uoo`06001o

ogoo001oo`000Woo00<007oo00009Woo00H007ooOol007oo0002Ool00`00Ool0000UOol00`00Ool0

0002Ool02000Ool0000OOol007oo0007Ool001]oo`03001oogoo02Uoo`07001oogooOol007oo0000

0Woo00<007oo00009Goo00L007ooOomoo`00Ool00002Ool00`00Ool0000FOol01G`0Oomoogoo01l0

2goo00L007ooOomoo`00Ool00002Ool00`00Ool0000TOol4000017oo001oo`000Woo00<007oo0000

9goo00/007ooOol007oo00007goo001oo`0000Moo`006goo0P00:Woo00L007ooOomoo`00Ool00002

Ool00`00Ool0000UOol01`00Oomoogoo001oo`00009oo`03001oo`0001Ioo`05O01oogooOol07`0<

Ool01P00Oomoo`00Ool0009oo`03001oo`0002Aoo`03001oo`00009oo`03001oo`00009oo`03001o

o`0002Eoo`8000=oo`08001oo`00Ool07`00Ool000Moo`006goo00<007ooOol0:Goo00L007ooOomo

o`00Ool00002Ool00`00Ool0000TOol00`00Ool00002Ool00`00Ool00002Ool00`00Ool0000FOol0

17`0Oomoo`0O2goo00<007oo00000Woo00<007oo00000Woo00<007oo00009Goo0P000Woo00<007oo

00000Woo00<007oo00009Goo00<007ooOol00Woo00P007oo001oo`0O001oo`001goo000KOol00`00

Oomoo`0XOol20004Ool00`00Oomoo`02Ool00`00Oomoo`0TOol00`00Oomoo`02Ool00`00Oomoo`02

Ool00`00Oomoo`0EOol017`0Oomoo`0O37oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0

9Goo00D007ooOomoo`0000Aoo`03001oogoo02Aoo`<000=oo`06001oogooOol07`0027oo000KOol0

0`00Oomoo`1lOol00g`0Ool07`1iOol00`0OOomoo`07Ool001]oo`03001oogoo07aoo`03O01oo`0O

07Yoo`0301moogoo00Ioo`006goo00<007ooOol0O7oo00=l000OOol0NWoo00<07gooOol01Woo000K

Ool00`00Oomoo`1lOol00g`001moo`1kOol00`0OOomoo`05Ool001]oo`03001oogoo07aoo`0301mo

ogoo07]oo`0301moogoo00Eoo`0057oo1`0000<07`000000O00000<07`000000P`00000KOol00`00

01moo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00

Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00

Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`0OOol00009Ool00`00Oomoo`07Ool00`00

Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00

Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00

Oomoo`07Ool00`00Oomoo`01Ool001]oo`0300007goo02ioo`03001oogoo02moo`03001oogoo01Qo

o`0301moogoo01=oo`03001oogoo02moo`03001oogoo02ioo`03001oogoo00]oo`006goo00<007oo

01l0Ngoo00<07gooOol0Q7oo000KOol00`00Ool07`1jOol00`0OO01oo`25Ool001]oo`04001oogoo

01miOol00`0OO01oo`25Ool001]oo`04001oogoo01mhOol00`0OOoml0026Ool001]oo`05001oogoo

Ool07`1gOol00`0OOoml0026Ool001]oo`80009oo`0301moogoo07Aoo`0401moogooO026Ool001]o

o`03001oogoo009oo`0301moogoo07=oo`0401moogooO026Ool001]oo`03001oogoo009oo`0301mo

ogoo079oo`0501moogooOoml0026Ool001]oo`03001oogoo00=oo`0301moogoo075oo`0501moogoo

Ooml0026Ool001]oo`03001oogoo00=oo`807g5oo`0301moogoo009oo`03O01oogoo08Aoo`006goo

00<007ooOol017oo00<07gooOol0KWoo00<07gooOol00goo00=l07ooOol0Q7oo000KOol00`00Oomo

o`05Ool00`0OOomoo`1]Ool00`0OOomoo`03Ool00g`0Oomoo`24Ool001]oo`03001oogoo00Eoo`03

01moogoo06aoo`0301moogoo00Aoo`03O01oogoo08Aoo`006goo0P001goo00<07gooOol0Hgoo27`0

00<07g`0O0001G`0QWoo000KOol00`00Oomoo`06Ool00`0OOomoo`1SOol00g`0Oomoo`04Ool00`0O

Oomoo`2<Ool001]oo`03001oogoo00Moo`0301moogoo069oo`03O01oogoo00Aoo`0301moogoo08ao

o`006goo00<007ooOol01goo00<07gooOol0HWoo00=l07ooOol00goo00<07gooOol0SGoo000KOol0

0`00Oomoo`08Ool00`0OOomoo`1QOol00g`0Oomoo`03Ool00`0OOomoo`2=Ool001]oo`03001oogoo

00Qoo`0301moogoo065oo`03O01oogoo009oo`0301moogoo08ioo`006goo00<007ooOol02Goo00<0

7gooOol0H7oo00=l07ooOol00Woo00<07gooOol0SWoo000KOol00`00Oomoo`09Ool00`0OOomoo`1P

Ool01G`0Oomoogoo01l0TGoo000KOol2000;Ool00`0OOomoo`1OOol01G`0Oomoogoo01l0TGoo000K

Ool00`00Oomoo`0:Ool201mPOol017`0Oomoo`0OTWoo000KOol00`00Oomoo`0;Ool00`0OOomoo`1N

Ool00g`0Ool07`2COol001]oo`03001oogoo00aoo`0301moogoo05eoo`03O01oo`0O09=oo`006goo

00<007ooOol037oo00<07gooOol0GGoo00=l000OOol0Tgoo000KOol00`00Oomoo`0=Ool00`0OOomo

o`1LOol00g`001moo`2COol001]oo`03001oogoo00eoo`0301moogoo05aoo`0301moogoo09=oo`00

6goo0P003goo00<07gooOol0Fgoo00<07gooOol0Tgoo000KOol00`00Oomoo`0>Ool00`0OOomoo`1J

Ool00`0OO01oo`2DOol001]oo`03001oogoo00moo`0301moogoo05Uoo`0301ml07oo09Aoo`006goo

00<007ooOol03goo0P0ODgoo1W`000<07g`0O000UGoo000KOol00`00Oomoo`0@Ool00`0OOomoo`1A

Ool00g`0Oomoo`02Ool00`0OOomoo`2FOol001]oo`03001oogoo015oo`0301moogoo051oo`03O01o

ogoo009oo`0301moogoo09Ioo`002goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo

00<007ooOol04Goo00<07gooOol0D7oo00El07ooOomoo`0O09Uoo`002Woo00<007oo00001goo00<0

07oo000017oo00<007ooOol04Woo00<07gooOol0Cgoo00El07ooOomoo`0O09Uoo`002Woo00<007oo

00002Goo00<007ooOol00Woo0P004goo0P0OD7oo00Al07ooOol07iYoo`002Woo00<007oo00001goo

0P001Goo00<007ooOol04goo00<07gooOol0CWoo00=l07oo01l0Vgoo000:Ool00`00Ool00007Ool0

0`00Oomoo`04Ool00`00Oomoo`0DOol00`0OOomoo`1=Ool00g`0Ool07`2KOol000]oo`03001oogoo

00Ioo`<000Aoo`03001oogoo01Aoo`0301moogoo04eoo`03O0007goo09]oo`006goo00<007ooOol0

5Goo00<07gooOol0C7oo00=l000OOol0Vgoo000KOol00`00Oomoo`0EOol201m=Ool00`0OOomoo`2K

Ool001]oo`03001oogoo01Ioo`0301moogoo04Yoo`0301ml07oo09aoo`006goo00<007ooOol05goo

00<07gooOol0BGoo00<07g`0Ool0W7oo000KOol2000HOol201m9Ool00`0OOoml002MOol001]oo`03

001oogoo01Qoo`0301moogoo04Ioo`0401moogooO02MOol001]ooaal000301ml07`0025l01moo`El

000401ml07`0O02MOol001]oo`03001oogoo01Uoo`807b5oo`03O01oogoo01eoo`05O01oogooOol0

7`2QOol001]oo`03001oogoo01Yoo`0301moogoo01moo`03O01oogoo01eoo`04O01oogoo01nROol0

01]oo`03001oogoo01]oo`0301moogoo01ioo`03O01oogoo01eoo`04O01oogoo01nROol001]oo`03

001oogoo01]oo`807amoo`03O01oogoo01eoo`03O01oo`0O0:=oo`006goo00<007ooOol077oo00<0

7gooOol07Goo00=l07ooOol07Goo00=l000OOol0Xgoo000KOol2000MOol201lNOol00g`0Oomoo`0M

Ool201nTOol001]oo`03001oogoo01eoo`0301moogoo01aoo`03O01oogoo01eoo`0301moogoo0:=o

o`006goo00<007ooOol07Woo00<07gooOol06goo00=l07ooOol077oo00<07g`0Ool0Y7oo000KOol0

0`00Oomoo`0OOol00`0OOomoo`0JOol00g`0Oomoo`0KOol00`0OOoml002UOol001]oo`03001oogoo

01moo`807a]oo`03O01oogoo01Yoo`807`03Ooml07oo0:Aoo`006goo00<007ooOol087oo00<07goo

Ool06Goo00=l07ooOol06Woo00@07gooOoml0:Eoo`006goo00<007ooOol08Goo00<07gooOol067oo

00=l07ooOol06Goo00D07gooOomoog`00:Eoo`006goo00<007ooOol08Woo00<07gooOol05goo00=l

07ooOol067oo00<07gooOol00Woo00=l07ooOol0Xgoo000KOol2000TOol00`0OOomoo`0GOol00g`0

Oomoo`0<Ool:O0000`0OO01l0004O02UOol001]oo`03001oogoo02Aoo`0301moogoo01Ioo`03O01o

ogoo00aoo`03O01oogoo00Ioo`0301moogoo0:Yoo`006goo00<007ooOol097oo0P0O5goo00=l07oo

Ool037oo00=l07ooOol01Goo0P0O[7oo000KOol00`00Oomoo`0UOol201lFOol00g`0Oomoo`0<Ool0

0g`0Oomoo`04Ool201n]Ool001]oo`03001oogoo02Ioo`807aEoo`03O01oogoo00aoo`03O01oogoo

00=oo`807jioo`006goo00<007ooOol09goo0P0O57oo00=l07ooOol037oo00=l07ooOol00Woo0P0O

[goo000KOol00`00Oomoo`0XOol201lCOol00g`0Oomoo`0<Ool017`0Oomoogoo0P0O/7oo000KOol2

000ZOol201lBOol00g`0Oomoo`0<Ool00g`0Oomoo`0201naOol001]oo`03001oogoo02]oo`0301mo

ogoo00moo`03O01oogoo00aoo`03O01oo`0O0;=oo`006goo00<007ooOol0;7oo0P0O3goo00=l07oo

Ool037oo0P0O]7oo000KOol00`00Oomoo`0]Ool201l>Ool00g`0Oomoo`0;Ool201neOol001]oo`03

001oogoo02moo`807`aoo`03O01oogoo00Yoo`807`03O01oogoo0;=oo`006goo00<007ooOol0<7oo

0`0O2Woo00=l07ooOol027oo0P0O0Woo00=l07ooOol0/goo000COol50003Ool00`00Oomoo`0bOol3

01l8Ool9O00201l5O02eOol001Eoo`03001oogoo00=oo`03001oogoo03Aoo`@07`]oo`<07kaoo`00

5Goo00<007ooOol00goo0P00>7oo300O_goo000EOol00`00Oomoo`03Ool00`00Oomoo`3oOol3Ool0

01Eoo`03001oogoo00=oo`03001oogoo0?moo`=oo`0057oo0P001Goo00<007ooOol0ogoo0goo000K

Ool00`00Oomoo`3oOol3Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o

OolQOol00001\

\>"],

  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-55.2265, -1.13006, 2.02101, 

  0.0127737}}],



Cell[BoxData[

    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),

      False,

      Editable->False]], "Output"]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{



Cell["Undersmoothed approximation", "Subsubtitle"],



Cell["\<\

This approximation below shows gross undersmoothing. The noise is \"obvious\" \

(especially since we are comparing the smooth with the underlying curve).\

\>", "Text"],



Cell[CellGroupData[{



Cell[BoxData[

    \(swdata3\  = \ thresh[wdata,  .2]\)], "Input"],



Cell[BoxData[

    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.278099670683798372`, 

      0, 0, 0, 0, 0, 0, 0.220117801042158989`, 0, 0, 0.308513578455259462`, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.215304964851505031`, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0.252468282466862703`, 0, 0, 0, 0, 0, 0, 0, 0, 

      0.211412153282535175`, 0, 0.245626988430101`, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0.316657248300451721`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0.23740274314222951`, 0, 0.24555896072975325`, 0, 0, 

      0.209729026715614175`, 0.236835203762295876`, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0.290945600109123603`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0.205645514017512542`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0.253188539052818928`, 0, 0, 0, 0, 0, 0, 0.237282729883557852`, 0, 0, 

      0.333785361582870265`, 0.204759252956833925`, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0.219682795602949099`, 0, 0, 0, 0, 0.293754765002615272`, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0.26436948410928549`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.277191484575628033`, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.306198444412742887`, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0.245794571842841103`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0.206688519179256902`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0.323403998917812574`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0.243945502192737073`, 0, 0, 0, 0.31239594856137387`, 0, 

      0.202815623735387129`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0.366903665405006229`, 0, 0, 0.337213579869583002`, 0, 0, 0, 0, 

      0.226638787006519493`, 0, 0, 0, 0.302864353549964215`, 

      0.271501313276411249`, 0, 0, 0, 0, 0, 0, 0, 0, 0.267254351347164931`, 

      0, 0.288851441030770672`, 0, 0, 0.274900560338105037`, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0.310183865588104534`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0.213803115796055553`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0.302240716658591646`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0.238723837745924516`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0.277408786206492674`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0.224076985742768908`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0.276060566716661126`, 0, 0.31383000635784497`, 

      0.208157570749786469`, 0.220831762620360994`, 0.202798205510905571`, 

      0.206039294195011457`, 0, 0, 0, 0, 0.287328077583493435`, 0, 0, 0, 0, 

      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.366496100760525855`, 

      0.549509373939600642`, 0.432963305520454966`, 0.262212626245867586`, 

      0.776151873726004204`, 0.234305660965524964`, 0, 0, 0, 0, 0, 0, 0, 

      0.651234733463280424`, 1.34183460162570122`, 1.50108201979227402`, 

      0.400995134824817967`, 0, 0, 0, 2.92281199433181981`, 

      2.86810968799443912`, 0, 0, 0, 14.1306966394984261`, 0}\)], "Output"]

}, Open  ]],



Cell[BoxData[

    \(\(sdata3\  = \ IDWT[swdata3]; \)\)], "Input"],



Cell[CellGroupData[{



Cell[BoxData[

    \(Plot2Lists[sdata3, udata]\)], "Input"],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.00186012 0.31198 0.258751 [

[.20982 .29948 -9 -9 ]

[.20982 .29948 9 0 ]

[.39583 .29948 -9 -9 ]

[.39583 .29948 9 0 ]

[.58185 .29948 -9 -9 ]

[.58185 .29948 9 0 ]

[.76786 .29948 -9 -9 ]

[.76786 .29948 9 0 ]

[.95387 .29948 -9 -9 ]

[.95387 .29948 9 0 ]

[.01131 .05323 -12 -4.5 ]

[.01131 .05323 0 4.5 ]

[.01131 .1826 -24 -4.5 ]

[.01131 .1826 0 4.5 ]

[.01131 .44136 -18 -4.5 ]

[.01131 .44136 0 4.5 ]

[.01131 .57073 -6 -4.5 ]

[.01131 .57073 0 4.5 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.20982 .31198 m

.20982 .31823 L

s

[(100)] .20982 .29948 0 1 Mshowa

.39583 .31198 m

.39583 .31823 L

s

[(200)] .39583 .29948 0 1 Mshowa

.58185 .31198 m

.58185 .31823 L

s

[(300)] .58185 .29948 0 1 Mshowa

.76786 .31198 m

.76786 .31823 L

s

[(400)] .76786 .29948 0 1 Mshowa

.95387 .31198 m

.95387 .31823 L

s

[(500)] .95387 .29948 0 1 Mshowa

.125 Mabswid

.06101 .31198 m

.06101 .31573 L

s

.09821 .31198 m

.09821 .31573 L

s

.13542 .31198 m

.13542 .31573 L

s

.17262 .31198 m

.17262 .31573 L

s

.24702 .31198 m

.24702 .31573 L

s

.28423 .31198 m

.28423 .31573 L

s

.32143 .31198 m

.32143 .31573 L

s

.35863 .31198 m

.35863 .31573 L

s

.43304 .31198 m

.43304 .31573 L

s

.47024 .31198 m

.47024 .31573 L

s

.50744 .31198 m

.50744 .31573 L

s

.54464 .31198 m

.54464 .31573 L

s

.61905 .31198 m

.61905 .31573 L

s

.65625 .31198 m

.65625 .31573 L

s

.69345 .31198 m

.69345 .31573 L

s

.73065 .31198 m

.73065 .31573 L

s

.80506 .31198 m

.80506 .31573 L

s

.84226 .31198 m

.84226 .31573 L

s

.87946 .31198 m

.87946 .31573 L

s

.91667 .31198 m

.91667 .31573 L

s

.99107 .31198 m

.99107 .31573 L

s

.25 Mabswid

0 .31198 m

1 .31198 L

s

.02381 .05323 m

.03006 .05323 L

s

[(-1)] .01131 .05323 1 0 Mshowa

.02381 .1826 m

.03006 .1826 L

s

[(-0.5)] .01131 .1826 1 0 Mshowa

.02381 .44136 m

.03006 .44136 L

s

[(0.5)] .01131 .44136 1 0 Mshowa

.02381 .57073 m

.03006 .57073 L

s

[(1)] .01131 .57073 1 0 Mshowa

.125 Mabswid

.02381 .0791 m

.02756 .0791 L

s

.02381 .10498 m

.02756 .10498 L

s

.02381 .13085 m

.02756 .13085 L

s

.02381 .15673 m

.02756 .15673 L

s

.02381 .20848 m

.02756 .20848 L

s

.02381 .23435 m

.02756 .23435 L

s

.02381 .26023 m

.02756 .26023 L

s

.02381 .2861 m

.02756 .2861 L

s

.02381 .33786 m

.02756 .33786 L

s

.02381 .36373 m

.02756 .36373 L

s

.02381 .38961 m

.02756 .38961 L

s

.02381 .41548 m

.02756 .41548 L

s

.02381 .46723 m

.02756 .46723 L

s

.02381 .49311 m

.02756 .49311 L

s

.02381 .51898 m

.02756 .51898 L

s

.02381 .54486 m

.02756 .54486 L

s

.02381 .02735 m

.02756 .02735 L

s

.02381 .00148 m

.02756 .00148 L

s

.02381 .59661 m

.02756 .59661 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02567 .47357 m

.02753 .47357 L

.02939 .47357 L

.03125 .47357 L

.03311 .47357 L

.03497 .47357 L

.03683 .47357 L

.03869 .47357 L

.04055 .47357 L

.04241 .47357 L

.04427 .47357 L

.04613 .47357 L

.04799 .47357 L

.04985 .47357 L

.05171 .47357 L

.05357 .47357 L

.05543 .47357 L

.05729 .47357 L

.05915 .47357 L

.06101 .47357 L

.06287 .47357 L

.06473 .47357 L

.06659 .47357 L

.06845 .47357 L

.07031 .47357 L

.07217 .47357 L

.07403 .47357 L

.07589 .47357 L

.07775 .47357 L

.07961 .47357 L

.08147 .47357 L

.08333 .47357 L

.08519 .52445 L

.08705 .42269 L

.08891 .47357 L

.09077 .47357 L

.09263 .47357 L

.09449 .47357 L

.09635 .47357 L

.09821 .47357 L

.10007 .47357 L

.10193 .47357 L

.10379 .47357 L

.10565 .47357 L

.10751 .47357 L

.10937 .47357 L

.11124 .51384 L

.1131 .43329 L

.11496 .50122 L

.11682 .50122 L

Mistroke

.11868 .50122 L

.12054 .50122 L

.1224 .50237 L

.12426 .38947 L

.12612 .44592 L

.12798 .44592 L

.12984 .47357 L

.1317 .47357 L

.13356 .47357 L

.13542 .47357 L

.13728 .47357 L

.13914 .47357 L

.141 .47357 L

.14286 .47357 L

.14472 .47357 L

.14658 .47357 L

.14844 .47357 L

.1503 .47357 L

.15216 .47357 L

.15402 .47357 L

.15588 .47357 L

.15774 .47357 L

.1596 .47357 L

.16146 .47357 L

.16332 .51296 L

.16518 .43418 L

.16704 .47357 L

.1689 .47357 L

.17076 .47357 L

.17262 .47357 L

.17448 .47357 L

.17634 .47357 L

.1782 .47357 L

.18006 .47357 L

.18192 .47357 L

.18378 .47357 L

.18564 .47357 L

.1875 .47357 L

.18936 .50031 L

.19122 .50031 L

.19308 .44683 L

.19494 .44683 L

.1968 .47357 L

.19866 .47357 L

.20052 .47357 L

.20238 .47357 L

.20424 .47357 L

.2061 .47357 L

.20796 .47357 L

.20982 .47357 L

Mistroke

.21168 .51976 L

.21354 .42738 L

.2154 .47357 L

.21726 .47357 L

.21912 .47357 L

.22098 .47357 L

.22284 .47357 L

.2247 .47357 L

.22656 .47357 L

.22842 .47357 L

.23028 .47357 L

.23214 .47357 L

.234 .47357 L

.23586 .47357 L

.23772 .47357 L

.23958 .47357 L

.24144 .47357 L

.2433 .47357 L

.24516 .51225 L

.24702 .43489 L

.24888 .47357 L

.25074 .47357 L

.2526 .51851 L

.25446 .42863 L

.25632 .47357 L

.25818 .47357 L

.26004 .47357 L

.2619 .47357 L

.26376 .56148 L

.26563 .56148 L

.26749 .56148 L

.26935 .56148 L

.27121 .56148 L

.27307 .56148 L

.27493 .56148 L

.27679 .56148 L

.27865 .60332 L

.28051 .60332 L

.28237 .51964 L

.28423 .51964 L

.28609 .56148 L

.28795 .56148 L

.28981 .56148 L

.29167 .56148 L

.29353 .56148 L

.29539 .56148 L

.29725 .56148 L

.29911 .56148 L

.30097 .56148 L

.30283 .56148 L

Mistroke

.30469 .56148 L

.30655 .56148 L

.30841 .56148 L

.31027 .56148 L

.31213 .56148 L

.31399 .56148 L

.31585 .56148 L

.31771 .56148 L

.31957 .56148 L

.32143 .56148 L

.32329 .55397 L

.32515 .55397 L

.32701 .55397 L

.32887 .55397 L

.33073 .55397 L

.33259 .55397 L

.33445 .55397 L

.33631 .55397 L

.33817 .51826 L

.34003 .51826 L

.34189 .51826 L

.34375 .51826 L

.34561 .51826 L

.34747 .51826 L

.34933 .51826 L

.35119 .51826 L

.35305 .50259 L

.35491 .50259 L

.35677 .50259 L

.35863 .50259 L

.36049 .50259 L

.36235 .50259 L

.36421 .50259 L

.36607 .50259 L

.36793 .50259 L

.36979 .50259 L

.37165 .50259 L

.37351 .50259 L

.37537 .50259 L

.37723 .50259 L

.37909 .56052 L

.38095 .44465 L

.38281 .5174 L

.38467 .5174 L

.38653 .5174 L

.38839 .5174 L

.39025 .47372 L

.39211 .47372 L

.39397 .47372 L

.39583 .47372 L

Mistroke

.39769 .45496 L

.39955 .45496 L

.40141 .45496 L

.40327 .45496 L

.40513 .48652 L

.40699 .48652 L

.40885 .4234 L

.41071 .4234 L

.41257 .43845 L

.41443 .43845 L

.41629 .43845 L

.41815 .43845 L

.42001 .43845 L

.42188 .43845 L

.42374 .43845 L

.4256 .43845 L

.42746 .41152 L

.42932 .41152 L

.43118 .41152 L

.43304 .41152 L

.4349 .49537 L

.43676 .4085 L

.43862 .37111 L

.44048 .37111 L

.44234 .44234 L

.4442 .35248 L

.44606 .39741 L

.44792 .39741 L

.44978 .42365 L

.45164 .42365 L

.4535 .40954 L

.45536 .3328 L

.45722 .41217 L

.45908 .32551 L

.46094 .36884 L

.4628 .36884 L

.46466 .36884 L

.46652 .36884 L

.46838 .36884 L

.47024 .36884 L

.4721 .35664 L

.47396 .35664 L

.47582 .35664 L

.47768 .35664 L

.47954 .35664 L

.4814 .35664 L

.48326 .35664 L

.48512 .35664 L

.48698 .3304 L

.48884 .3304 L

Mistroke

.4907 .3304 L

.49256 .3304 L

.49442 .38363 L

.49628 .27717 L

.49814 .3304 L

.5 .3304 L

.50186 .28986 L

.50372 .28986 L

.50558 .28986 L

.50744 .28986 L

.5093 .28986 L

.51116 .28986 L

.51302 .28986 L

.51488 .28986 L

.51674 .2632 L

.5186 .2632 L

.52046 .2632 L

.52232 .2632 L

.52418 .2632 L

.52604 .2632 L

.5279 .2632 L

.52976 .2632 L

.53162 .27792 L

.53348 .27792 L

.53534 .31555 L

.5372 .2403 L

.53906 .27463 L

.54092 .27463 L

.54278 .1797 L

.54464 .1797 L

.5465 .25254 L

.54836 .25254 L

.55022 .25254 L

.55208 .25254 L

.55394 .25254 L

.5558 .25254 L

.55766 .25254 L

.55952 .25254 L

.56138 .24657 L

.56324 .24657 L

.5651 .15931 L

.56696 .15931 L

.56882 .20294 L

.57068 .20294 L

.57254 .24926 L

.5744 .15661 L

.57626 .20294 L

.57813 .20294 L

.57999 .20294 L

.58185 .20294 L

Mistroke

.58371 .20294 L

.58557 .20294 L

.58743 .20294 L

.58929 .20294 L

.59115 .13193 L

.59301 .13193 L

.59487 .13193 L

.59673 .13193 L

.59859 .20467 L

.60045 .11784 L

.60231 .10261 L

.60417 .10261 L

.60603 .13193 L

.60789 .13193 L

.60975 .193 L

.61161 .07086 L

.61347 .1694 L

.61533 .09447 L

.61719 .13193 L

.61905 .13193 L

.62091 .10848 L

.62277 .10848 L

.62463 .10848 L

.62649 .10848 L

.62835 .14767 L

.63021 .14767 L

.63207 .0693 L

.63393 .0693 L

.63579 .14361 L

.63765 .14361 L

.63951 .07336 L

.64137 .07336 L

.64323 .10848 L

.64509 .10848 L

.64695 .10848 L

.64881 .10848 L

.65067 .10564 L

.65253 .10564 L

.65439 .14583 L

.65625 .06544 L

.65811 .10564 L

.65997 .10564 L

.66183 .10564 L

.66369 .10564 L

.66555 .06846 L

.66741 .06846 L

.66927 .06846 L

.67113 .06846 L

.67299 .12221 L

.67485 .01472 L

Mistroke

.67671 .06846 L

.67857 .06846 L

.68043 .07183 L

.68229 .07183 L

.68415 .07183 L

.68601 .07183 L

.68787 .07183 L

.68973 .07183 L

.69159 .07183 L

.69345 .07183 L

.69531 .07183 L

.69717 .07183 L

.69903 .07183 L

.70089 .07183 L

.70275 .1064 L

.70461 .1064 L

.70647 .03725 L

.70833 .03725 L

.71019 .07183 L

.71205 .07183 L

.71391 .07183 L

.71577 .07183 L

.71763 .1092 L

.71949 .1092 L

.72135 .03446 L

.72321 .03446 L

.72507 .07183 L

.72693 .07183 L

.72879 .07183 L

.73065 .07183 L

.73251 .07183 L

.73438 .07183 L

.73624 .07183 L

.7381 .07183 L

.73996 .18596 L

.74182 .18596 L

.74368 .11483 L

.74554 .11483 L

.7474 .15039 L

.74926 .15039 L

.75112 .19876 L

.75298 .10202 L

.75484 .15039 L

.7567 .15039 L

.75856 .15039 L

.76042 .15039 L

.76228 .15039 L

.76414 .15039 L

.766 .15039 L

.76786 .15039 L

Mistroke

.76972 .17089 L

.77158 .17089 L

.77344 .17089 L

.7753 .17089 L

.77716 .12989 L

.77902 .12989 L

.78088 .12989 L

.78274 .12989 L

.7846 .15039 L

.78646 .15039 L

.78832 .20111 L

.79018 .09968 L

.79204 .15039 L

.7939 .15039 L

.79576 .15039 L

.79762 .15039 L

.79948 .15039 L

.80134 .15039 L

.8032 .15039 L

.80506 .15039 L

.80692 .15039 L

.80878 .15039 L

.81064 .15039 L

.8125 .15039 L

.81436 .19052 L

.81622 .19052 L

.81808 .11026 L

.81994 .11026 L

.8218 .15039 L

.82366 .15039 L

.82552 .15039 L

.82738 .15039 L

.82924 .15039 L

.8311 .15039 L

.83296 .15039 L

.83482 .15039 L

.83668 .15039 L

.83854 .15039 L

.8404 .15039 L

.84226 .15039 L

.84412 .20641 L

.84598 .09437 L

.84784 .15039 L

.8497 .15039 L

.85156 .15039 L

.85342 .15039 L

.85528 .15039 L

.85714 .15039 L

.859 .15039 L

.86086 .15039 L

Mistroke

.86272 .15039 L

.86458 .15039 L

.86644 .15039 L

.8683 .15039 L

.87016 .15039 L

.87202 .15039 L

.87388 .15039 L

.87574 .15039 L

.8776 .15039 L

.87946 .15039 L

.88132 .15039 L

.88318 .15039 L

.88504 .15039 L

.8869 .15039 L

.88876 .15039 L

.89063 .15039 L

.89249 .15039 L

.89435 .15039 L

.89621 .17805 L

.89807 .17805 L

.89993 .12273 L

.90179 .12273 L

.90365 .15039 L

.90551 .15039 L

.90737 .15039 L

.90923 .15039 L

.91109 .15039 L

.91295 .15039 L

.91481 .15039 L

.91667 .15039 L

.91853 .15039 L

.92039 .15039 L

.92225 .15039 L

.92411 .15039 L

.92597 .15039 L

.92783 .15039 L

.92969 .19536 L

.93155 .10542 L

.93341 .15039 L

.93527 .15039 L

.93713 .15039 L

.93899 .15039 L

.94085 .15039 L

.94271 .15039 L

.94457 .15039 L

.94643 .15039 L

.94829 .15039 L

.95015 .15039 L

.95201 .15039 L

.95387 .15039 L

Mistroke

.95573 .15039 L

.95759 .15039 L

.95945 .15039 L

.96131 .15039 L

.96317 .15039 L

.96503 .15039 L

.96689 .15039 L

.96875 .15039 L

.97061 .15039 L

.97247 .15039 L

.97433 .15039 L

.97619 .15039 L

Mfstroke

0 0 1 r

.02567 .31198 m

.02753 .31516 L

.02939 .31833 L

.03125 .3215 L

.03311 .32468 L

.03497 .32785 L

.03683 .33101 L

.03869 .33418 L

.04055 .33734 L

.04241 .3405 L

.04427 .34365 L

.04613 .3468 L

.04799 .34995 L

.04985 .35308 L

.05171 .35622 L

.05357 .35934 L

.05543 .36246 L

.05729 .36557 L

.05915 .36867 L

.06101 .37177 L

.06287 .37485 L

.06473 .37793 L

.06659 .38099 L

.06845 .38405 L

.07031 .38709 L

.07217 .39012 L

.07403 .39315 L

.07589 .39615 L

.07775 .39915 L

.07961 .40213 L

.08147 .4051 L

.08333 .40806 L

.08519 .411 L

.08705 .41393 L

.08891 .41684 L

.09077 .41973 L

.09263 .42261 L

.09449 .42547 L

.09635 .42832 L

.09821 .43114 L

.10007 .43395 L

.10193 .43675 L

.10379 .43952 L

.10565 .44227 L

.10751 .445 L

.10937 .44772 L

.11124 .45041 L

.1131 .45308 L

.11496 .45573 L

.11682 .45836 L

Mistroke

.11868 .46097 L

.12054 .46356 L

.1224 .46612 L

.12426 .46866 L

.12612 .47117 L

.12798 .47366 L

.12984 .47613 L

.1317 .47857 L

.13356 .48099 L

.13542 .48338 L

.13728 .48575 L

.13914 .48809 L

.141 .4904 L

.14286 .49269 L

.14472 .49494 L

.14658 .49718 L

.14844 .49938 L

.1503 .50155 L

.15216 .5037 L

.15402 .50582 L

.15588 .50791 L

.15774 .50997 L

.1596 .512 L

.16146 .514 L

.16332 .51597 L

.16518 .5179 L

.16704 .51981 L

.1689 .52169 L

.17076 .52353 L

.17262 .52534 L

.17448 .52712 L

.17634 .52887 L

.1782 .53059 L

.18006 .53227 L

.18192 .53392 L

.18378 .53553 L

.18564 .53712 L

.1875 .53866 L

.18936 .54018 L

.19122 .54166 L

.19308 .5431 L

.19494 .54451 L

.1968 .54589 L

.19866 .54723 L

.20052 .54853 L

.20238 .5498 L

.20424 .55103 L

.2061 .55223 L

.20796 .55339 L

.20982 .55452 L

Mistroke

.21168 .55561 L

.21354 .55666 L

.2154 .55767 L

.21726 .55865 L

.21912 .55959 L

.22098 .56049 L

.22284 .56136 L

.2247 .56219 L

.22656 .56298 L

.22842 .56373 L

.23028 .56444 L

.23214 .56512 L

.234 .56576 L

.23586 .56636 L

.23772 .56692 L

.23958 .56745 L

.24144 .56793 L

.2433 .56838 L

.24516 .56879 L

.24702 .56915 L

.24888 .56948 L

.25074 .56978 L

.2526 .57003 L

.25446 .57024 L

.25632 .57042 L

.25818 .57056 L

.26004 .57065 L

.2619 .57071 L

.26376 .57073 L

.26563 .57071 L

.26749 .57065 L

.26935 .57056 L

.27121 .57042 L

.27307 .57024 L

.27493 .57003 L

.27679 .56978 L

.27865 .56948 L

.28051 .56915 L

.28237 .56879 L

.28423 .56838 L

.28609 .56793 L

.28795 .56745 L

.28981 .56692 L

.29167 .56636 L

.29353 .56576 L

.29539 .56512 L

.29725 .56444 L

.29911 .56373 L

.30097 .56298 L

.30283 .56219 L

Mistroke

.30469 .56136 L

.30655 .56049 L

.30841 .55959 L

.31027 .55865 L

.31213 .55767 L

.31399 .55666 L

.31585 .55561 L

.31771 .55452 L

.31957 .55339 L

.32143 .55223 L

.32329 .55103 L

.32515 .5498 L

.32701 .54853 L

.32887 .54723 L

.33073 .54589 L

.33259 .54451 L

.33445 .5431 L

.33631 .54166 L

.33817 .54018 L

.34003 .53866 L

.34189 .53712 L

.34375 .53553 L

.34561 .53392 L

.34747 .53227 L

.34933 .53059 L

.35119 .52887 L

.35305 .52712 L

.35491 .52534 L

.35677 .52353 L

.35863 .52169 L

.36049 .51981 L

.36235 .5179 L

.36421 .51597 L

.36607 .514 L

.36793 .512 L

.36979 .50997 L

.37165 .50791 L

.37351 .50582 L

.37537 .5037 L

.37723 .50155 L

.37909 .49938 L

.38095 .49718 L

.38281 .49494 L

.38467 .49269 L

.38653 .4904 L

.38839 .48809 L

.39025 .48575 L

.39211 .48338 L

.39397 .48099 L

.39583 .47857 L

Mistroke

.39769 .47613 L

.39955 .47366 L

.40141 .47117 L

.40327 .46866 L

.40513 .46612 L

.40699 .46356 L

.40885 .46097 L

.41071 .45836 L

.41257 .45573 L

.41443 .45308 L

.41629 .45041 L

.41815 .44772 L

.42001 .445 L

.42188 .44227 L

.42374 .43952 L

.4256 .43675 L

.42746 .43395 L

.42932 .43114 L

.43118 .42832 L

.43304 .42547 L

.4349 .42261 L

.43676 .41973 L

.43862 .41684 L

.44048 .41393 L

.44234 .411 L

.4442 .40806 L

.44606 .4051 L

.44792 .40213 L

.44978 .39915 L

.45164 .39615 L

.4535 .39315 L

.45536 .39012 L

.45722 .38709 L

.45908 .38405 L

.46094 .38099 L

.4628 .37793 L

.46466 .37485 L

.46652 .37177 L

.46838 .36867 L

.47024 .36557 L

.4721 .36246 L

.47396 .35934 L

.47582 .35622 L

.47768 .35308 L

.47954 .34995 L

.4814 .3468 L

.48326 .34365 L

.48512 .3405 L

.48698 .33734 L

.48884 .33418 L

Mistroke

.4907 .33101 L

.49256 .32785 L

.49442 .32468 L

.49628 .3215 L

.49814 .31833 L

.5 .31516 L

.50186 .31198 L

.50372 .3088 L

.50558 .30563 L

.50744 .30246 L

.5093 .29928 L

.51116 .29611 L

.51302 .29295 L

.51488 .28978 L

.51674 .28662 L

.5186 .28346 L

.52046 .28031 L

.52232 .27716 L

.52418 .27401 L

.52604 .27088 L

.5279 .26774 L

.52976 .26462 L

.53162 .2615 L

.53348 .25839 L

.53534 .25529 L

.5372 .25219 L

.53906 .24911 L

.54092 .24603 L

.54278 .24297 L

.54464 .23991 L

.5465 .23687 L

.54836 .23384 L

.55022 .23081 L

.55208 .22781 L

.55394 .22481 L

.5558 .22183 L

.55766 .21886 L

.55952 .2159 L

.56138 .21296 L

.56324 .21003 L

.5651 .20712 L

.56696 .20423 L

.56882 .20135 L

.57068 .19849 L

.57254 .19564 L

.5744 .19282 L

.57626 .19001 L

.57813 .18721 L

.57999 .18444 L

.58185 .18169 L

Mistroke

.58371 .17896 L

.58557 .17624 L

.58743 .17355 L

.58929 .17088 L

.59115 .16823 L

.59301 .1656 L

.59487 .16299 L

.59673 .1604 L

.59859 .15784 L

.60045 .1553 L

.60231 .15279 L

.60417 .1503 L

.60603 .14783 L

.60789 .14539 L

.60975 .14297 L

.61161 .14058 L

.61347 .13821 L

.61533 .13587 L

.61719 .13356 L

.61905 .13127 L

.62091 .12902 L

.62277 .12678 L

.62463 .12458 L

.62649 .1224 L

.62835 .12026 L

.63021 .11814 L

.63207 .11605 L

.63393 .11399 L

.63579 .11196 L

.63765 .10996 L

.63951 .10799 L

.64137 .10606 L

.64323 .10415 L

.64509 .10227 L

.64695 .10043 L

.64881 .09862 L

.65067 .09684 L

.65253 .09509 L

.65439 .09337 L

.65625 .09169 L

.65811 .09004 L

.65997 .08843 L

.66183 .08684 L

.66369 .0853 L

.66555 .08378 L

.66741 .0823 L

.66927 .08086 L

.67113 .07945 L

.67299 .07807 L

.67485 .07673 L

Mistroke

.67671 .07543 L

.67857 .07416 L

.68043 .07293 L

.68229 .07173 L

.68415 .07057 L

.68601 .06944 L

.68787 .06835 L

.68973 .0673 L

.69159 .06629 L

.69345 .06531 L

.69531 .06437 L

.69717 .06347 L

.69903 .0626 L

.70089 .06177 L

.70275 .06098 L

.70461 .06023 L

.70647 .05952 L

.70833 .05884 L

.71019 .0582 L

.71205 .0576 L

.71391 .05704 L

.71577 .05651 L

.71763 .05603 L

.71949 .05558 L

.72135 .05517 L

.72321 .05481 L

.72507 .05447 L

.72693 .05418 L

.72879 .05393 L

.73065 .05372 L

.73251 .05354 L

.73438 .0534 L

.73624 .05331 L

.7381 .05325 L

.73996 .05323 L

.74182 .05325 L

.74368 .05331 L

.74554 .0534 L

.7474 .05354 L

.74926 .05372 L

.75112 .05393 L

.75298 .05418 L

.75484 .05447 L

.7567 .05481 L

.75856 .05517 L

.76042 .05558 L

.76228 .05603 L

.76414 .05651 L

.766 .05704 L

.76786 .0576 L

Mistroke

.76972 .0582 L

.77158 .05884 L

.77344 .05952 L

.7753 .06023 L

.77716 .06098 L

.77902 .06177 L

.78088 .0626 L

.78274 .06347 L

.7846 .06437 L

.78646 .06531 L

.78832 .06629 L

.79018 .0673 L

.79204 .06835 L

.7939 .06944 L

.79576 .07057 L

.79762 .07173 L

.79948 .07293 L

.80134 .07416 L

.8032 .07543 L

.80506 .07673 L

.80692 .07807 L

.80878 .07945 L

.81064 .08086 L

.8125 .0823 L

.81436 .08378 L

.81622 .0853 L

.81808 .08684 L

.81994 .08843 L

.8218 .09004 L

.82366 .09169 L

.82552 .09337 L

.82738 .09509 L

.82924 .09684 L

.8311 .09862 L

.83296 .10043 L

.83482 .10227 L

.83668 .10415 L

.83854 .10606 L

.8404 .10799 L

.84226 .10996 L

.84412 .11196 L

.84598 .11399 L

.84784 .11605 L

.8497 .11814 L

.85156 .12026 L

.85342 .1224 L

.85528 .12458 L

.85714 .12678 L

.859 .12902 L

.86086 .13127 L

Mistroke

.86272 .13356 L

.86458 .13587 L

.86644 .13821 L

.8683 .14058 L

.87016 .14297 L

.87202 .14539 L

.87388 .14783 L

.87574 .1503 L

.8776 .15279 L

.87946 .1553 L

.88132 .15784 L

.88318 .1604 L

.88504 .16299 L

.8869 .1656 L

.88876 .16823 L

.89063 .17088 L

.89249 .17355 L

.89435 .17624 L

.89621 .17896 L

.89807 .18169 L

.89993 .18444 L

.90179 .18721 L

.90365 .19001 L

.90551 .19282 L

.90737 .19564 L

.90923 .19849 L

.91109 .20135 L

.91295 .20423 L

.91481 .20712 L

.91667 .21003 L

.91853 .21296 L

.92039 .2159 L

.92225 .21886 L

.92411 .22183 L

.92597 .22481 L

.92783 .22781 L

.92969 .23081 L

.93155 .23384 L

.93341 .23687 L

.93527 .23991 L

.93713 .24297 L

.93899 .24603 L

.94085 .24911 L

.94271 .25219 L

.94457 .25529 L

.94643 .25839 L

.94829 .2615 L

.95015 .26462 L

.95201 .26774 L

.95387 .27088 L

Mistroke

.95573 .27401 L

.95759 .27716 L

.95945 .28031 L

.96131 .28346 L

.96317 .28662 L

.96503 .28978 L

.96689 .29295 L

.96875 .29611 L

.97061 .29928 L

.97247 .30246 L

.97433 .30563 L

.97619 .3088 L

Mfstroke

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{288, 177.938},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ

Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`006goo0P00ogoo17oo000KOol00`00Oomo

o`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomo

o`2ZOol00g`0Oomoo`1EOol001]oo`03001oogoo0:Yoo`03O01oogoo05Eoo`006goo00<007ooOol0

ZWoo00=l07ooOol0EGoo000KOol2002[Ool00g`0Oomoo`1EOol001]oo`03001oogoo0:Yoo`03O01o

ogoo05Eoo`006goo00<007ooOol0ZWoo00=l07ooOol02Goo0W`0BWoo000KOol00`00Oomoo`2ZOol0

0g`0Oomoo`05Ool2O002Ool2O01:Ool001]oo`03001oogoo0:Yoo`03O01oogoo00Eoo`9l009oo`9l

04Yoo`004goo1@000goo00<007ooOol0ZWoo0W`01Woo0W`00Woo0W`0BWoo000EOol00`00Oomoo`03

Ool00`00Oomoo`2ZOol2O006Ool2O002Ool2O01:Ool000moo`<000=oo`03001oogoo00=oo`800:]o

o`9l00Ioo`9l009oo`03O0007`0O00P07d5oo`005Goo00<007ooOol00goo00<007ooOol0ZWoo0W`0

1Woo00=l000O01l00P0O00=l07ooOol01Woo1@0O?Goo000EOol00`00Oomoo`03Ool00`00Oomoo`2Z

Ool2O004Ool301l00g`0Oomoo`02O00<Ool301lkOol001Aoo`8000Eoo`03001oogoo0:Eoo`03O01o

ogoo009oo`9l009oo`<07`03Ooml07`0009oo`9l00moo`807cUoo`006goo00<007ooOol0Wgoo00=l

07ooOol00goo00=l07ooOol017`000=oo`0O01l00goo0W`00Woo0W`04Goo0P0O=goo000KOol00`00

Oomoo`2IOol00g`0Oomoo`03Ool00g`0Ooml0003Ool00g`0Oomoo`03O00201l?O00>Ool201lfOol0

01]oo`03001oogoo09Uoo`03O01oogoo00=oo`03O01oog`000=oo`03O01oogoo009l00807`Eoo`9l

009oo`9l00Aoo`03O01oogoo00ioo`807cAoo`006goo0P00VWoo00=l07ooOol00goo00=l07ooO000

0goo00Al07ooOoml00807`Ioo`9l009oo`9l00Aoo`03O01oogoo00moo`807c=oo`006goo00<007oo

Ool0VGoo00=l07ooOol00goo00=l07ooO0000goo00Al07ooOol07`9l00Ioo`9l009oo`9l00Aoo`03

O01oogoo015oo`0301moogoo031oo`006goo00<007ooOol0VGoo00=l07ooOol00goo00=l07ooO000

0goo00Al000O01moo`9l00Ioo`9l009oo`9l00Aoo`03O01oogoo019oo`807c1oo`006goo00<007oo

Ool0VGoo00=l07ooOol00goo00=l07ooO0000goo0P0O00Al07ooO01l00Ioo`9l009oo`9l00Aoo`03

O01oogoo01=oo`807bmoo`006goo00<007ooOol0VGoo0W`017oo00El07ooO01l07oo00807`9l0003

Ooml07`000Ioo`9l009oo`9l00Aoo`03O01oogoo01Aoo`807`Aoo`03O01oogoo02Moo`006goo00<0

07ooOol0VGoo0W`017oo00Al07ooO01l00807`=l009oo`03O01oogoo00Aoo`9l009oo`9l00Aoo`03

O01oogoo00]oo`03O01oogoo00Moo`807`=oo`03O01oogoo02Moo`006goo00<007ooOol0Ugoo00Al

07ooO01l00Aoo`03O01oog`000807`04Ooml07`0O002Ool00g`0Oomoo`04Ool2O002Ool2O004Ool0

1G`0OomoogooO0002Goo00=l07ooOol027oo0P0O0Woo00=l07ooOol09goo000KOol2002HOol017`0

Ooml07`017oo00El07oo01l07goo00Al009oo`03O01oogoo00Aoo`9l009oo`9l00Aoo`05O01oogoo

Ooml0009Ool00g`0Oomoo`09Ool201l00gooO01oo`0DOol00g`0Oomoo`0AOol001]oo`03001oogoo

09Ioo`9l0004Ooml07`0Ool3O0000goo01l07`04O004Ool00g`0Oomoo`08Ool2O004Ool01G`0Oomo

ogooO0002Goo00=l07ooOol017oo0W`017oo0P0O00=l07ooOol04goo00=l07ooOol04Goo000KOol0

0`00Oomoo`2FOol2O00017ooO01l07oo0g`00P0O0goo0W`017oo00=l07ooOol03Woo0g`000=oog`0

Ool027oo00=l07ooOol017oo0W`01Goo0P0O5Goo00=l07ooOol04Goo000KOol00`00Oomoo`2FOol2

O0000gooO01l0003O00201l017`0Oomoogoo0W`017oo00=l07ooOol03Woo0g`000=oog`0Ool027oo

00=l07ooOol017oo0W`01Woo0P0O57oo00=l07ooOol04Goo000KOol00`00Oomoo`2FOol00g`0Ooml

0003O0001Goo01l07gooO0000goo0W`017oo00=l07ooOol03Woo0g`000=oog`0Ool027oo00=l07oo

Ool017oo0W`01Woo00=l000O01l02goo00=l07ooOol01Goo00=l07ooOol04Goo000KOol00`00Oomo

o`2FOol00g`0Ooml0003O0001Goo01ml07ooO0000goo0W`05Goo0g`000=oog`0Ool027oo00=l07oo

Ool017oo0W`01Woo00=l07oo01l02goo00=l07ooOol01Goo00=l07ooOol04Goo000KOol00`00Oomo

o`2FOol00g`0Ooml0003O0001@0OO01l07ooO00017oo00=l07ooOol04goo0g`000=oog`0Ool017oo

0g`000=oog`0Ool01Goo0W`01Woo00Al07oo01l07`Yoo`03O01oogoo00Eoo`03O01oogoo015oo`00

6goo0P00UGoo0g`000Eoog`0O01l000O009oo`03O01oog`000Aoo`03O01oogoo01=oo`=l0003Ooml

07oo00Aoo`05O01oog`0Ooml0006Ool2O006Ool00g`0Oomoo`0201l9Ool00g`0Oomoo`05Ool2O00B

Ool001]oo`03001oogoo09Aoo`=l0004Ooml07`001l3Ool00g`0Ooml0004Ool00g`0Oomoo`0COol3

O0000gooO01oo`04Ool01G`0Ooml07ooO0001Woo0W`01Woo00El07ooOomoo`0O00Uoo`03O01oogoo

00Eoo`9l019oo`006goo00<007ooOol0U7oo0g`000Aoog`001l07`=oo`03O01oog`000Aoo`03O01o

ogoo01=oo`=l0003Ooml07oo00Aoo`05O01oog`0Ooml0006Ool2O006Ool00g`0Oomoo`02Ool00`0O

Oomoo`06Ool2O006Ool2O00BOol001]oo`03001oogoo09Aoo`=l0004Ooml000OO003Ool00g`0Ooml

0004Ool00g`0Oomoo`0COol3O0000gooO01oo`04Ool01G`0Ooml07ooO0001Woo0W`01Woo00=l07oo

Ool00goo00<07gooOol01Goo0W`01Woo0W`04Woo000KOol00`00Oomoo`2DOol3O00017oo01ml07`0

0goo00=l07ooOol017oo00=l07ooOol04goo0g`000=oog`0Ool017oo00El07ooO01oog`000Ioo`9l

00Ioo`03O01oogoo00=oo`807`Ioo`9l00Ioo`9l019oo`006goo00<007ooOol0U7oo0g`000@07g`0

O01l021oo`Ul0003Ooml07oo01Ql00807`El0003Ooml07`0019l00Moo`006goo00<007ooOol0Sgoo

00=l07ooOol00Woo0W`000<07gooO0000W`087oo0W`000=oog`0Ool00goo00=l07ooO0000Woo00=l

07ooOol017oo0W`01Woo00=l07ooOol01Woo00@07gooOomoo`9l00Moo`9l01=oo`006goo0P00SWoo

00=l07ooO00017oo00Al000O01moo`=l021oo`9l0003Ooml07oo00=oo`03O01oog`0009oo`03O01o

ogoo00Aoo`9l00Ioo`03O01oogoo00Moo`0301moogoo009l00Moo`9l01=oo`006goo00<007ooOol0

SGoo00=l07ooO00017oo00Al000OO01oo`=l021oo`9l0003Ooml07oo00=oo`03O01oog`0009oo`03

O01oogoo00Aoo`9l00Ioo`03O01oogoo00Qoo`0401moog`0O007Ool2O00COol001]oo`03001oogoo

08eoo`03O01oog`000Aoo`0301ml07`0009oo`9l021oo`9l0003Ooml07oo00=oo`03O01oog`0009o

o`03O01oogoo00Aoo`9l00Ioo`03O01oogoo00Qoo`0401moogooO007Ool2O00COol001]oo`03001o

ogoo08eoo`03O01oog`000=oo`807`04Ooml07ooOol2O00POol2O0000gooO01oo`03Ool3O002Ool0

0g`0Oomoo`04Ool2O006Ool00g`0Oomoo`09Ool00`0OOoml0007Ool2O00COol000]oo`03001oogoo

009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo08eoo`03O01oog`000=oo`0401moogoo

O002Ool00g`0Oomoo`0OOol2O0000gooO01oo`08Ool00g`0Oomoo`04Ool2O006Ool00g`0Oomoo`0:

Ool00`0OO01oo`06Ool2O00COol000Yoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo08eo

o`03O01oog`0009oo`0501ml07ooOoml0002Ool00g`0Oomoo`0OOol2O0000gooO01oo`08Ool00g`0

Oomoo`04Ool2O006Ool00g`0Oomoo`0:Ool201l8Ool00g`0Oomoo`0AOol000Eoo`<0009oo`03001o

o`0000Uoo`03001oogoo009oo`8008Qoo`03O01oogoo00=oo`07O01oog`0O0007gooO0000Woo00Al

07ooOoml025oo`9l0003Ooml07oo00Qoo`03O01oogoo00Aoo`9l00Ioo`03O01oogoo00]oo`0301mo

ogoo00Ioo`03O01oogoo015oo`002Woo00<007oo00001goo0P001Goo00<007ooOol0Qgoo00=l07oo

Ool00goo17`000<07gooO0000Woo00Al07ooOoml025oo`9l0003Ooml07oo00Qoo`03O01oogoo00Ao

o`9l00Ioo`03O01oogoo00aoo`0301moogoo00Eoo`03O01oogoo015oo`002Woo00<007oo00001goo

00<007ooOol017oo00<007ooOol0Qgoo00=l07ooOol00goo0g`000@07gooOoml009oo`04O01oogoo

O00TOol00g`0Oomoo`07Ool00g`0Oomoo`04Ool2O006Ool00g`0Oomoo`0<Ool201l6Ool00g`0Oomo

o`0AOol000]oo`03001oogoo00Ioo`<000Aoo`03001oogoo08Moo`03O01oogoo00=oo`9l000501ml

07ooOoml0002Ool017`0Oomoog`097oo00=l07ooOol01goo00=l07ooOol017oo0W`01Woo00=l07oo

Ool03Goo00<07gooOol017oo00=l07ooOol04Goo000KOol00`00Oomoo`27Ool00g`0Oomoo`03Ool2

O0001@0OO01oogooO0000Woo00=l07ooOol09Goo00=l07ooOol01goo00=l07ooOol037oo00=l07oo

Ool03Woo00<07gooOol00goo00=l07ooOol04Goo000KOol00`00Oomoo`27Ool00g`0Oomoo`03Ool0

17`001ml07`00Woo00Al07ooOoml02Moo`03O01oogoo00Moo`03O01oogoo00aoo`03O01oogoo00io

o`807aQoo`006goo00<007ooOol0Qgoo00=l07ooOol00Woo00=l000OO0001G`00Woo00=l07ooOol0

?Woo00=l07ooOol03goo00<07gooOol05Woo000KOol20028Ool00g`0Oomoo`02Ool017`001ml07`0

Agoo00=l07ooOol047oo00<07gooOol05Goo000KOol00`00Oomoo`27Ool00g`0Oomoo`02Ool0100O

Ooml07`0FWoo0P0O5Woo000KOol00`00Oomoo`27Ool01g`0Oomoogoo01ml07oo009l05]oo`0301mo

ogoo01Aoo`006goo00<007ooOol0Qgoo0W`00Woo00<07g`0Ool00W`0G7oo00<07gooOol04goo000K

Ool00`00Oomoo`27Ool2O0001Goo01moog`0Ool00W`0G7oo00<07gooOol04goo000KOol00`00Oomo

o`27Ool2O00201l00gooO01oo`02O01MOol00`0OOomoo`0BOol001]oo`03001oogoo08Ioo`04O01o

og`001l2Ool017`0Oomoog`0GWoo00<07gooOol04Goo000KOol20027Ool00g`0Ool07`03Ool017`0

Oomoog`0GWoo00<07gooOol04Goo000KOol00`00Oomoo`26Ool00g`0Ool07`03Ool017`0Oomoog`0

Ggoo00<07gooOol047oo000KOol00`00Oomoo`25Ool2O0000`0OO01oo`02Ool017`0Oomoog`0Ggoo

0P0O4Goo000KOol00`00Oomoo`25Ool017`001moog`00goo00Al07ooOoml061oo`0301moogoo00mo

o`006goo00<007ooOol0QGoo00Al000OOoml009oo`05O01oogooOoml001QOol00`0OOomoo`0>Ool0

01]oo`03001oogoo08Eoo`0301ml07oo00Al06Eoo`0301moogoo00ioo`006goo00<007ooOol0QGoo

00<07g`0Ool0JWoo00<07gooOol03Goo000KOol20025Ool00`0OO01l001[Ool201l>Ool001]oo`03

001oogoo081oo`=l000401moog`0O01/Ool00`0OOomoo`0<Ool001]oo`03001oogoo02Moo`D0009o

o`03001oogoo009oo`03001oogoo02=oo`<000=oo`03001oogoo009oo`03001oogoo01Uoo`05O01o

ogoo01moo`02O004Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0TOol30002Ool00`00Oomoo`02

Ool00`00Oomoo`0UOol00`00Oomoo`02Ool00`0OOomoo`02Ool00`00Oomoo`06Ool001]oo`03001o

ogoo02Uoo`07001oogooOol007oo00000Woo00<007oo000097oo00<007ooOol00Woo00<007oo0000

0Woo00<007oo00006Woo00El07oo01ml07oo009l00Ioo`06001oogoo001oo`000Woo00<007oo0000

9Woo00H007ooOol007oo0002Ool00`00Ool0000UOol00`00Ool00002Ool00`0001l00002Ool00`00

Ool00007Ool001]oo`03001oogoo02Uoo`07001oogooOol007oo00000Woo00<007oo00009Goo00L0

07ooOomoo`00Ool00002Ool00`00Ool0000JOol017`0Ool07goo0g`01Goo00L007ooOomoo`00Ool0

0002Ool00`00Ool0000TOol4000017oo001oo`000Woo00<007oo00009goo00H007ooOol007oo01l2

Ool00`00Ool00007Ool001]oo`03001oogoo02Uoo`07001oogooOol007oo00000Woo00<007oo0000

9Goo00L007ooOomoo`00Ool00002Ool00`00Ool0000EOol01g`0OomoogooO01oo`0O009oo`9l00Mo

o`06001oogoo001oo`000Woo00<007oo000097oo00<007oo00000Woo00<007oo00000Woo00<007oo

00009Goo0P000goo00P007oo01l07goo001oo`001goo000KOol00`00Oomoo`0YOol01`00Oomoogoo

001oo`00009oo`03001oo`0002Aoo`03001oo`00009oo`03001oo`00009oo`03001oo`0001Eoo`06

O01oogooOoml000O0goo0W`01Goo00<007oo00000Woo00<007oo00000Woo00<007oo00009Goo0P00

0Woo00<007oo00000Woo00<007oo00009Goo00<007ooOol00Woo00P007oo00007goo001oo`001goo

000KOol2000YOol20004Ool00`00Oomoo`02Ool00`00Oomoo`0TOol00`00Oomoo`02Ool00`00Oomo

o`02Ool00`00Oomoo`0DOol01W`0OomoogooO0007`=oo`9l00Ioo`03001oogoo009oo`03001oogoo

009oo`03001oogoo02Eoo`05001oogooOol00004Ool00`00Oomoo`0TOol30003Ool01P00Oomoo`0O

Ool000Qoo`006goo00<007ooOol0Ngoo17`000<07gooOol00Woo0W`0LGoo00<07gooOol027oo000K

Ool00`00Oomoo`1kOol2O002Ool00`0OOomoo`02Ool2O01bOol00`0OOomoo`07Ool001]oo`03001o

ogoo07]oo`9l0003Ool07goo00Aoo`9l079oo`807`Qoo`006goo00<007ooOol0Ngoo0W`000<07goo

Ool01Goo00=l07ooOol0LGoo00<07gooOol01Woo000KOol00`00Oomoo`1kOol2O0000`0OOomoo`05

Ool00g`0Oomoo`1bOol00`0OOomoo`05Ool001]oo`03001oogoo07]oo`03O0007goo00Moo`03O01o

ogoo079oo`0301moogoo00Eoo`0057oo1`0000<07`000000N`0000=l000O00001`0000=l00000000

NP00000KOol00`0001moo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00

Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00

Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`0OOol00007Ool00g`0

Ool00009Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00

Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00

Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`01Ool001]oo`0300007`0O07]oo`0301moogoo08Ao

o`006goo00<007oo01l0LGoo00=l07ooOol01Woo00<07g`0Ool0QGoo000KOol01000Oomoo`0OL7oo

00=l07ooOol01Woo00<07g`0Ool0QGoo000KOol01000Oomoo`0OKgoo0W`01Woo00Al000OO01l08Io

o`006goo00D007ooOomoo`0O06ioo`9l00Ioo`03O0007g`008Moo`006goo0P000Woo0P0OKGoo0W`0

1Woo00<07gooO000Qgoo000KOol00`00Oomoo`02Ool00`0OOomoo`1[Ool2O005Ool0100OO01oog`0

Qgoo000KOol00`00Oomoo`03Ool00`0OOomoo`1ZOol2O005Ool0100OO01oog`0Qgoo000KOol00`00

Oomoo`03Ool00`0OOomoo`1ZOol2O004Ool01@0OOoml07ooO000Qgoo000KOol00`00Oomoo`04Ool0

0`0OOomoo`1VOol00g`0Oomoo`02O004Ool01@0OOoml07ooO000Qgoo000KOol00`00Oomoo`04Ool2

01mWOol00g`0Oomoo`02O002Ool00g`001ml0002O0000gooO01oo`26Ool001]oo`03001oogoo00Eo

o`0301moogoo06Eoo`03O01oogoo009l009oo`0301moogoo00=oo`03O01oogoo08Eoo`006goo0P00

1goo00<07gooOol0I7oo00=l07ooOol00W`00Woo00<07gooOol00goo00=l07ooOol0QGoo000KOol0

0`00Oomoo`06Ool00`0OOomoo`1TOol00g`0Oomoo`03O0000`0OO01oo`04Ool00g`0Oomoo`25Ool0

01]oo`03001oogoo00Moo`0301moogoo065oo`=l0003Ooml07`0009oo`0301moogoo00Aoo`03O01o

ogoo08Eoo`006goo00<007ooOol01goo0P0OHWoo0g`000Eoog`0O01oo`0O00Moo`03O01oogoo08Eo

o`006goo00<007ooOol027oo00<07gooOol0H7oo0g`000Aoog`0O0007`Qoo`03O01oogoo08Eoo`00

6goo00<007ooOol02Goo00<07gooOol0Ggoo0g`000Aoog`0O0007`Qoo`03O01oogoo08Eoo`006goo

0P002Woo00<07gooOol037oo00=l07ooOol0D7oo0g`000=oog`001l0TGoo000KOol00`00Oomoo`0:

Ool00`0OOomoo`0;Ool00g`0Oomoo`1@Ool3O0000goo01l07`2AOol001]oo`03001oogoo00]oo`03

01moogoo00Yoo`03O01oogoo051oo`=l0003Ool07g`0095oo`006goo00<007ooOol02goo00<07goo

Ool02Woo00=l07ooOol0D7oo0g`000<07g`0O000TGoo000KOol00`00Oomoo`0<Ool00`0OOomoo`09

Ool00g`0Oomoo`1@Ool2O00017oo01ml07`0TGoo000KOol00`00Oomoo`0<Ool201l:Ool00g`0Oomo

o`1@Ool2O000100OO01l07`0TGoo000KOol00`00Oomoo`0=Ool00`0OOomoo`08Ool00g`0Oomoo`1=

Ool4O0000`0OOoml0002O02AOol001]oo`8000moo`0301moogoo00Moo`03O01oogoo04eoo`06O01o

og`0O0007goo0W`0TWoo000KOol00`00Oomoo`0>Ool201l8Ool00g`0Oomoo`1=Ool01W`0Ooml000O

O01oo`9l099oo`006goo00<007ooOol03Woo00=l000OOol01goo00=l07ooOol0B7oo0W`00goo00=l

07oo01l00W`000=oog`0O000TWoo000KOol00`00Oomoo`0>Ool00g`0Ool07`07Ool00g`0Oomoo`18

Ool2O003Ool00g`0Ool07`02O0000gooO01l002BOol001]oo`03001oogoo00ioo`03O01oo`0O00Mo

o`03O01oogoo01Aoo`03O01oogoo00Qoo`03O01oogoo02Ioo`9l00=oo`03O0007g`0009l09Eoo`00

2goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol03Woo00Al07ooOol0

7`=oo`04O01oogooO009Ool00g`0Oomoo`0:Ool00g`0Oomoo`08Ool00g`0Oomoo`0VOol2O003Ool2

01l3O02EOol000Yoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo00ioo`05O01oogooOol0

7`02Ool017`0Oomoog`02Goo00=l07ooOol02Woo00=l07ooOol01Woo00=l07ooO000:7oo1G`000<0

7gooO0000W`0UGoo000:Ool00`00Ool00009Ool00`00Oomoo`02Ool2000?Ool017`0Oomoogoo0P0O

00Eoog`0Oomoog`000Uoo`03O01oogoo00Yoo`03O01oogoo00Ioo`03O01oog`002Qoo`05O01oogoo

Ool07`02Ool3O02EOol000Yoo`03001oo`0000Moo`8000Eoo`03001oogoo00ioo`03O01oogoo009o

o`0401moog`0Ool3O008Ool00g`0Oomoo`0:Ool00g`0Oomoo`06Ool00g`0Ooml000QOol00g`0Oomo

o`04Ool017`0Oomoo`0O0goo0W`0UWoo000:Ool00`00Ool00007Ool00`00Oomoo`04Ool00`00Oomo

o`0>Ool00g`0Oomoo`03Ool01P0OO01oog`0Ooml00Qoo`03O01oogoo00Eoo`03O01oogoo009oo`03

O01oogoo00Ioo`03O01oog`0025oo`03O01oogoo00Aoo`04O01oogoo01l3Ool2O02FOol000]oo`03

001oogoo00Ioo`<000Aoo`03001oogoo00ioo`03O01oogoo00=oo`807`04Ooml07ooO008Ool00g`0

Oomoo`05Ool00g`0Oomoo`02Ool00g`0Oomoo`06Ool00g`0Ooml000QOol00g`0Oomoo`04Ool00g`0

Ool07`04Ool00g`0Oomoo`2EOol001]oo`03001oogoo00ioo`03O01oogoo00Aoo`0501moog`0Ooml

0008Ool2O006Ool00g`0Oomoo`02Ool2O007Ool017`0Ooml07`087oo00Al07ooOomoo`Al000301mo

ogoo00=oo`03O01oogoo09Eoo`006goo00<007ooOol03Woo00=l07ooOol017oo00El000OO01oog`0

00Qoo`9l00Ioo`03O01oogoo009oo`9l00Moo`Al021oo`07O01oogooOoml07ooO0000P0O1Goo00=l

07ooOol0UGoo000KOol00`00Oomoo`0>Ool00g`0Oomoo`04Ool01G`0Ool07gooO00027oo0W`01Woo

0W`00goo0W`01goo17`087oo00Ql07ooOomoog`0Ooml000O1Woo00=l07ooOol0UGoo000KOol2000?

Ool00g`0Oomoo`04Ool01G`0Ool07`0OO00027oo0W`01Woo0W`00goo0W`01goo17`087oo00Ql07oo

Oomoog`0Ool07g`01Woo00=l07ooOol0UGoo000KOol00`00Oomoo`0>Ool00g`0Oomoo`04Ool01G`0

Ooml000OO00027oo0W`01Woo0W`00goo0W`01goo17`087oo00Il07ooOomoog`001l2O006Ool00g`0

Oomoo`2EOol001]ooaUl0004Ooml07oo01l@O0000gooO01l000@O00OOol017`0Ooml07`00P0O0W`0

1Woo00=l07ooOol0UGoo000KOol00`00Oomoo`0=Ool00g`0Oomoo`04Ool2O0001GooO01oogoo01l0

1Woo0W`01Goo0W`017oo0W`01goo17`000=oog`0Ool07Woo00Il07ooO01oo`0OOol2O006Ool00g`0

Oomoo`2EOol001]oo`03001oogoo00eoo`03O01oogoo00Aoo`9l0004Ooml07ooOol201l5Ool2O005

Ool2O004Ool2O007Ool4O0000gooO01oo`0NOol017`0Ooml000O0Woo0W`01Woo00=l07ooOol0UGoo

000KOol00`00Oomoo`0=Ool00g`0Oomoo`04Ool2O0000gooO01oo`02Ool00`0OOomoo`03Ool2O005

Ool2O004Ool2O007Ool4O0000gooO01oo`0NOol00g`0Ool07`03Ool2O006Ool00g`0Oomoo`2EOol0

01]oo`03001oogoo00eoo`03O01oogoo00Aoo`9l0003Ooml07oo00=oo`0301moogoo009oo`9l00Io

o`03O01oogoo009oo`9l00Moo`Al0003Ooml07oo01ioo`03O0007`0O00]oo`03O01oogoo09Eoo`00

6goo0P003Woo00=l07ooOol017oo0W`000=oog`0Ool00goo0P0O0goo0W`01Woo00=l07ooOol00Woo

0W`01goo17`000=oog`0Ool07Woo0P0O00=l07ooOol02Goo00=l07ooOol0UGoo000KOol00`00Oomo

o`0=Ool00g`0Oomoo`04Ool2O0000gooO01oo`04Ool00`0OOomoo`02Ool00g`0Oomoo`04Ool00g`0

Oomoo`02Ool2O008Ool3O0000gooO01oo`0NOol00`0OOoml000;Ool00g`0Oomoo`2EOol001]oo`03

001oogoo00eoo`03O01oogoo00Aoo`Al00Ioo`0501moogooOoml0006Ool00g`0Oomoo`03Ool00g`0

Oomoo`06Ool01G`0Ooml07ooO0007Woo00@07g`0Ooml0:=oo`006goo00<007ooOol03Goo00=l07oo

Ool017oo00=l07ooOol027oo00@07gooOoml00aoo`03O01oogoo00Ioo`05O01oog`0Ooml000GOol6

O0001@0OO01l07ooO000Xgoo000KOol00`00Oomoo`0=Ool00g`0Oomoo`04Ool00g`0Oomoo`09Ool0

0`0OOoml000<Ool00g`0Oomoo`06Ool01G`0Ooml07ooO0005goo00=l07ooOol00Woo00H07gooO01l

07ooO02SOol001]oo`03001oogoo00eoo`03O01oogoo00Aoo`03O01oogoo00Yoo`0301ml07oo00]o

o`03O01oogoo00Ioo`05O01oog`0Ooml000GOol01G`0Oomoogoo01l00Woo0W`000=oog`0Ool0XWoo

000KOol00`00Oomoo`0=Ool00g`0Oomoo`04Ool00g`0Oomoo`0:Ool201l<Ool00g`0Oomoo`08Ool0

0g`0Ooml000GOol00g`0Oomoo`0201l2Ool4O02SOol001]oo`8000ioo`03O01oogoo019oo`807`]o

o`03O01oogoo00Qoo`04O01oogooO004Ool00g`0Oomoo`0;Ool5O0000goo01l07`03Ool00g`0Oomo

o`2TOol001]oo`03001oogoo00eoo`03O01oogoo01=oo`807aQoo`03O01oogoo009oo`03O01oogoo

00]oo`03O01oogoo009oo`807`Aoo`03O01oogoo0:Aoo`006goo00<007ooOol097oo0P0O5goo00=l

07ooOol00Woo00=l07ooOol02goo00Al07ooOomoo`807`Eoo`03O01oogoo0:Aoo`006goo00<007oo

Ool09Goo0P0O5Woo00=l07ooOol00Woo00=l07ooOol02goo00=l07ooOol00P0O1Woo00=l07ooOol0

Y7oo000KOol00`00Oomoo`0WOol00`0OOomoo`0COol00g`0Oomoo`02Ool00g`0Oomoo`0;Ool00g`0

Ool07`08Ool00g`0Oomoo`2TOol001]oo`03001oogoo02Qoo`0301moogoo019oo`03O01oogoo009o

o`03O01oogoo00]oo`03O0007goo00Qoo`03O01oogoo0:Aoo`006goo00<007ooOol0:Goo0P0O4Woo

00=l07ooOol00Woo0W`02goo0P0O2Woo00=l07ooOol0Y7oo000KOol2000[Ool201lAOol00g`0Oomo

o`02Ool2O00:Ool201l00g`0Oomoo`08Ool00g`0Oomoo`2TOol001]oo`03001oogoo02aoo`807`mo

o`03O01oogoo009oo`9l00Qoo`807`9oo`03O01oogoo00Qoo`03O01oogoo0:Aoo`006goo00<007oo

Ool0;Goo0P0O3Woo00=l07ooOol00Woo0W`01goo0P0O17`02Woo00=l07ooOol0Y7oo000KOol00`00

Oomoo`0_Ool201l<Ool00g`0Oomoo`02Ool2O005Ool301l00g`0Oomoo`0<Ool00g`0Oomoo`2TOol0

01]oo`03001oogoo035oo`807`Yoo`El0003Ooml07`0009l00<07`=l00ioo`03O01oogoo0:Aoo`00

4goo1@000goo00<007ooOol0<goo0`0O2Woo0W`00Woo100O^Woo000EOol00`00Oomoo`03Ool00`00

Oomoo`0fOol501l5Ool501nmOol001Eoo`03001oogoo00=oo`8003]oo`H07`9l0<1oo`005Goo00<0

07ooOol00goo00<007ooOol0@7oo0W`0`7oo000EOol00`00Oomoo`03Ool00`00Oomoo`10Ool2O030

Ool001Aoo`8000Eoo`03001oogoo045oo`03O01oogoo0;ioo`006goo00<007ooOol0@Goo00=l07oo

Ool0_Woo000KOol00`00Oomoo`11Ool00g`0Oomoo`2nOol001]oo`03001oogoo045oo`03O01oogoo

0;ioo`006goo0P00@Woo00=l07ooOol0_Woo000KOol00`00Oomoo`11Ool00g`0Oomoo`2nOol001]o

o`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]o

o`03001oogoo0?moo`=oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo

ob5oo`00\

\>"],

  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-55.2265, -1.29679, 2.02101, 

  0.0145287}}],



Cell[BoxData[

    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),

      False,

      Editable->False]], "Output"]

}, Open  ]]

}, Open  ]]

}, Open  ]]

}, Open  ]]

},

FrontEndVersion->"Macintosh 3.0",

ScreenRectangle->{{0, 800}, {0, 580}},

ScreenStyleEnvironment->"Presentation",

PrintingStyleEnvironment->"Printout",

ShowPageBreaks->True,

WindowSize->{588, 430},

WindowMargins->{{43, Automatic}, {Automatic, 17}},

PrintingCopies->1,

PrintingPageRange->{Automatic, Automatic},

PrivateFontOptions->{"FontType"->"Outline"},

StyleDefinitions -> "HTML.nb",

MacintoshSystemPageSetup->"\<\

00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001

0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000

00000000000000000000000000000000\>"

]





(***********************************************************************

Cached data follows.  If you edit this Notebook file directly, not using

Mathematica, you must remove the line containing CacheID at the top of 

the file.  The cache data will then be recreated when you save this file 

from within Mathematica.

***********************************************************************)



(*CellTagsOutline

CellTagsIndex->{}

*)



(*CellTagsIndex

CellTagsIndex->{}

*)



(*NotebookFileOutline

Notebook[{



Cell[CellGroupData[{

Cell[1731, 51, 73, 0, 92, "Title"],

Cell[1807, 53, 25, 0, 39, "Subtitle"],

Cell[1835, 55, 76, 0, 35, "Subsubtitle"],

Cell[1914, 57, 192, 6, 25, "Text"],

Cell[2109, 65, 192, 3, 32, "Input"],



Cell[CellGroupData[{

Cell[2326, 72, 62, 0, 35, "Subsubtitle"],

Cell[2391, 74, 214, 4, 32, "Input"]

}, Open  ]],



Cell[CellGroupData[{

Cell[2642, 83, 63, 0, 35, "Subsubtitle"],

Cell[2708, 85, 230, 4, 32, "Input"],

Cell[2941, 91, 181, 3, 32, "Input"],

Cell[3125, 96, 206, 4, 32, "Input"]

}, Open  ]],



Cell[CellGroupData[{

Cell[3368, 105, 96, 2, 35, "Subsubtitle"],

Cell[3467, 109, 113, 3, 25, "Text"],

Cell[3583, 114, 70, 1, 22, "Input"],

Cell[3656, 117, 62, 1, 22, "Input"],

Cell[3721, 120, 129, 2, 22, "Input"]

}, Open  ]],



Cell[CellGroupData[{

Cell[3887, 127, 63, 0, 35, "Subsubtitle"],

Cell[3953, 129, 219, 5, 43, "Input"],

Cell[4175, 136, 346, 7, 54, "Input"]

}, Open  ]],



Cell[CellGroupData[{

Cell[4558, 148, 68, 0, 35, "Subsubtitle"],

Cell[4629, 150, 89, 1, 22, "Input"],

Cell[4721, 153, 102, 2, 22, "Input"],

Cell[4826, 157, 87, 1, 22, "Input"],

Cell[4916, 160, 88, 1, 22, "Input"],

Cell[5007, 163, 378, 6, 77, "Input"]

}, Open  ]],



Cell[CellGroupData[{

Cell[5422, 174, 33, 0, 39, "Subtitle"],

Cell[5458, 176, 95, 1, 45, "Subsubtitle"],

Cell[5556, 179, 87, 1, 22, "Input"],



Cell[CellGroupData[{

Cell[5668, 184, 68, 1, 22, "Input"],

Cell[5739, 187, 26516, 1659, 253, 11911, 1474, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]],



Cell[CellGroupData[{

Cell[32292, 1851, 43, 0, 35, "Subsubtitle"],

Cell[32338, 1853, 158, 3, 32, "Input"],



Cell[CellGroupData[{

Cell[32521, 1860, 67, 1, 22, "Input"],

Cell[32591, 1863, 49922, 1233, 251, 11316, 752, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{

Cell[82562, 3102, 63, 0, 35, "Subsubtitle"],

Cell[82628, 3104, 152, 3, 20, "Message"],

Cell[82783, 3109, 152, 3, 20, "Message"],

Cell[82938, 3114, 151, 3, 20, "Message"],

Cell[83092, 3119, 213, 4, 28, "Message"],

Cell[83308, 3125, 151, 3, 20, "Message"],

Cell[83462, 3130, 68, 0, 25, "Text"],



Cell[CellGroupData[{

Cell[83555, 3134, 54, 1, 22, "Input"],

Cell[83612, 3137, 15053, 242, 1948, "Output"]

}, Closed]],



Cell[CellGroupData[{

Cell[98702, 3384, 63, 1, 20, "Input"],

Cell[98768, 3387, 1752, 23, 354, "Output"]

}, Open  ]],

Cell[100535, 3413, 63, 1, 22, "Input"],



Cell[CellGroupData[{

Cell[100623, 3418, 57, 1, 22, "Input"],

Cell[100683, 3421, 38111, 2744, 261, 20685, 2524, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]],

Cell[138809, 6168, 60, 1, 22, "Input"],



Cell[CellGroupData[{

Cell[138894, 6173, 66, 2, 32, "Input"],

Cell[138963, 6177, 54, 1, 22, "Output"],

Cell[139020, 6180, 59, 1, 22, "Output"]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{

Cell[139128, 6187, 61, 0, 35, "Subsubtitle"],



Cell[CellGroupData[{

Cell[139214, 6191, 63, 1, 22, "Input"],

Cell[139280, 6194, 1929, 25, 212, "Output"]

}, Open  ]],

Cell[141224, 6222, 63, 1, 22, "Input"],



Cell[CellGroupData[{

Cell[141312, 6227, 57, 1, 22, "Input"],

Cell[141372, 6230, 39006, 1508, 263, 19423, 1262, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{

Cell[180427, 7744, 50, 0, 35, "Subsubtitle"],

Cell[180480, 7746, 322, 5, 51, "Text"],



Cell[CellGroupData[{

Cell[180827, 7755, 65, 1, 22, "Input"],

Cell[180895, 7758, 1893, 25, 212, "Output"]

}, Open  ]],

Cell[182803, 7786, 65, 1, 22, "Input"],



Cell[CellGroupData[{

Cell[182893, 7791, 58, 1, 22, "Input"],

Cell[182954, 7794, 31713, 1419, 185, 19391, 1262, "GraphicsData", 

"PostScript", "Graphics"],

Cell[214670, 9215, 130, 3, 22, "Output"]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{

Cell[214849, 9224, 50, 0, 35, "Subsubtitle"],

Cell[214902, 9226, 177, 3, 38, "Text"],



Cell[CellGroupData[{

Cell[215104, 9233, 65, 1, 22, "Input"],

Cell[215172, 9236, 3111, 43, 257, "Output"]

}, Open  ]],

Cell[218298, 9282, 65, 1, 22, "Input"],



Cell[CellGroupData[{

Cell[218388, 9287, 58, 1, 22, "Input"],

Cell[218449, 9290, 37629, 1500, 185, 19479, 1271, "GraphicsData", 

"PostScript", "Graphics"],

Cell[256081, 10792, 130, 3, 22, "Output"]

}, Open  ]]

}, Open  ]]

}, Open  ]]

}, Open  ]]

}

]

*)









(***********************************************************************

End of Mathematica Notebook file.

***********************************************************************)



